@@ -250,10 +250,10 @@ archivePushCheck(bool pgPathSet)
                             ArchiveMismatchError,
                             "%s version %s, system-id %" PRIu64 " do not match %s stanza version %s, system-id %" PRIu64
                             "\nHINT: are you archiving to the correct stanza?",
-                            pgPathSet ? PG_NAME : strZ(strNewFmt("repo%u stanza", cfgOptionGroupIdxToKey(cfgOptGrpRepo, 0))),
+                            pgPathSet ? PG_NAME : strZ(strNewFmt("%s stanza", cfgOptionGroupName(cfgOptGrpRepo, 0))),
                             strZ(pgVersionToStr(result.pgVersion)), result.pgSystemId,
-                            strZ(strNewFmt("repo%u", cfgOptionGroupIdxToKey(cfgOptGrpRepo, repoIdx))),
-                            strZ(pgVersionToStr(archiveInfo.version)), archiveInfo.systemId);
+                            cfgOptionGroupName(cfgOptGrpRepo, repoIdx), strZ(pgVersionToStr(archiveInfo.version)),
+                            archiveInfo.systemId);
                     }
                 }
 
@@ -279,8 +279,7 @@ archivePushCheck(bool pgPathSet)
                 strLstAdd(
                     result.errorList,
                     strNewFmt(
-                        "repo%u: [%s] %s", cfgOptionGroupIdxToKey(cfgOptGrpRepo, repoIdx), errorTypeName(errorType()),
-                        errorMessage()));
+                        "%s: [%s] %s", cfgOptionGroupName(cfgOptGrpRepo, repoIdx), errorTypeName(errorType()), errorMessage()));
             }
             TRY_END();
         }
@@ -413,7 +412,7 @@ cmdArchivePush(void)
                 // Push the file to the archive
                 ArchivePushFileResult fileResult = archivePushFile(
                     walFile, cfgOptionBool(cfgOptArchiveHeaderCheck), archiveInfo.pgVersion, archiveInfo.pgSystemId, archiveFile,
-                    compressTypeEnum(cfgOptionStr(cfgOptCompressType)), cfgOptionInt(cfgOptCompressLevel), archiveInfo.repoList,
+                    compressTypeEnum(cfgOptionStrId(cfgOptCompressType)), cfgOptionInt(cfgOptCompressLevel), archiveInfo.repoList,
                     archiveInfo.errorList);
 
                 // If a warning was returned then log it
@@ -526,7 +525,7 @@ cmdArchivePushAsync(void)
         ArchivePushAsyncData jobData =
         {
             .walPath = strLstGet(commandParam, 0),
-            .compressType = compressTypeEnum(cfgOptionStr(cfgOptCompressType)),
+            .compressType = compressTypeEnum(cfgOptionStrId(cfgOptCompressType)),
             .compressLevel = cfgOptionInt(cfgOptCompressLevel),
         };
 
@@ -629,7 +628,7 @@ cmdArchivePushAsync(void)
             }
         }
         // On any global error write a single error file to cover all unprocessed files
-        CATCH_ANY()
+        CATCH_FATAL()
         {
             archiveAsyncStatusErrorWrite(archiveModePush, NULL, errorCode(), STR(errorMessage()));
             RETHROW();
