@@ -23,28 +23,33 @@ typedef enum
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
+// Copy a file from the archive to the specified destination
+typedef struct BackupFile
+{
+    const String *pgFile;                                           // Pg file to backup
+    bool pgFileIgnoreMissing;                                       // Ignore missing pg file
+    uint64_t pgFileSize;                                            // Expected pg file size
+    bool pgFileCopyExactSize;                                       // Copy only pg expected size
+    const String *pgFileChecksum;                                   // Expected pg file checksum
+    bool pgFileChecksumPage;                                        // Validate page checksums?
+    const String *manifestFile;                                     // Repo file
+    bool manifestFileHasReference;                                  // Reference to prior backup, if any
+} BackupFile;
+
 // Copy a file from the PostgreSQL data directory to the repository
 typedef struct BackupFileResult
 {
+    const String *manifestFile;                                     // Manifest file
     BackupCopyResult backupCopyResult;
     uint64_t copySize;
     String *copyChecksum;
+    uint64_t bundleOffset;                                          // Offset in bundle if any
     uint64_t repoSize;
-    KeyValue *pageChecksumResult;
+    Pack *pageChecksumResult;
 } BackupFileResult;
 
-BackupFileResult backupFile(
-    const String *pgFile, bool pgFileIgnoreMissing, uint64_t pgFileSize, bool pgFileCopyExactSize, const String *pgFileChecksum,
-    bool pgFileChecksumPage, uint64_t pgFileChecksumPageLsnLimit, const String *repoFile, bool repoFileHasReference,
-    CompressType repoFileCompressType, int repoFileCompressLevel, const String *backupLabel, bool delta, CipherType cipherType,
-    const String *cipherPass);
-
-/***********************************************************************************************************************************
-Macros for function logging
-***********************************************************************************************************************************/
-#define FUNCTION_LOG_BACKUP_FILE_RESULT_TYPE                                                                                       \
-    BackupFileResult
-#define FUNCTION_LOG_BACKUP_FILE_RESULT_FORMAT(value, buffer, bufferSize)                                                          \
-    objToLog(&value, "BackupFileResult", buffer, bufferSize)
+List *backupFile(
+    const String *repoFile, CompressType repoFileCompressType, int repoFileCompressLevel, bool delta, CipherType cipherType,
+    const String *cipherPass, const List *fileList);
 
 #endif
