@@ -11,13 +11,12 @@ Check all pages in a PostgreSQL relation to ensure the checksums are valid.
 /***********************************************************************************************************************************
 Filter type constant
 ***********************************************************************************************************************************/
-#define PAGE_CHECKSUM_FILTER_TYPE                                   "pageChecksum"
-    STRING_DECLARE(PAGE_CHECKSUM_FILTER_TYPE_STR);
+#define PAGE_CHECKSUM_FILTER_TYPE                                   STRID5("pg-chksum", 0xdacd681ecf00)
 
 /***********************************************************************************************************************************
-Constructor
+Constructors
 ***********************************************************************************************************************************/
-IoFilter *pageChecksumNew(unsigned int segmentNo, unsigned int segmentPageTotal, uint64_t lsnLimit);
-IoFilter *pageChecksumNewVar(const VariantList *paramList);
+IoFilter *pageChecksumNew(unsigned int segmentNo, unsigned int segmentPageTotal, const String *fileName);
+IoFilter *pageChecksumNewPack(const Pack *paramList);
 
 #endif
