@@ -12,12 +12,18 @@ Stop Command
 
 #include "command/control/common.h"
 #include "common/debug.h"
+#include "common/lock.h"
 #include "common/type/convert.h"
 #include "config/config.h"
 #include "storage/helper.h"
 #include "storage/storage.h"
 #include "storage/storage.intern.h"
 
+/***********************************************************************************************************************************
+Read contents of lock file. ??? This should be merged into the lock code.
+***********************************************************************************************************************************/
+LockData lockReadDataFile(const String *lockFile, int fd);
+
 /**********************************************************************************************************************************/
 void
 cmdStop(void)
@@ -62,7 +68,7 @@ cmdStop(void)
                     // If we cannot open the lock file for any reason then warn and continue to next file
                     if ((fd = open(strZ(lockFile), O_RDONLY, 0)) == -1)
                     {
-                        LOG_WARN_FMT( "unable to open lock file %s", strZ(lockFile));
+                        LOG_WARN_FMT("unable to open lock file %s", strZ(lockFile));
                         continue;
                     }
 
@@ -76,17 +82,15 @@ cmdStop(void)
                     }
 
                     // The file is locked so that means there is a running process - read the process id and send it a term signal
-                    char contents[64];
-                    ssize_t actualBytes = read(fd, contents, sizeof(contents));
-                    String *processId = actualBytes > 0 ? strTrim(strNewN(contents, (size_t)actualBytes)) : NULL;
+                    const pid_t processId = lockReadDataFile(lockFile, fd).processId;
 
                     // If the process id is defined then assume this is a valid lock file
-                    if (processId != NULL && strSize(processId) > 0)
+                    if (processId != 0)
                     {
-                        if (kill(cvtZToInt(strZ(processId)), SIGTERM) != 0)
-                            LOG_WARN_FMT("unable to send term signal to process %s", strZ(processId));
+                        if (kill(processId, SIGTERM) != 0)
+                            LOG_WARN_FMT("unable to send term signal to process %d", processId);
                         else
-                            LOG_INFO_FMT("sent term signal to process %s", strZ(processId));
+                            LOG_INFO_FMT("sent term signal to process %d", processId);
                     }
                     else
                     {
@@ -100,7 +104,7 @@ cmdStop(void)
         {
             LOG_WARN_FMT(
                 "stop file already exists for %s",
-                cfgOptionTest(cfgOptStanza) ? strZ(strNewFmt("stanza %s", strZ(cfgOptionStr(cfgOptStanza)))) : "all stanzas");
+                cfgOptionTest(cfgOptStanza) ? strZ(strNewFmt("stanza %s", strZ(cfgOptionDisplay(cfgOptStanza)))) : "all stanzas");
         }
     }
     MEM_CONTEXT_TEMP_END();
