@@ -20,7 +20,7 @@ Help Command
 #include "version.h"
 
 /***********************************************************************************************************************************
-Define the console width - use a fixed with of 80 since this should be safe on virtually all consoles
+Define the console width - use a fixed width of 80 since this should be safe on virtually all consoles
 ***********************************************************************************************************************************/
 #define CONSOLE_WIDTH                                               80
 
@@ -150,61 +150,65 @@ helpRenderText(const String *text, const bool internal, size_t indent, bool inde
 Helper function for helpRender() to output values as strings
 ***********************************************************************************************************************************/
 static const String *
-helpRenderValue(const Variant *value, ConfigOptionType type)
+helpRenderValue(const ConfigOption optionId, const unsigned int optionIdx)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
-        FUNCTION_LOG_PARAM(VARIANT, value);
-        FUNCTION_LOG_PARAM(ENUM, type);
+        FUNCTION_LOG_PARAM(ENUM, optionId);
+        FUNCTION_LOG_PARAM(UINT, optionIdx);
     FUNCTION_LOG_END();
 
     const String *result = NULL;
 
-    if (value != NULL)
+    if (cfgOptionIdxSource(optionId, 0) != cfgSourceDefault)
     {
-        if (varType(value) == varTypeBool)
-        {
-            if (varBool(value))
-                result = Y_STR;
-            else
-                result = N_STR;
-        }
-        else if (varType(value) == varTypeKeyValue)
-        {
-            String *resultTemp = strNew();
+        const Variant *const value = cfgOptionIdxVar(optionId, optionIdx);
+        ASSERT(value != NULL);
 
-            const KeyValue *optionKv = varKv(value);
-            const VariantList *keyList = kvKeyList(optionKv);
-
-            for (unsigned int keyIdx = 0; keyIdx < varLstSize(keyList); keyIdx++)
+        switch (varType(value))
+        {
+            case varTypeKeyValue:
             {
-                if (keyIdx != 0)
-                    strCatZ(resultTemp, ", ");
+                String *resultTemp = strNew();
 
-                strCatFmt(
-                    resultTemp, "%s=%s", strZ(varStr(varLstGet(keyList, keyIdx))),
-                    strZ(varStrForce(kvGet(optionKv, varLstGet(keyList, keyIdx)))));
+                const KeyValue *optionKv = varKv(value);
+                const VariantList *keyList = kvKeyList(optionKv);
+
+                for (unsigned int keyIdx = 0; keyIdx < varLstSize(keyList); keyIdx++)
+                {
+                    if (keyIdx != 0)
+                        strCatZ(resultTemp, ", ");
+
+                    strCatFmt(
+                        resultTemp, "%s=%s", strZ(varStr(varLstGet(keyList, keyIdx))),
+                        strZ(varStrForce(kvGet(optionKv, varLstGet(keyList, keyIdx)))));
+                }
+
+                result = resultTemp;
+                break;
             }
 
-            result = resultTemp;
-        }
-        else if (varType(value) == varTypeVariantList)
-        {
-            String *resultTemp = strNew();
-
-            const VariantList *list = varVarLst(value);
-
-            for (unsigned int listIdx = 0; listIdx < varLstSize(list); listIdx++)
+            case varTypeVariantList:
             {
-                if (listIdx != 0)
-                    strCatZ(resultTemp, ", ");
+                String *resultTemp = strNew();
 
-                strCatFmt(resultTemp, "%s", strZ(varStr(varLstGet(list, listIdx))));
+                const VariantList *list = varVarLst(value);
+
+                for (unsigned int listIdx = 0; listIdx < varLstSize(list); listIdx++)
+                {
+                    if (listIdx != 0)
+                        strCatZ(resultTemp, ", ");
+
+                    strCatFmt(resultTemp, "%s", strZ(varStr(varLstGet(list, listIdx))));
+                }
+
+                result = resultTemp;
+                break;
             }
 
-            result = resultTemp;
+            default:
+                result = cfgOptionIdxDisplay(optionId, optionIdx);
+                break;
         }
-        else
-            result = cfgOptionDisplayVar(value, type);
     }
 
     FUNCTION_LOG_RETURN_CONST(STRING, result);
@@ -386,7 +390,9 @@ helpRender(const Buffer *const helpData)
             if (strLstEmpty(cfgCommandParam()))
             {
                 // Output command summary and description. Add a warning for internal commands.
-                CHECK(commandData[commandId].summary != NULL && commandData[commandId].description != NULL);
+                CHECK(
+                    AssertError, commandData[commandId].summary != NULL && commandData[commandId].description != NULL,
+                    "command help missing");
 
                 strCatFmt(
                     result,
@@ -450,10 +456,7 @@ helpRender(const Buffer *const helpData)
 
                         // Output current and default values if they exist
                         const String *defaultValue = cfgOptionDefault(optionId);
-                        const String *value = NULL;
-
-                        if (cfgOptionIdxSource(optionId, 0) != cfgSourceDefault)
-                            value = helpRenderValue(cfgOptionIdxVar(optionId, 0), cfgParseOptionType(optionId));
+                        const String *value = helpRenderValue(optionId, 0);
 
                         if (value != NULL || defaultValue != NULL)
                         {
@@ -501,7 +504,9 @@ helpRender(const Buffer *const helpData)
                     THROW_FMT(OptionInvalidError, "option '%s' is not valid for command '%s'", strZ(optionName), commandName);
 
                 // Output option summary and description. Add a warning for internal options.
-                CHECK(optionData[option.id].summary != NULL && optionData[option.id].description != NULL);
+                CHECK(
+                    AssertError, optionData[option.id].summary != NULL && optionData[option.id].description != NULL,
+                    "option help missing");
 
                 strCatFmt(
                     result,
@@ -517,10 +522,7 @@ helpRender(const Buffer *const helpData)
 
                 // Output current and default values if they exist
                 const String *defaultValue = cfgOptionDefault(option.id);
-                const String *value = NULL;
-
-                if (cfgOptionIdxSource(option.id, 0) != cfgSourceDefault)
-                    value = helpRenderValue(cfgOptionIdxVar(option.id, 0), cfgParseOptionType(option.id));
+                const String *value = helpRenderValue(option.id, 0);
 
                 if (value != NULL || defaultValue != NULL)
                 {
