@@ -45,7 +45,7 @@ storageListRenderCallback(void *data, const StorageInfo *info)
         return;
     }
 
-    // Add seperator character
+    // Add separator character
     if (!listData->first && listData->json)
         ioWrite(listData->write, COMMA_BUF);
     else
@@ -60,28 +60,20 @@ storageListRenderCallback(void *data, const StorageInfo *info)
         switch (info->type)
         {
             case storageTypeFile:
-            {
                 ioWrite(listData->write, BUFSTRDEF("file\""));
                 break;
-            }
 
             case storageTypeLink:
-            {
                 ioWrite(listData->write, BUFSTRDEF("link\""));
                 break;
-            }
 
             case storageTypePath:
-            {
                 ioWrite(listData->write, BUFSTRDEF("path\""));
                 break;
-            }
 
             case storageTypeSpecial:
-            {
                 ioWrite(listData->write, BUFSTRDEF("special\""));
                 break;
-            }
         }
 
         if (info->type == storageTypeFile)
@@ -115,24 +107,36 @@ storageListRender(IoWrite *write)
     // Get sort order
     SortOrder sortOrder = sortOrderAsc;
 
-    if (strEqZ(cfgOptionStr(cfgOptSort), "desc"))
-        sortOrder = sortOrderDesc;
-    else if (!strEqZ(cfgOptionStr(cfgOptSort), "asc"))
+    switch (cfgOptionStrId(cfgOptSort))
     {
-        ASSERT(strEqZ(cfgOptionStr(cfgOptSort), "none"));
-        sortOrder = sortOrderNone;
+        case CFGOPTVAL_SORT_DESC:
+            sortOrder = sortOrderDesc;
+            break;
+
+        case CFGOPTVAL_SORT_NONE:
+            sortOrder = sortOrderNone;
+            break;
+
+        default:
+            ASSERT(cfgOptionStrId(cfgOptSort) == CFGOPTVAL_SORT_ASC);
     }
 
     // Get path
     const String *path = NULL;
 
     if (strLstSize(cfgCommandParam()) == 1)
+    {
         path = strLstGet(cfgCommandParam(), 0);
+
+        // Make sure the path does not end with a slash unless it is only /
+        if (strEndsWith(path, FSLASH_STR) && strSize(path) > 1)
+            path = strPath(path);
+    }
     else if (strLstSize(cfgCommandParam()) > 1)
         THROW(ParamInvalidError, "only one path may be specified");
 
     // Get options
-    bool json = strEqZ(cfgOptionStr(cfgOptOutput), "json") ? true : false;
+    bool json = cfgOptionStrId(cfgOptOutput) == CFGOPTVAL_OUTPUT_JSON ? true : false;
     const String *expression = cfgOptionStrNull(cfgOptFilter);
     RegExp *regExp = expression == NULL ? NULL : regExpNew(expression);
 
@@ -194,8 +198,7 @@ cmdStorageList(void)
     {
         TRY_BEGIN()
         {
-            storageListRender(
-                ioFdWriteNew(STRDEF("stdout"), STDOUT_FILENO, (TimeMSec)(cfgOptionDbl(cfgOptIoTimeout) * 1000)));
+            storageListRender(ioFdWriteNew(STRDEF("stdout"), STDOUT_FILENO, cfgOptionUInt64(cfgOptIoTimeout)));
         }
         // Ignore write errors because it's possible (even likely) that this output is being piped to something like head which
         // will exit when it gets what it needs and leave us writing to a broken pipe.  It would be better to just ignore the broken
