@@ -14,9 +14,9 @@ Functions
 ***********************************************************************************************************************************/
 // Copy a file from the backup to the specified destination
 bool restoreFile(
-    const String *repoFile, const String *repoFileReference, CompressType repoFileCompressType, const String *pgFile,
-    const String *pgFileChecksum, bool pgFileZero, uint64_t pgFileSize, time_t pgFileModified, mode_t pgFileMode,
-    const String *pgFileUser, const String *pgFileGroup, time_t copyTimeBegin, bool delta, bool deltaForce,
+    const String *repoFile, unsigned int repoIdx, uint64_t offset, const Variant *limit, CompressType repoFileCompressType,
+    const String *pgFile, const String *pgFileChecksum, bool pgFileZero, uint64_t pgFileSize, time_t pgFileModified,
+    mode_t pgFileMode, const String *pgFileUser, const String *pgFileGroup, time_t copyTimeBegin, bool delta, bool deltaForce,
     const String *cipherPass);
 
 #endif
