@@ -18,17 +18,18 @@ Represents an error type
 struct ErrorType
 {
     const int code;
+    const bool fatal;
     const char *name;
     const struct ErrorType *parentType;
 };
 
 // Macro for defining new error types
-#define ERROR_DEFINE(code, name, parentType)                                                                                       \
-    const ErrorType name = {code, #name, &parentType}
+#define ERROR_DEFINE(code, name, fatal, parentType)                                                                                \
+    const ErrorType name = {code, fatal, #name, &parentType}
 
 // Define test error
 #ifdef DEBUG
-    ERROR_DEFINE(1, TestError, RuntimeError);
+    ERROR_DEFINE(1, TestError, false, RuntimeError);
 #endif
 
 // Include error type definitions
@@ -42,7 +43,7 @@ Maximum allowed number of nested try blocks
 /***********************************************************************************************************************************
 States for each try
 ***********************************************************************************************************************************/
-typedef enum {errorStateBegin, errorStateTry, errorStateCatch, errorStateFinal, errorStateEnd} ErrorState;
+typedef enum {errorStateTry, errorStateCatch, errorStateEnd} ErrorState;
 
 /***********************************************************************************************************************************
 Track error handling
@@ -112,6 +113,13 @@ errorTypeCode(const ErrorType *errorType)
     return errorType->code;
 }
 
+/**********************************************************************************************************************************/
+bool
+errorTypeFatal(const ErrorType *const errorType)
+{
+    return errorType->fatal;
+}
+
 /**********************************************************************************************************************************/
 const ErrorType *
 errorTypeFromCode(int code)
@@ -191,6 +199,13 @@ errorCode(void)
     return errorTypeCode(errorType());
 }
 
+/**********************************************************************************************************************************/
+bool
+errorFatal(void)
+{
+    return errorTypeFatal(errorType());
+}
+
 /**********************************************************************************************************************************/
 const char *
 errorFileName(void)
@@ -260,27 +275,19 @@ errorInternalState(void)
 }
 
 /**********************************************************************************************************************************/
-bool
-errorInternalStateTry(void)
+void
+errorInternalTryBegin(const char *const fileName, const char *const functionName, const int fileLine)
 {
-    return errorInternalState() == errorStateTry;
-}
+    // If try total has been exceeded then throw an error
+    if (errorContext.tryTotal >= ERROR_TRY_MAX)
+        errorInternalThrowFmt(&AssertError, fileName, functionName, fileLine, "too many nested try blocks");
 
-/**********************************************************************************************************************************/
-bool
-errorInternalStateCatch(const ErrorType *errorTypeCatch)
-{
-    if (errorInternalState() == errorStateCatch && errorInstanceOf(errorTypeCatch))
-        return errorInternalProcess(true);
+    // Increment try total
+    errorContext.tryTotal++;
 
-    return false;
-}
-
-/**********************************************************************************************************************************/
-bool
-errorInternalStateFinal(void)
-{
-    return errorInternalState() == errorStateFinal;
+    // Setup try
+    errorContext.tryList[errorContext.tryTotal].state = errorStateTry;
+    errorContext.tryList[errorContext.tryTotal].uncaught = false;
 }
 
 /**********************************************************************************************************************************/
@@ -292,21 +299,26 @@ errorInternalJump(void)
 
 /**********************************************************************************************************************************/
 bool
-errorInternalTry(const char *fileName, const char *functionName, int fileLine)
+errorInternalCatch(const ErrorType *const errorTypeCatch, const bool fatalCatch)
 {
-    // If try total has been exceeded then throw an error
-    if (errorContext.tryTotal >= ERROR_TRY_MAX)
-        errorInternalThrowFmt(&AssertError, fileName, functionName, fileLine, "too many nested try blocks");
+    // If just entering error state clean up the stack
+    if (errorInternalState() == errorStateTry)
+    {
+        for (unsigned int handlerIdx = 0; handlerIdx < errorContext.handlerTotal; handlerIdx++)
+            errorContext.handlerList[handlerIdx](errorTryDepth());
 
-    // Increment try total
-    errorContext.tryTotal++;
+        errorContext.tryList[errorContext.tryTotal].state++;
+    }
 
-    // Setup try
-    errorContext.tryList[errorContext.tryTotal].state = errorStateBegin;
-    errorContext.tryList[errorContext.tryTotal].uncaught = false;
+    if (errorInternalState() == errorStateCatch && errorInstanceOf(errorTypeCatch) && (fatalCatch || !errorFatal()))
+    {
+        errorContext.tryList[errorContext.tryTotal].uncaught = false;
+        errorContext.tryList[errorContext.tryTotal].state++;
 
-    // Try setup was successful
-    return true;
+        return true;
+    }
+
+    return false;
 }
 
 /**********************************************************************************************************************************/
@@ -331,52 +343,22 @@ errorInternalPropagate(void)
 }
 
 /**********************************************************************************************************************************/
-bool
-errorInternalProcess(bool catch)
+void
+errorInternalTryEnd(void)
 {
-    // If a catch statement then return
-    if (catch)
-    {
-        errorContext.tryList[errorContext.tryTotal].uncaught = false;
-        return true;
-    }
-    // Else if just entering error state clean up the stack
-    else if (errorContext.tryList[errorContext.tryTotal].state == errorStateTry)
-    {
-        for (unsigned int handlerIdx = 0; handlerIdx < errorContext.handlerTotal; handlerIdx++)
-            errorContext.handlerList[handlerIdx](errorTryDepth());
-    }
-
     // Any catch blocks have been processed and none of them called RETHROW() so clear the error
-    if (errorContext.tryList[errorContext.tryTotal].state == errorStateCatch &&
+    if (errorContext.tryList[errorContext.tryTotal].state == errorStateEnd &&
         !errorContext.tryList[errorContext.tryTotal].uncaught)
     {
         errorContext.error = (Error){0};
     }
 
-    // Increment the state
-    errorContext.tryList[errorContext.tryTotal].state++;
-
-    // If the error has been caught then increment the state
-    if (errorContext.tryList[errorContext.tryTotal].state == errorStateCatch &&
-        !errorContext.tryList[errorContext.tryTotal].uncaught)
-    {
-        errorContext.tryList[errorContext.tryTotal].state++;
-    }
-
-    // Return if not done
-    if (errorContext.tryList[errorContext.tryTotal].state < errorStateEnd)
-        return true;
-
     // Remove the try
     errorContext.tryTotal--;
 
     // If not caught in the last try then propagate
     if (errorContext.tryList[errorContext.tryTotal + 1].uncaught)
         errorInternalPropagate();
-
-    // Nothing left to process
-    return false;
 }
 
 /**********************************************************************************************************************************/
