@@ -67,6 +67,9 @@ Functions to get information about a generic error type
 // Error type code
 int errorTypeCode(const ErrorType *errorType);
 
+// Is the error type fatal
+bool errorTypeFatal(const ErrorType *errorType);
+
 // Get error type using a code
 const ErrorType *errorTypeFromCode(int code);
 
@@ -88,6 +91,9 @@ const ErrorType *errorType(void);
 // Error code (pulled from error type)
 int errorCode(void);
 
+// Is the error fatal?
+bool errorFatal(void);
+
 // Error filename
 const char *errorFileName(void);
 
@@ -126,37 +132,51 @@ Begin a block where errors can be thrown
 #define TRY_BEGIN()                                                                                                                \
     do                                                                                                                             \
     {                                                                                                                              \
-        if (errorInternalTry(__FILE__, __func__, __LINE__) && setjmp(*errorInternalJump()) >= 0)                                   \
-        {                                                                                                                          \
-            while (errorInternalProcess(false))                                                                                    \
-            {                                                                                                                      \
-                if (errorInternalStateTry())
+        errorInternalTryBegin(__FILE__, __func__, __LINE__);                                                                       \
+                                                                                                                                   \
+        if (setjmp(*errorInternalJump()) == 0)                                                                                     \
+        {
 
 /***********************************************************************************************************************************
 Catch a specific error thrown in the try block
 ***********************************************************************************************************************************/
 #define CATCH(errorTypeCatch)                                                                                                      \
-                else if (errorInternalStateCatch(&errorTypeCatch))
+        }                                                                                                                          \
+        else if (errorInternalCatch(&errorTypeCatch, true))                                                                        \
+        {
+
+/***********************************************************************************************************************************
+Catch any non-fatal error thrown in the try block
+***********************************************************************************************************************************/
+#define CATCH_ANY()                                                                                                                \
+        }                                                                                                                          \
+        else if (errorInternalCatch(&RuntimeError, false))                                                                         \
+        {
 
 /***********************************************************************************************************************************
 Catch any error thrown in the try block
 ***********************************************************************************************************************************/
-#define CATCH_ANY()                                                                                                                \
-                else if (errorInternalStateCatch(&RuntimeError))
+#define CATCH_FATAL()                                                                                                              \
+        }                                                                                                                          \
+        else if (errorInternalCatch(&RuntimeError, true))                                                                          \
+        {
 
 /***********************************************************************************************************************************
 Code to run whether the try block was successful or not
 ***********************************************************************************************************************************/
 #define FINALLY()                                                                                                                  \
-                else if (errorInternalStateFinal())
+        }                                                                                                                          \
+        {
 
 /***********************************************************************************************************************************
 End the try block
 ***********************************************************************************************************************************/
 #define TRY_END()                                                                                                                  \
-            }                                                                                                                      \
         }                                                                                                                          \
-    } while (0)
+                                                                                                                                   \
+        errorInternalTryEnd();                                                                                                     \
+    }                                                                                                                              \
+    while (0)
 
 /***********************************************************************************************************************************
 Throw an error
@@ -279,26 +299,20 @@ Internal functions
 These functions are used by the macros to implement the error handler and should never be called independently.
 ***********************************************************************************************************************************/
 // Begin the try block
-bool errorInternalTry(const char *fileName, const char *functionName, int fileLine);
+void errorInternalTryBegin(const char *fileName, const char *functionName, int fileLine);
 
 // Return jump buffer for current try
 jmp_buf *errorInternalJump(void);
 
-// True when in try state
-bool errorInternalStateTry(void);
-
 // True when in catch state and the expected error matches
-bool errorInternalStateCatch(const ErrorType *errorTypeCatch);
-
-// True when in final state
-bool errorInternalStateFinal(void);
-
-// Process the error through each try and state
-bool errorInternalProcess(bool catch);
+bool errorInternalCatch(const ErrorType *errorTypeCatch, bool fatalCatch);
 
 // Propagate the error up so it can be caught
 void errorInternalPropagate(void) __attribute__((__noreturn__));
 
+// End the try block
+void errorInternalTryEnd(void);
+
 // Throw an error
 void errorInternalThrow(
     const ErrorType *errorType, const char *fileName, const char *functionName, int fileLine, const char *message,
