@@ -25,6 +25,7 @@ typedef struct TlsSession
     SSL *session;                                                   // TLS session on the file descriptor
     TimeMSec timeout;                                               // Timeout for any i/o operation (read, write, etc.)
     bool shutdownOnClose;                                           // Shutdown the TLS connection when closing the session
+    bool ignoreUnexpectedEof;                                       // Ignore unexpected EOF when requested
 
     IoRead *read;                                                   // Read interface
     IoWrite *write;                                                 // Write interface
@@ -128,18 +129,30 @@ tlsSessionResultProcess(TlsSession *this, int errorTls, long unsigned int errorT
     {
         // The connection was closed
         case SSL_ERROR_ZERO_RETURN:
+        // A syscall failed (this usually indicates unexpected eof)
+        case SSL_ERROR_SYSCALL:
         {
-            if (!closeOk)
-                THROW(ProtocolError, "unexpected TLS eof");
+            // Error on SSL_ERROR_SYSCALL if unexpected EOF is not allowed
+            if (errorTls == SSL_ERROR_SYSCALL && !this->ignoreUnexpectedEof)
+            {
+                THROW_SYS_ERROR_CODE(errorSys, KernelError, "TLS syscall error");
+            }
+            // Else close the connection if we are in a state where it is allowed, e.g. not connecting
+            else
+            {
+                if (!closeOk)
+                    THROW(ProtocolError, "unexpected TLS eof");
+
+                this->shutdownOnClose = false;
+                tlsSessionClose(this);
+            }
 
-            this->shutdownOnClose = false;
-            tlsSessionClose(this);
             break;
         }
 
         // Try again after waiting for read ready
         case SSL_ERROR_WANT_READ:
-            ioReadReadyP(ioSessionIoRead(this->ioSession), .error = true);
+            ioReadReadyP(ioSessionIoReadP(this->ioSession), .error = true);
             result = 0;
             break;
 
@@ -149,10 +162,6 @@ tlsSessionResultProcess(TlsSession *this, int errorTls, long unsigned int errorT
             result = 0;
             break;
 
-        // A syscall failed (this usually indicates unexpected eof)
-        case SSL_ERROR_SYSCALL:
-            THROW_SYS_ERROR_CODE(errorSys, KernelError, "TLS syscall error");
-
         // Any other error that we cannot handle
         default:
         {
@@ -220,7 +229,7 @@ tlsSessionRead(THIS_VOID, Buffer *buffer, bool block)
     {
         // If no TLS data pending then check the io to reduce blocking
         if (!SSL_pending(this->session))
-            ioReadReadyP(ioSessionIoRead(this->ioSession), .error = true);
+            ioReadReadyP(ioSessionIoReadP(this->ioSession), .error = true);
 
         // Read and handle errors. The error queue must be cleared before this operation.
         ERR_clear_error();
@@ -267,8 +276,7 @@ tlsSessionWrite(THIS_VOID, const Buffer *buffer)
 
         result = tlsSessionResult(this, SSL_write(this->session, bufPtrConst(buffer), (int)bufUsed(buffer)), false);
 
-        // Either a retry or all data was written
-        CHECK(result == 0 || (size_t)result == bufUsed(buffer));
+        CHECK(ServiceError, result == 0 || (size_t)result == bufUsed(buffer), "expected retry or complete write");
     }
 
     FUNCTION_LOG_RETURN_VOID();
@@ -293,16 +301,19 @@ tlsSessionEof(THIS_VOID)
 
 /**********************************************************************************************************************************/
 static IoRead *
-tlsSessionIoRead(THIS_VOID)
+tlsSessionIoRead(THIS_VOID, const bool ignoreUnexpectedEof)
 {
     THIS(TlsSession);
 
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(TLS_SESSION, this);
+        FUNCTION_TEST_PARAM(BOOL, ignoreUnexpectedEof);
     FUNCTION_TEST_END();
 
     ASSERT(this != NULL);
 
+    this->ignoreUnexpectedEof = ignoreUnexpectedEof;
+
     FUNCTION_TEST_RETURN(this->read);
 }
 
