@@ -10,7 +10,11 @@ Lock Handler
 #include <unistd.h>
 
 #include "common/debug.h"
+#include "common/io/bufferRead.h"
+#include "common/io/bufferWrite.h"
+#include "common/io/fdRead.h"
 #include "common/io/fdWrite.h"
+#include "common/io/io.h"
 #include "common/lock.h"
 #include "common/log.h"
 #include "common/memContext.h"
@@ -19,6 +23,13 @@ Lock Handler
 #include "storage/storage.intern.h"
 #include "version.h"
 
+/***********************************************************************************************************************************
+Constants
+***********************************************************************************************************************************/
+// Indicates a lock that was made by matching exec-id rather than holding an actual lock. This disguishes it from -1, which is a
+// general system error.
+#define LOCK_ON_EXEC_ID                                             -2
+
 /***********************************************************************************************************************************
 Lock type names
 ***********************************************************************************************************************************/
@@ -31,16 +42,103 @@ static const char *const lockTypeName[] =
 /***********************************************************************************************************************************
 Mem context and local variables
 ***********************************************************************************************************************************/
-static MemContext *lockMemContext = NULL;
-static String *lockFile[lockTypeAll];
-static int lockFd[lockTypeAll];
-static LockType lockTypeHeld = lockTypeNone;
+static struct LockLocal
+{
+    MemContext *memContext;                                         // Mem context for locks
+    LockType held;                                                  // Current lock type held
+    const String *execId;                                           // Process exec id
+
+    struct
+    {
+        String *name;                                               // Name of lock file
+        int fd;                                                     // File descriptor for lock file
+    } file[lockTypeAll];
+} lockLocal =
+{
+    .held = lockTypeNone,
+};
 
 /***********************************************************************************************************************************
-Acquire a lock using a file on the local filesystem
+Read contents of lock file
+
+If a seek is required to get to the beginning of the data, that must be done before calling this function.
+
+??? This function should not be extern'd, but need to fix dependency in cmdStop().
 ***********************************************************************************************************************************/
+// Size of initial buffer used to load lock file
+#define LOCK_BUFFER_SIZE                                            128
+
+// Helper to read data
+LockData
+lockReadDataFile(const String *const lockFile, const int fd)
+{
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(STRING, lockFile);
+        FUNCTION_LOG_PARAM(INT, fd);
+    FUNCTION_LOG_END();
+
+    ASSERT(lockFile != NULL);
+    ASSERT(fd != -1);
+
+    LockData result = {0};
+
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        // Read contents of file
+        Buffer *const buffer = bufNew(LOCK_BUFFER_SIZE);
+        IoWrite *const write = ioBufferWriteNewOpen(buffer);
+
+        ioCopy(ioFdReadNewOpen(lockFile, fd, 0), write);
+        ioWriteClose(write);
+
+        // Parse the file
+        const StringList *const parse = strLstNewSplitZ(strNewBuf(buffer), LF_Z);
+
+        MEM_CONTEXT_PRIOR_BEGIN()
+        {
+            if (!strEmpty(strTrim(strLstGet(parse, 0))))
+                result.processId = cvtZToInt(strZ(strLstGet(parse, 0)));
+
+            if (strLstSize(parse) == 3)
+                result.execId = strDup(strLstGet(parse, 1));
+        }
+        MEM_CONTEXT_PRIOR_END();
+    }
+    MEM_CONTEXT_TEMP_END();
+
+    FUNCTION_LOG_RETURN_STRUCT(result);
+}
+
+/***********************************************************************************************************************************
+Write contents of lock file
+***********************************************************************************************************************************/
+static void
+lockWriteData(const LockType lockType)
+{
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(ENUM, lockType);
+    FUNCTION_LOG_END();
+
+    ASSERT(lockType < lockTypeAll);
+    ASSERT(lockLocal.file[lockType].name != NULL);
+    ASSERT(lockLocal.file[lockType].fd != -1);
+
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        IoWrite *const write = ioFdWriteNewOpen(lockLocal.file[lockType].name, lockLocal.file[lockType].fd, 0);
+
+        ioCopy(ioBufferReadNewOpen(BUFSTR(strNewFmt("%d" LF_Z "%s" LF_Z, getpid(), strZ(lockLocal.execId)))), write);
+        ioWriteClose(write);
+    }
+    MEM_CONTEXT_TEMP_END();
+
+    FUNCTION_LOG_RETURN_VOID();
+}
+
+/**********************************************************************************************************************************/
+// Helper to acquire a file lock
 static int
-lockAcquireFile(const String *lockFile, TimeMSec lockTimeout, bool failOnNoLock)
+lockAcquireFile(const String *const lockFile, const TimeMSec lockTimeout, const bool failOnNoLock)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
         FUNCTION_LOG_PARAM(STRING, lockFile);
@@ -48,18 +146,23 @@ lockAcquireFile(const String *lockFile, TimeMSec lockTimeout, bool failOnNoLock)
         FUNCTION_LOG_PARAM(BOOL, failOnNoLock);
     FUNCTION_LOG_END();
 
+    ASSERT(lockFile != NULL);
+
     int result = -1;
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
         Wait *wait = waitNew(lockTimeout);
-        bool retry = false;
+        bool retry;
         int errNo = 0;
 
         do
         {
+            // Assume there will be no retry
+            retry = false;
+
             // Attempt to open the file
-            if ((result = open(strZ(lockFile), O_WRONLY | O_CREAT, STORAGE_MODE_FILE_DEFAULT)) == -1)
+            if ((result = open(strZ(lockFile), O_RDWR | O_CREAT, STORAGE_MODE_FILE_DEFAULT)) == -1)
             {
                 // Save the error for reporting outside the loop
                 errNo = errno;
@@ -79,9 +182,25 @@ lockAcquireFile(const String *lockFile, TimeMSec lockTimeout, bool failOnNoLock)
                     // Save the error for reporting outside the loop
                     errNo = errno;
 
-                    // Close the file and reset the file descriptor
-                    close(result);
-                    result = -1;
+                    // Get execId from lock file and close it
+                    const String *execId = NULL;
+
+                    TRY_BEGIN()
+                    {
+                        execId = lockReadDataFile(lockFile, result).execId;
+                    }
+                    FINALLY()
+                    {
+                        close(result);
+                    }
+                    TRY_END();
+
+                    // Even though we were unable to lock the file, it may be that it is already locked by another process with the
+                    // same exec-id, i.e. spawned by the same original main process. If so, report the lock as successful.
+                    if (strEq(execId, lockLocal.execId))
+                        result = LOCK_ON_EXEC_ID;
+                    else
+                        result = -1;
                 }
             }
         }
@@ -96,7 +215,7 @@ lockAcquireFile(const String *lockFile, TimeMSec lockTimeout, bool failOnNoLock)
                 const String *errorHint = NULL;
 
                 if (errNo == EWOULDBLOCK)
-                    errorHint = strNew("\nHINT: is another " PROJECT_NAME " process running?");
+                    errorHint = strNewZ("\nHINT: is another " PROJECT_NAME " process running?");
                 else if (errNo == EACCES)
                 {
                     errorHint = strNewFmt(
@@ -108,22 +227,94 @@ lockAcquireFile(const String *lockFile, TimeMSec lockTimeout, bool failOnNoLock)
                     errorHint == NULL ? "" : strZ(errorHint));
             }
         }
-        else
-        {
-            // Write pid of the current process
-            ioFdWriteOneStr(result, strNewFmt("%d\n", getpid()));
-        }
     }
     MEM_CONTEXT_TEMP_END();
 
     FUNCTION_LOG_RETURN(INT, result);
 }
 
-/***********************************************************************************************************************************
-Release the current lock
-***********************************************************************************************************************************/
+bool
+lockAcquire(
+    const String *lockPath, const String *stanza, const String *execId, LockType lockType, TimeMSec lockTimeout, bool failOnNoLock)
+{
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(STRING, lockPath);
+        FUNCTION_LOG_PARAM(STRING, stanza);
+        FUNCTION_LOG_PARAM(STRING, execId);
+        FUNCTION_LOG_PARAM(ENUM, lockType);
+        FUNCTION_LOG_PARAM(TIMEMSEC, lockTimeout);
+        FUNCTION_LOG_PARAM(BOOL, failOnNoLock);
+    FUNCTION_LOG_END();
+
+    ASSERT(lockPath != NULL);
+    ASSERT(stanza != NULL);
+    ASSERT(execId != NULL);
+
+    bool result = true;
+
+    // Don't allow failures when locking more than one file.  This makes cleanup difficult and there are no known use cases.
+    ASSERT(failOnNoLock || lockType != lockTypeAll);
+
+    // Don't allow another lock if one is already held
+    if (lockLocal.held != lockTypeNone)
+        THROW(AssertError, "lock is already held by this process");
+
+    // Allocate a mem context to hold lock filenames if one does not already exist
+    if (lockLocal.memContext == NULL)
+    {
+        MEM_CONTEXT_BEGIN(memContextTop())
+        {
+            MEM_CONTEXT_NEW_BEGIN("Lock")
+            {
+                lockLocal.memContext = MEM_CONTEXT_NEW();
+                lockLocal.execId = strDup(execId);
+            }
+            MEM_CONTEXT_NEW_END();
+        }
+        MEM_CONTEXT_END();
+    }
+
+    // Exec id should never change
+    ASSERT(strEq(execId, lockLocal.execId));
+
+    // Lock files
+    LockType lockMin = lockType == lockTypeAll ? lockTypeArchive : lockType;
+    LockType lockMax = lockType == lockTypeAll ? (lockTypeAll - 1) : lockType;
+
+    for (LockType lockIdx = lockMin; lockIdx <= lockMax; lockIdx++)
+    {
+        MEM_CONTEXT_BEGIN(lockLocal.memContext)
+        {
+            lockLocal.file[lockIdx].name = strNewFmt("%s/%s-%s" LOCK_FILE_EXT, strZ(lockPath), strZ(stanza), lockTypeName[lockIdx]);
+        }
+        MEM_CONTEXT_END();
+
+        lockLocal.file[lockIdx].fd = lockAcquireFile(lockLocal.file[lockIdx].name, lockTimeout, failOnNoLock);
+
+        if (lockLocal.file[lockIdx].fd == -1)
+        {
+            // Free the lock context and reset lock data
+            memContextFree(lockLocal.memContext);
+            lockLocal = (struct LockLocal){.held = lockTypeNone};
+
+            result = false;
+            break;
+        }
+        // Else write lock data unless we locked an execId match
+        else if (lockLocal.file[lockIdx].fd != LOCK_ON_EXEC_ID)
+            lockWriteData(lockIdx);
+    }
+
+    if (result)
+        lockLocal.held = lockType;
+
+    FUNCTION_LOG_RETURN(BOOL, result);
+}
+
+/**********************************************************************************************************************************/
+// Helper to release a file lock
 static void
-lockReleaseFile(int lockFd, const String *lockFile)
+lockReleaseFile(const int lockFd, const String *const lockFile)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
         FUNCTION_LOG_PARAM(INT, lockFd);
@@ -131,7 +322,7 @@ lockReleaseFile(int lockFd, const String *lockFile)
     FUNCTION_LOG_END();
 
     // Can't release lock if there isn't one
-    ASSERT(lockFd != -1);
+    ASSERT(lockFd >= 0);
 
     // Remove file first and then close it to release the lock.  If we close it first then another process might grab the lock
     // right before the delete which means the file locked by the other process will get deleted.
@@ -141,104 +332,6 @@ lockReleaseFile(int lockFd, const String *lockFile)
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/**********************************************************************************************************************************/
-bool
-lockAcquire(const String *lockPath, const String *stanza, LockType lockType, TimeMSec lockTimeout, bool failOnNoLock)
-{
-    FUNCTION_LOG_BEGIN(logLevelDebug);
-        FUNCTION_LOG_PARAM(STRING, lockPath);
-        FUNCTION_LOG_PARAM(STRING, stanza);
-        FUNCTION_LOG_PARAM(ENUM, lockType);
-        FUNCTION_LOG_PARAM(TIMEMSEC, lockTimeout);
-        FUNCTION_LOG_PARAM(BOOL, failOnNoLock);
-    FUNCTION_LOG_END();
-
-    bool result = false;
-
-    // Don't allow failures when locking more than one file.  This makes cleanup difficult and there are no known use cases.
-    ASSERT(failOnNoLock || lockType != lockTypeAll);
-
-    // Don't allow another lock if one is already held
-    if (lockTypeHeld != lockTypeNone)
-        THROW(AssertError, "lock is already held by this process");
-
-    // Allocate a mem context to hold lock filenames if one does not already exist
-    if (lockMemContext == NULL)
-    {
-        MEM_CONTEXT_BEGIN(memContextTop())
-        {
-            MEM_CONTEXT_NEW_BEGIN("Lock")
-            {
-                lockMemContext = MEM_CONTEXT_NEW();
-            }
-            MEM_CONTEXT_NEW_END();
-        }
-        MEM_CONTEXT_END();
-    }
-
-    // Lock files
-    MEM_CONTEXT_BEGIN(lockMemContext)
-    {
-        LockType lockMin = lockType == lockTypeAll ? lockTypeArchive : lockType;
-        LockType lockMax = lockType == lockTypeAll ? (lockTypeAll - 1) : lockType;
-        bool error = false;
-
-        for (LockType lockIdx = lockMin; lockIdx <= lockMax; lockIdx++)
-        {
-            lockFile[lockIdx] = strNewFmt("%s/%s-%s" LOCK_FILE_EXT, strZ(lockPath), strZ(stanza), lockTypeName[lockIdx]);
-
-            lockFd[lockIdx] = lockAcquireFile(lockFile[lockIdx], lockTimeout, failOnNoLock);
-
-            if (lockFd[lockIdx] == -1)
-            {
-                error = true;
-                break;
-            }
-        }
-
-        if (!error)
-        {
-            lockTypeHeld = lockType;
-            result = true;
-        }
-    }
-    MEM_CONTEXT_END();
-
-    FUNCTION_LOG_RETURN(BOOL, result);
-}
-
-/**********************************************************************************************************************************/
-bool
-lockClear(bool failOnNoLock)
-{
-    FUNCTION_LOG_BEGIN(logLevelTrace);
-        FUNCTION_LOG_PARAM(BOOL, failOnNoLock);
-    FUNCTION_LOG_END();
-
-    bool result = false;
-
-    if (lockTypeHeld == lockTypeNone)
-    {
-        if (failOnNoLock)
-            THROW(AssertError, "no lock is held by this process");
-    }
-    else
-    {
-        // Clear locks
-        LockType lockMin = lockTypeHeld == lockTypeAll ? lockTypeArchive : lockTypeHeld;
-        LockType lockMax = lockTypeHeld == lockTypeAll ? (lockTypeAll - 1) : lockTypeHeld;
-
-        for (LockType lockIdx = lockMin; lockIdx <= lockMax; lockIdx++)
-            strFree(lockFile[lockIdx]);
-
-        lockTypeHeld = lockTypeNone;
-        result = true;
-    }
-
-    FUNCTION_LOG_RETURN(BOOL, result);
-}
-
-/**********************************************************************************************************************************/
 bool
 lockRelease(bool failOnNoLock)
 {
@@ -248,7 +341,7 @@ lockRelease(bool failOnNoLock)
 
     bool result = false;
 
-    if (lockTypeHeld == lockTypeNone)
+    if (lockLocal.held == lockTypeNone)
     {
         if (failOnNoLock)
             THROW(AssertError, "no lock is held by this process");
@@ -256,16 +349,19 @@ lockRelease(bool failOnNoLock)
     else
     {
         // Release locks
-        LockType lockMin = lockTypeHeld == lockTypeAll ? lockTypeArchive : lockTypeHeld;
-        LockType lockMax = lockTypeHeld == lockTypeAll ? (lockTypeAll - 1) : lockTypeHeld;
+        LockType lockMin = lockLocal.held == lockTypeAll ? lockTypeArchive : lockLocal.held;
+        LockType lockMax = lockLocal.held == lockTypeAll ? (lockTypeAll - 1) : lockLocal.held;
 
         for (LockType lockIdx = lockMin; lockIdx <= lockMax; lockIdx++)
         {
-            lockReleaseFile(lockFd[lockIdx], lockFile[lockIdx]);
-            strFree(lockFile[lockIdx]);
+            if (lockLocal.file[lockIdx].fd != LOCK_ON_EXEC_ID)
+                lockReleaseFile(lockLocal.file[lockIdx].fd, lockLocal.file[lockIdx].name);
         }
 
-        lockTypeHeld = lockTypeNone;
+        // Free the lock context and reset lock data
+        memContextFree(lockLocal.memContext);
+        lockLocal = (struct LockLocal){.held = lockTypeNone};
+
         result = true;
     }
 
