@@ -104,11 +104,6 @@ Array and object types:
 #include "common/type/convert.h"
 #include "common/type/pack.h"
 
-/***********************************************************************************************************************************
-Constants
-***********************************************************************************************************************************/
-#define PACK_UINT64_SIZE_MAX                                        10
-
 /***********************************************************************************************************************************
 Map PackType types to the types that will be written into the pack. This hides the details of the type IDs from the user and allows
 the IDs used in the pack to differ from the IDs the user sees.
@@ -495,7 +490,7 @@ pckReadU64Internal(PackRead *this)
     uint8_t byte;
 
     // Convert bytes from varint-128 encoding to a uint64
-    for (unsigned int bufferIdx = 0; bufferIdx < PACK_UINT64_SIZE_MAX; bufferIdx++)
+    for (unsigned int bufferIdx = 0; bufferIdx < CVT_VARINT128_BUFFER_SIZE; bufferIdx++)
     {
         // Get the next encoded byte
         pckReadBuffer(this, 1);
@@ -553,7 +548,9 @@ pckReadTagNext(PackRead *this)
         if (this->tagNextTypeMap == 0xF)
             this->tagNextTypeMap = (unsigned int)pckReadU64Internal(this) + 0xF;
 
-        CHECK(this->tagNextTypeMap < PACK_TYPE_MAP_SIZE && packTypeMapData[this->tagNextTypeMap].type != 0);
+        CHECK(
+            FormatError, this->tagNextTypeMap < PACK_TYPE_MAP_SIZE && packTypeMapData[this->tagNextTypeMap].type != 0,
+            "invalid tag type");
 
         // If the value can contain multiple bits (e.g. integer)
         if (packTypeMapData[this->tagNextTypeMap].valueMultiBit)
@@ -1267,7 +1264,7 @@ pckReadEnd(PackRead *this)
     FUNCTION_TEST_END();
 
     ASSERT(this != NULL);
-    CHECK(this->tagStack.depth == 0);
+    CHECK(FormatError, this->tagStack.depth == 0, "invalid pack end read in container");
 
     // Make sure we are at the end of the pack
     unsigned int id = UINT_MAX - 1;
@@ -1407,7 +1404,7 @@ pckWriteBuffer(PackWrite *this, const Buffer *buffer)
 Pack an unsigned 64-bit integer to base-128 varint encoding
 ***********************************************************************************************************************************/
 static void
-pckWriteU64Internal(PackWrite *this, uint64_t value)
+pckWriteU64Internal(PackWrite *const this, const uint64_t value)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(PACK_WRITE, this);
@@ -1416,27 +1413,13 @@ pckWriteU64Internal(PackWrite *this, uint64_t value)
 
     ASSERT(this != NULL);
 
-    unsigned char buffer[PACK_UINT64_SIZE_MAX];
+    unsigned char buffer[CVT_VARINT128_BUFFER_SIZE];
     size_t size = 0;
 
-    // Convert uint64 to varint-128 encoding. Keep writing out bytes while the remaining value is greater than 7 bits.
-    while (value >= 0x80)
-    {
-        // Encode the lower order 7 bits, adding the continuation bit to indicate there is more data
-        buffer[size] = (unsigned char)value | 0x80;
-
-        // Shift the value to remove bits that have been encoded
-        value >>= 7;
-
-        // Keep track of size so we know how many bytes to write out
-        size++;
-    }
-
-    // Encode the last 7 bits of value
-    buffer[size] = (unsigned char)value;
+    cvtUInt64ToVarInt128(value, buffer, &size, sizeof(buffer));
 
     // Write encoded bytes to the buffer
-    pckWriteBuffer(this, BUF(buffer, size + 1));
+    pckWriteBuffer(this, BUF(buffer, size));
 
     FUNCTION_TEST_RETURN_VOID();
 }
@@ -1463,7 +1446,7 @@ pckWriteTag(PackWrite *this, PackTypeMap typeMap, unsigned int id, uint64_t valu
     }
     // Else the id must be greater than the last one
     else
-        CHECK(id > this->tagStack.top->idLast);
+        CHECK(AssertError, id > this->tagStack.top->idLast, "field id must be greater than last id");
 
     // Clear NULLs now that field id has been calculated
     this->tagStack.top->nullTotal = 0;
