@@ -237,6 +237,37 @@ cfgOptionGroup(ConfigOption optionId)
     FUNCTION_TEST_RETURN(configLocal->option[optionId].group);
 }
 
+/**********************************************************************************************************************************/
+const char *
+cfgOptionGroupName(const ConfigOptionGroup groupId, const unsigned int groupIdx)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(ENUM, groupId);
+        FUNCTION_TEST_PARAM(UINT, groupIdx);
+    FUNCTION_TEST_END();
+
+    ASSERT(configLocal != NULL);
+    ASSERT(groupId < CFG_OPTION_GROUP_TOTAL);
+    ASSERT(groupIdx < configLocal->optionGroup[groupId].indexTotal);
+
+    // Generate names for the group the first time one is requested
+    ConfigOptionGroupData *const group = &configLocal->optionGroup[groupId];
+
+    if (group->indexName == NULL)
+    {
+        MEM_CONTEXT_BEGIN(configLocal->memContext)
+        {
+            group->indexName = memNew(sizeof(String *) * group->indexTotal);
+
+            for (unsigned int groupIdx = 0; groupIdx < group->indexTotal; groupIdx++)
+                group->indexName[groupIdx] = strNewFmt("%s%u", group->name, group->indexMap[groupIdx] + 1);
+        }
+        MEM_CONTEXT_END();
+    }
+
+    FUNCTION_TEST_RETURN(strZ(group->indexName[groupIdx]));
+}
+
 /**********************************************************************************************************************************/
 unsigned int
 cfgOptionGroupId(ConfigOption optionId)
@@ -358,8 +389,9 @@ cfgOptionIdxDefault(ConfigOption optionId)
     ASSERT(
         !configLocal->option[optionId].group || configLocal->optionGroup[configLocal->option[optionId].groupId].indexDefaultExists);
 
-    FUNCTION_TEST_RETURN(
-        configLocal->option[optionId].group ? configLocal->optionGroup[configLocal->option[optionId].groupId].indexDefault : 0);
+    const ConfigOptionData *const option = &configLocal->option[optionId];
+
+    FUNCTION_TEST_RETURN(option->group ? configLocal->optionGroup[option->groupId].indexDefault : 0);
 }
 
 /**********************************************************************************************************************************/
@@ -373,8 +405,9 @@ cfgOptionIdxTotal(ConfigOption optionId)
     ASSERT(configLocal != NULL);
     ASSERT(optionId < CFG_OPTION_TOTAL);
 
-    FUNCTION_TEST_RETURN(
-        configLocal->option[optionId].group ? configLocal->optionGroup[configLocal->option[optionId].groupId].indexTotal : 1);
+    const ConfigOptionData *const option = &configLocal->option[optionId];
+
+    FUNCTION_TEST_RETURN(option->group ? configLocal->optionGroup[option->groupId].indexTotal : 1);
 }
 
 /**********************************************************************************************************************************/
@@ -388,10 +421,12 @@ cfgOptionDefault(ConfigOption optionId)
     ASSERT(configLocal != NULL);
     ASSERT(optionId < CFG_OPTION_TOTAL);
 
-    if (configLocal->option[optionId].defaultValue == NULL)
-        configLocal->option[optionId].defaultValue = cfgParseOptionDefault(cfgCommand(), optionId);
+    ConfigOptionData *const option = &configLocal->option[optionId];
 
-    FUNCTION_TEST_RETURN(configLocal->option[optionId].defaultValue);
+    if (option->defaultValue == NULL)
+        option->defaultValue = cfgParseOptionDefault(cfgCommand(), optionId);
+
+    FUNCTION_TEST_RETURN(option->defaultValue);
 }
 
 void
@@ -413,16 +448,19 @@ cfgOptionDefaultSet(ConfigOption optionId, const Variant *defaultValue)
         defaultValue = varDup(defaultValue);
 
         // Set the default value
-        configLocal->option[optionId].defaultValue = varStr(defaultValue);
+        ConfigOptionData *const option = &configLocal->option[optionId];
+        option->defaultValue = varStr(defaultValue);
 
         // Copy the value to option indexes that are marked as default so the default can be retrieved quickly
         for (unsigned int optionIdx = 0; optionIdx < cfgOptionIdxTotal(optionId); optionIdx++)
         {
-            if (configLocal->option[optionId].index[optionIdx].source == cfgSourceDefault)
+            ConfigOptionValue *const optionValue = &option->index[optionIdx];
+
+            if (optionValue->source == cfgSourceDefault)
             {
-                configLocal->option[optionId].index[optionIdx].set = true;
-                configLocal->option[optionId].index[optionIdx].value.string = varStr(defaultValue);
-                configLocal->option[optionId].index[optionIdx].display = NULL;
+                optionValue->set = true;
+                optionValue->value.string = varStr(defaultValue);
+                optionValue->display = NULL;
             }
         }
     }
@@ -456,6 +494,10 @@ cfgOptionDisplayVar(const Variant *const value, const ConfigOptionType optionTyp
     {
         FUNCTION_TEST_RETURN(strNewDbl((double)varInt64(value) / MSEC_PER_SEC));
     }
+    else if (optionType == cfgOptTypeStringId)
+    {
+        FUNCTION_TEST_RETURN(strIdToStr(varUInt64(value)));
+    }
 
     FUNCTION_TEST_RETURN(varStrForce(value));
 }
@@ -506,97 +548,6 @@ cfgOptionDisplay(const ConfigOption optionId)
     FUNCTION_TEST_RETURN(cfgOptionIdxDisplay(optionId, cfgOptionIdxDefault(optionId)));
 }
 
-/**********************************************************************************************************************************/
-String *
-cfgOptionHostPort(ConfigOption optionId, unsigned int *port)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(ENUM, optionId);
-        FUNCTION_TEST_PARAM_P(UINT, port);
-    FUNCTION_TEST_END();
-
-    FUNCTION_TEST_RETURN(cfgOptionIdxHostPort(optionId, cfgOptionIdxDefault(optionId), port));
-}
-
-String *
-cfgOptionIdxHostPort(ConfigOption optionId, unsigned int optionIdx, unsigned int *port)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(ENUM, optionId);
-        FUNCTION_TEST_PARAM(UINT, optionIdx);
-        FUNCTION_TEST_PARAM_P(UINT, port);
-    FUNCTION_TEST_END();
-
-    ASSERT(optionId < CFG_OPTION_TOTAL);
-    ASSERT(configLocal != NULL);
-    ASSERT(
-        (!configLocal->option[optionId].group && optionIdx == 0) ||
-        (configLocal->option[optionId].group && optionIdx <
-            configLocal->optionGroup[configLocal->option[optionId].groupId].indexTotal));
-    ASSERT(port != NULL);
-
-    String *result = NULL;
-
-    // Proceed if option is valid and has a value
-    if (cfgOptionIdxTest(optionId, optionIdx))
-    {
-        MEM_CONTEXT_TEMP_BEGIN()
-        {
-            const String *host = cfgOptionIdxStr(optionId, optionIdx);
-
-            // If the host contains a colon then it has a port appended
-            if (strChr(host, ':') != -1)
-            {
-                const StringList *hostPart = strLstNewSplitZ(host, ":");
-
-                // More than one colon is invalid
-                if (strLstSize(hostPart) > 2)
-                {
-                    THROW_FMT(
-                        OptionInvalidError,
-                        "'%s' is not valid for option '%s'"
-                            "\nHINT: is more than one port specified?",
-                        strZ(host), cfgOptionIdxName(optionId, optionIdx));
-                }
-
-                // Set the host
-                MEM_CONTEXT_PRIOR_BEGIN()
-                {
-                    result = strDup(strLstGet(hostPart, 0));
-                }
-                MEM_CONTEXT_PRIOR_END();
-
-                // Set the port and error if it is not a positive integer
-                TRY_BEGIN()
-                {
-                    *port = cvtZToUInt(strZ(strLstGet(hostPart, 1)));
-                }
-                CATCH(FormatError)
-                {
-                    THROW_FMT(
-                        OptionInvalidError,
-                        "'%s' is not valid for option '%s'"
-                            "\nHINT: port is not a positive integer.",
-                        strZ(host), cfgOptionIdxName(optionId, optionIdx));
-                }
-                TRY_END();
-            }
-            // Else there is no port and just copy the host
-            else
-            {
-                MEM_CONTEXT_PRIOR_BEGIN()
-                {
-                    result = strDup(host);
-                }
-                MEM_CONTEXT_PRIOR_END();
-            }
-        }
-        MEM_CONTEXT_TEMP_END();
-    }
-
-    FUNCTION_TEST_RETURN(result);
-}
-
 /***********************************************************************************************************************************
 Get option name by id
 ***********************************************************************************************************************************/
@@ -627,19 +578,34 @@ cfgOptionIdxName(ConfigOption optionId, unsigned int optionIdx)
         (configLocal->option[optionId].group && optionIdx <
             configLocal->optionGroup[configLocal->option[optionId].groupId].indexTotal));
 
-    if (configLocal->option[optionId].group)
-    {
-        // This is somewhat less than ideal since memory is being allocated with each call, rather than caching prior results. In
-        // practice the number of allocations should be quite small so we'll ignore this for now.
-        String *name = strNewFmt(
-            "%s%u%s", configLocal->optionGroup[configLocal->option[optionId].groupId].name,
-            configLocal->optionGroup[configLocal->option[optionId].groupId].indexMap[optionIdx] + 1,
-            configLocal->option[optionId].name + strlen(configLocal->optionGroup[configLocal->option[optionId].groupId].name));
+    // If an indexed option
+    ConfigOptionData *const option = &configLocal->option[optionId];
 
-        FUNCTION_TEST_RETURN(strZ(name));
+    if (option->group)
+    {
+        const ConfigOptionGroupData *const group = &configLocal->optionGroup[option->groupId];
+
+        // Generate indexed names for the option the first time one is requested
+        if (option->indexName == NULL)
+        {
+            MEM_CONTEXT_BEGIN(configLocal->memContext)
+            {
+                option->indexName = memNew(sizeof(String *) * group->indexTotal);
+
+                for (unsigned int optionIdx = 0; optionIdx < group->indexTotal; optionIdx++)
+                {
+                    option->indexName[optionIdx] = strNewFmt(
+                        "%s%u%s", group->name, group->indexMap[optionIdx] + 1, option->name + strlen(group->name));
+                }
+            }
+            MEM_CONTEXT_END();
+        }
+
+        FUNCTION_TEST_RETURN(strZ(option->indexName[optionIdx]));
     }
 
-    FUNCTION_TEST_RETURN(configLocal->option[optionId].name);
+    // Else not indexed
+    FUNCTION_TEST_RETURN(option->name);
 }
 
 /**********************************************************************************************************************************/
@@ -725,15 +691,16 @@ cfgOptionIdxInternal(
         THROW_FMT(AssertError, "option '%s' is not valid for the current command", cfgOptionIdxName(optionId, optionIdx));
 
     // If the option is not NULL then check it is the requested type
-    const ConfigOptionValue *const result = &configLocal->option[optionId].index[optionIdx];
+    ConfigOptionData *const option = &configLocal->option[optionId];
+    ConfigOptionValue *const result = &option->index[optionIdx];
 
     if (result->set)
     {
-        if (configLocal->option[optionId].dataType != typeRequested)
+        if (option->dataType != typeRequested)
         {
             THROW_FMT(
                 AssertError, "option '%s' is type %u but %u was requested", cfgOptionIdxName(optionId, optionIdx),
-                configLocal->option[optionId].dataType, typeRequested);
+                option->dataType, typeRequested);
         }
     }
     // Else check the option is allowed to be NULL
@@ -757,28 +724,35 @@ cfgOptionIdxVar(const ConfigOption optionId, const unsigned int optionIdx)
         (configLocal->option[optionId].group && optionIdx <
             configLocal->optionGroup[configLocal->option[optionId].groupId].indexTotal));
 
-    if (configLocal->option[optionId].index[optionIdx].set)
+    const ConfigOptionData *const option = &configLocal->option[optionId];
+
+    if (option->index[optionIdx].set)
     {
-        switch (configLocal->option[optionId].dataType)
+        const ConfigOptionValueType *const optionValueType = &option->index[optionIdx].value;
+
+        switch (option->dataType)
         {
             case cfgOptDataTypeBoolean:
-                FUNCTION_TEST_RETURN(varNewBool(configLocal->option[optionId].index[optionIdx].value.boolean));
+                FUNCTION_TEST_RETURN(varNewBool(optionValueType->boolean));
 
             case cfgOptDataTypeHash:
-                FUNCTION_TEST_RETURN(varNewKv(kvDup(configLocal->option[optionId].index[optionIdx].value.keyValue)));
+                FUNCTION_TEST_RETURN(varNewKv(kvDup(optionValueType->keyValue)));
 
             case cfgOptDataTypeInteger:
-                FUNCTION_TEST_RETURN(varNewInt64(configLocal->option[optionId].index[optionIdx].value.integer));
+                FUNCTION_TEST_RETURN(varNewInt64(optionValueType->integer));
 
             case cfgOptDataTypeList:
-                FUNCTION_TEST_RETURN(varNewVarLst(configLocal->option[optionId].index[optionIdx].value.list));
+                FUNCTION_TEST_RETURN(varNewVarLst(optionValueType->list));
+
+            case cfgOptDataTypeStringId:
+                FUNCTION_TEST_RETURN(varNewUInt64(optionValueType->stringId));
 
             default:
-                ASSERT(configLocal->option[optionId].dataType == cfgOptDataTypeString);
+                ASSERT(option->dataType == cfgOptDataTypeString);
                 break;
         }
 
-        FUNCTION_TEST_RETURN(varNewStr(configLocal->option[optionId].index[optionIdx].value.string));
+        FUNCTION_TEST_RETURN(varNewStr(optionValueType->string));
     }
 
     FUNCTION_TEST_RETURN(NULL);
@@ -916,34 +890,6 @@ cfgOptionIdxStrNull(ConfigOption optionId, unsigned int optionIdx)
     FUNCTION_LOG_RETURN_CONST(STRING, cfgOptionIdxInternal(optionId, optionIdx, cfgOptDataTypeString, true)->value.string);
 }
 
-// Helper to convert option String values to StringIds. Some options need 6-bit encoding while most work fine with 5-bit encoding.
-// At some point the config parser will work with StringIds directly and this code can be removed, but for now it protects the
-// callers from this logic and hopefully means no changes to the callers when the parser is updated.
-static StringId
-cfgOptionStrIdInternal(
-    const ConfigOption optionId, const unsigned int optionIdx)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(ENUM, optionId);
-        FUNCTION_TEST_PARAM(UINT, optionIdx);
-    FUNCTION_TEST_END();
-
-    const String *const value = cfgOptionIdxInternal(optionId, optionIdx, cfgOptDataTypeString, false)->value.string;
-    StringId result = 0;
-
-    TRY_BEGIN()
-    {
-        result = strIdFromStr(stringIdBit5, value);
-    }
-    CATCH_ANY()
-    {
-        result = strIdFromStr(stringIdBit6, value);
-    }
-    TRY_END();
-
-    FUNCTION_TEST_RETURN(result);
-}
-
 StringId
 cfgOptionIdxStrId(ConfigOption optionId, unsigned int optionIdx)
 {
@@ -952,7 +898,7 @@ cfgOptionIdxStrId(ConfigOption optionId, unsigned int optionIdx)
         FUNCTION_LOG_PARAM(UINT, optionIdx);
     FUNCTION_LOG_END();
 
-    FUNCTION_LOG_RETURN(STRING_ID, cfgOptionStrIdInternal(optionId, optionIdx));
+    FUNCTION_LOG_RETURN(STRING_ID, cfgOptionIdxInternal(optionId, optionIdx, cfgOptDataTypeStringId, false)->value.stringId);
 }
 
 /**********************************************************************************************************************************/
@@ -988,19 +934,23 @@ cfgOptionIdxSet(ConfigOption optionId, unsigned int optionIdx, ConfigSource sour
             configLocal->optionGroup[configLocal->option[optionId].groupId].indexTotal));
 
     // Set the source
-    configLocal->option[optionId].index[optionIdx].source = source;
+    ConfigOptionData *const option = &configLocal->option[optionId];
+    ConfigOptionValue *const optionValue = &option->index[optionIdx];
+    optionValue->source = source;
 
     // Only set value if it is not null
+    ConfigOptionValueType *const optionValueType = &optionValue->value;
+
     if (value != NULL)
     {
-        switch (configLocal->option[optionId].dataType)
+        switch (option->dataType)
         {
             case cfgOptDataTypeBoolean:
-                configLocal->option[optionId].index[optionIdx].value.boolean = varBool(value);
+                optionValueType->boolean = varBool(value);
                 break;
 
             case cfgOptDataTypeInteger:
-                configLocal->option[optionId].index[optionIdx].value.integer = varInt64(value);
+                optionValueType->integer = varInt64(value);
                 break;
 
             case cfgOptDataTypeString:
@@ -1009,7 +959,7 @@ cfgOptionIdxSet(ConfigOption optionId, unsigned int optionIdx, ConfigSource sour
                 {
                     MEM_CONTEXT_BEGIN(configLocal->memContext)
                     {
-                        configLocal->option[optionId].index[optionIdx].value.string = strDup(varStr(value));
+                        optionValueType->string = strDup(varStr(value));
                     }
                     MEM_CONTEXT_END();
                 }
@@ -1022,22 +972,33 @@ cfgOptionIdxSet(ConfigOption optionId, unsigned int optionIdx, ConfigSource sour
                 break;
             }
 
+            case cfgOptDataTypeStringId:
+            {
+                if (varType(value) == varTypeUInt64)
+                    optionValueType->stringId = varUInt64(value);
+                else
+                    optionValueType->stringId = strIdFromStr(varStr(value));
+
+                break;
+            }
+
             default:
-                THROW_FMT(AssertError, "set not available for option data type %u", configLocal->option[optionId].dataType);
+                THROW_FMT(AssertError, "set not available for option data type %u", option->dataType);
         }
 
-        configLocal->option[optionId].index[optionIdx].set = true;
+        optionValue->set = true;
     }
     else
     {
-        configLocal->option[optionId].index[optionIdx].set = false;
+        optionValue->set = false;
 
         // Pointer values need to be set to null since they can be accessed when the option is not set, e.g. cfgOptionStrNull().
-        configLocal->option[optionId].index[optionIdx].value.string = NULL;
+        // Setting string to NULL suffices to set the other pointers in the union to NULL.
+        optionValueType->string = NULL;
     }
 
     // Clear the display value, which will be generated when needed
-    configLocal->option[optionId].index[optionIdx].display = NULL;
+    optionValue->display = NULL;
 
     FUNCTION_TEST_RETURN_VOID();
 }
