@@ -40,15 +40,13 @@ cfgLoadLogSetting(void)
     unsigned int logProcessMax = 1;
 
     if (cfgOptionValid(cfgOptLogLevelConsole))
-        logLevelConsole = logLevelEnum(strZ(cfgOptionStr(cfgOptLogLevelConsole)));
+        logLevelConsole = logLevelEnum(cfgOptionStrId(cfgOptLogLevelConsole));
 
     if (cfgOptionValid(cfgOptLogLevelStderr))
-    {
-        logLevelStdErr = logLevelEnum(strZ(cfgOptionStr(cfgOptLogLevelStderr)));
-    }
+        logLevelStdErr = logLevelEnum(cfgOptionStrId(cfgOptLogLevelStderr));
 
     if (cfgOptionValid(cfgOptLogLevelFile))
-        logLevelFile = logLevelEnum(strZ(cfgOptionStr(cfgOptLogLevelFile)));
+        logLevelFile = logLevelEnum(cfgOptionStrId(cfgOptLogLevelFile));
 
     if (cfgOptionValid(cfgOptLogTimestamp))
         logTimestamp = cfgOptionBool(cfgOptLogTimestamp);
@@ -95,13 +93,13 @@ cfgLoadUpdateOption(void)
                 for (unsigned int repoIdx = 0; repoIdx < cfgOptionGroupIdxTotal(cfgOptGrpRepo); repoIdx++)
                 {
                     if (optionIdx != repoIdx && !(cfgOptionIdxTest(cfgOptRepoHost, repoIdx)) &&
-                        strEq(cfgOptionIdxStr(cfgOptRepoType, optionIdx), cfgOptionIdxStr(cfgOptRepoType, repoIdx)) &&
+                        cfgOptionIdxStrId(cfgOptRepoType, optionIdx) == cfgOptionIdxStrId(cfgOptRepoType, repoIdx) &&
                         strEq(cfgOptionIdxStr(cfgOptRepoPath, optionIdx), cfgOptionIdxStr(cfgOptRepoPath, repoIdx)))
                     {
                         THROW_FMT(
                             OptionInvalidValueError,
-                            "local repo%u and repo%u paths are both '%s' but must be different",
-                            cfgOptionGroupIdxToKey(cfgOptGrpRepo, optionIdx), cfgOptionGroupIdxToKey(cfgOptGrpRepo, repoIdx),
+                            "local %s and %s paths are both '%s' but must be different",
+                            cfgOptionGroupName(cfgOptGrpRepo, optionIdx), cfgOptionGroupName(cfgOptGrpRepo, repoIdx),
                             strZ(cfgOptionIdxDisplay(cfgOptRepoPath, repoIdx)));
                     }
                 }
@@ -109,6 +107,10 @@ cfgLoadUpdateOption(void)
         }
     }
 
+    // Set default for cmd
+    if (cfgOptionValid(cfgOptCmd))
+        cfgOptionDefaultSet(cfgOptCmd, VARSTR(cfgExe()));
+
     // Set default for repo-host-cmd
     if (cfgOptionValid(cfgOptRepoHostCmd))
         cfgOptionDefaultSet(cfgOptRepoHostCmd, VARSTR(cfgExe()));
@@ -146,7 +148,7 @@ cfgLoadUpdateOption(void)
                 OptionInvalidValueError,
                 "'%s' is not valid for '" CFGOPT_PROTOCOL_TIMEOUT "' option\nHINT '" CFGOPT_PROTOCOL_TIMEOUT "' option (%s)"
                     " should be greater than '" CFGOPT_DB_TIMEOUT "' option (%s).",
-                strZ(cfgOptionDisplay(cfgOptProtocolTimeout)),  strZ(cfgOptionDisplay(cfgOptProtocolTimeout)),
+                strZ(cfgOptionDisplay(cfgOptProtocolTimeout)), strZ(cfgOptionDisplay(cfgOptProtocolTimeout)),
                 strZ(cfgOptionDisplay(cfgOptDbTimeout)));
         }
     }
@@ -329,7 +331,7 @@ cfgLoadUpdateOption(void)
             // Set compress-type to none. Eventually the compress option will be deprecated and removed so this reduces code churn
             // when that happens.
             if (!cfgOptionBool(cfgOptCompress) && cfgOptionSource(cfgOptCompressType) == cfgSourceDefault)
-                cfgOptionSet(cfgOptCompressType, cfgSourceParam, VARSTR(compressTypeStr(compressTypeNone)));
+                cfgOptionSet(cfgOptCompressType, cfgSourceParam, VARUINT64(CFGOPTVAL_COMPRESS_TYPE_NONE));
         }
 
         // Now invalidate compress so it can't be used and won't be passed to child processes
@@ -339,14 +341,14 @@ cfgLoadUpdateOption(void)
 
     // Check that selected compress type has been compiled into this binary
     if (cfgOptionValid(cfgOptCompressType))
-        compressTypePresent(compressTypeEnum(cfgOptionStr(cfgOptCompressType)));
+        compressTypePresent(compressTypeEnum(cfgOptionStrId(cfgOptCompressType)));
 
     // Update compress-level default based on the compression type
     if (cfgOptionValid(cfgOptCompressLevel) && cfgOptionSource(cfgOptCompressLevel) == cfgSourceDefault)
     {
         cfgOptionSet(
             cfgOptCompressLevel, cfgSourceDefault,
-            VARINT64(compressLevelDefault(compressTypeEnum(cfgOptionStr(cfgOptCompressType)))));
+            VARINT64(compressLevelDefault(compressTypeEnum(cfgOptionStrId(cfgOptCompressType)))));
     }
 
     FUNCTION_LOG_RETURN_VOID();
@@ -387,7 +389,7 @@ cfgLoadLogFile(void)
 
             // Attempt to open log file
             if (!logFileSet(strZ(logFile)))
-                cfgOptionSet(cfgOptLogLevelFile, cfgSourceParam, varNewStrZ("off"));
+                cfgOptionSet(cfgOptLogLevelFile, cfgSourceParam, VARUINT64(CFGOPTVAL_LOG_LEVEL_CONSOLE_OFF));
         }
         MEM_CONTEXT_TEMP_END();
     }
