@@ -7,6 +7,8 @@ Database Client
 #include "common/log.h"
 #include "common/type/json.h"
 #include "common/wait.h"
+#include "config/config.h"
+#include "config/protocol.h"
 #include "db/db.h"
 #include "db/protocol.h"
 #include "postgres/interface.h"
@@ -18,6 +20,7 @@ Database Client
 Constants
 ***********************************************************************************************************************************/
 #define PG_BACKUP_ADVISORY_LOCK                                     "12340078987004321"
+#define DB_PING_SEC                                                 30
 
 /***********************************************************************************************************************************
 Object type
@@ -28,7 +31,9 @@ struct Db
     PgClient *client;                                               // Local PostgreSQL client
     ProtocolClient *remoteClient;                                   // Protocol client for remote db queries
     unsigned int remoteIdx;                                         // Index provided by the remote on open for subsequent calls
+    const Storage *storage;                                         // PostgreSQL storage
     const String *applicationName;                                  // Used to identify this connection in PostgreSQL
+    time_t pingTimeLast;                                            // Last time cluster was pinged
 };
 
 /***********************************************************************************************************************************
@@ -55,15 +60,17 @@ dbFreeResource(THIS_VOID)
 
 /**********************************************************************************************************************************/
 Db *
-dbNew(PgClient *client, ProtocolClient *remoteClient, const String *applicationName)
+dbNew(PgClient *client, ProtocolClient *remoteClient, const Storage *const storage, const String *applicationName)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(PG_CLIENT, client);
         FUNCTION_LOG_PARAM(PROTOCOL_CLIENT, remoteClient);
+        FUNCTION_LOG_PARAM(STORAGE, storage);
         FUNCTION_LOG_PARAM(STRING, applicationName);
     FUNCTION_LOG_END();
 
     ASSERT((client != NULL && remoteClient == NULL) || (client == NULL && remoteClient != NULL));
+    ASSERT(storage != NULL);
     ASSERT(applicationName != NULL);
 
     Db *this = NULL;
@@ -79,6 +86,7 @@ dbNew(PgClient *client, ProtocolClient *remoteClient, const String *applicationN
                 .memContext = memContextCurrent(),
             },
             .remoteClient = remoteClient,
+            .storage = storage,
             .applicationName = strDup(applicationName),
         };
 
@@ -137,7 +145,7 @@ dbExec(Db *this, const String *command)
     ASSERT(this != NULL);
     ASSERT(command != NULL);
 
-    CHECK(dbQuery(this, command) == NULL);
+    CHECK(AssertError, dbQuery(this, command) == NULL, "exec returned data");
 
     FUNCTION_LOG_RETURN_VOID();
 }
@@ -158,8 +166,8 @@ dbQueryColumn(Db *this, const String *query)
 
     VariantList *result = dbQuery(this, query);
 
-    CHECK(varLstSize(result) == 1);
-    CHECK(varLstSize(varVarLst(varLstGet(result, 0))) == 1);
+    CHECK(AssertError, varLstSize(result) == 1, "query must return one column");
+    CHECK(AssertError, varLstSize(varVarLst(varLstGet(result, 0))) == 1, "query must return one row");
 
     FUNCTION_LOG_RETURN(VARIANT, varLstGet(varVarLst(varLstGet(result, 0)), 0));
 }
@@ -180,11 +188,31 @@ dbQueryRow(Db *this, const String *query)
 
     VariantList *result = dbQuery(this, query);
 
-    CHECK(varLstSize(result) == 1);
+    CHECK(AssertError, varLstSize(result) == 1, "query must return one row");
 
     FUNCTION_LOG_RETURN(VARIANT_LIST, varVarLst(varLstGet(result, 0)));
 }
 
+/***********************************************************************************************************************************
+Is the cluster in recovery?
+***********************************************************************************************************************************/
+static bool
+dbIsInRecovery(Db *const this)
+{
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(DB, this);
+    FUNCTION_LOG_END();
+
+    ASSERT(this != NULL);
+
+    bool result = false;
+
+    if (dbPgVersion(this) >= PG_VERSION_HOT_STANDBY)
+        result = varBool(dbQueryColumn(this, STRDEF("select pg_catalog.pg_is_in_recovery()")));
+
+    FUNCTION_LOG_RETURN(BOOL, result);
+}
+
 /**********************************************************************************************************************************/
 void
 dbOpen(Db *this)
@@ -205,9 +233,16 @@ dbOpen(Db *this)
 
             // Set a callback to notify the remote when a connection is closed
             memContextCallbackSet(this->pub.memContext, dbFreeResource, this);
+
+            // Get db-timeout from the remote since it might be different than the local value
+            this->pub.dbTimeout = varUInt64Force(
+                varLstGet(configOptionRemote(this->remoteClient, varLstAdd(varLstNew(), varNewStrZ(CFGOPT_DB_TIMEOUT))), 0));
         }
         else
+        {
             pgClientOpen(this->client);
+            this->pub.dbTimeout = cfgOptionUInt64(cfgOptDbTimeout);
+        }
 
         // Set search_path to prevent overrides of the functions we expect to call.  All queries should also be schema-qualified,
         // but this is an extra level protection.
@@ -223,7 +258,8 @@ dbOpen(Db *this)
                 "select (select setting from pg_catalog.pg_settings where name = 'server_version_num')::int4,"
                 " (select setting from pg_catalog.pg_settings where name = 'data_directory')::text,"
                 " (select setting from pg_catalog.pg_settings where name = 'archive_mode')::text,"
-                " (select setting from pg_catalog.pg_settings where name = 'archive_command')::text"));
+                " (select setting from pg_catalog.pg_settings where name = 'archive_command')::text,"
+                " (select setting from pg_catalog.pg_settings where name = 'checkpoint_timeout')::int4"));
 
         // Check that none of the return values are null, which indicates the user cannot select some rows in pg_settings
         for (unsigned int columnIdx = 0; columnIdx < varLstSize(row); columnIdx++)
@@ -244,22 +280,29 @@ dbOpen(Db *this)
 
         // Store the data directory that PostgreSQL is running in, the archive mode, and archive command. These can be compared to
         // the configured pgBackRest directory, and archive settings checked for validity, when validating the configuration.
+        // Also store the checkpoint timeout to warn in case a backup is requested without using the start-fast option.
         MEM_CONTEXT_BEGIN(this->pub.memContext)
         {
             this->pub.pgDataPath = strDup(varStr(varLstGet(row, 1)));
             this->pub.archiveMode = strDup(varStr(varLstGet(row, 2)));
             this->pub.archiveCommand = strDup(varStr(varLstGet(row, 3)));
+            this->pub.checkpointTimeout = (TimeMSec)(varUIntForce(varLstGet(row, 4))) * MSEC_PER_SEC;
         }
         MEM_CONTEXT_END();
 
         // Set application name to help identify the backup session
-        if (dbPgVersion(this) >= PG_VERSION_APPLICATION_NAME)
-            dbExec(this, strNewFmt("set application_name = '%s'", strZ(this->applicationName)));
+        dbExec(this, strNewFmt("set application_name = '%s'", strZ(this->applicationName)));
 
         // There is no need to have parallelism enabled in a backup session. In particular, 9.6 marks pg_stop_backup() as
         // parallel-safe but an error will be thrown if pg_stop_backup() is run in a worker.
         if (dbPgVersion(this) >= PG_VERSION_PARALLEL_QUERY)
             dbExec(this, STRDEF("set max_parallel_workers_per_gather = 0"));
+
+        // Is the cluster a standby?
+        this->pub.standby = dbIsInRecovery(this);
+
+        // Get control file
+        this->pub.pgControl = pgControlFromFile(this->storage);
     }
     MEM_CONTEXT_TEMP_END();
 
@@ -290,7 +333,7 @@ dbBackupStartQuery(unsigned int pgVersion, bool startFast)
         strCatFmt(result, ", " TRUE_Z);
     }
     // Else start backup at the next scheduled checkpoint
-    else if (pgVersion >= PG_VERSION_84)
+    else
         strCatFmt(result, ", " FALSE_Z);
 
     // Use non-exclusive backup mode when available
@@ -304,12 +347,13 @@ dbBackupStartQuery(unsigned int pgVersion, bool startFast)
 }
 
 DbBackupStartResult
-dbBackupStart(Db *this, bool startFast, bool stopAuto)
+dbBackupStart(Db *const this, const bool startFast, const bool stopAuto, const bool archiveCheck)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(DB, this);
         FUNCTION_LOG_PARAM(BOOL, startFast);
         FUNCTION_LOG_PARAM(BOOL, stopAuto);
+        FUNCTION_LOG_PARAM(BOOL, archiveCheck);
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
@@ -331,8 +375,7 @@ dbBackupStart(Db *this, bool startFast, bool stopAuto)
         // If stop-auto is enabled check for a running backup
         if (stopAuto)
         {
-            // Feature is not supported in PostgreSQL < 9.3
-            CHECK(dbPgVersion(this) >= PG_VERSION_93);
+            CHECK(AssertError, dbPgVersion(this) >= PG_VERSION_93, "feature not supported in PostgreSQL < " PG_VERSION_93_STR);
 
             // Feature is not needed for PostgreSQL >= 9.6 since backups are run in non-exclusive mode
             if (dbPgVersion(this) < PG_VERSION_96)
@@ -348,14 +391,74 @@ dbBackupStart(Db *this, bool startFast, bool stopAuto)
             }
         }
 
+        // When the start-fast option is disabled and db-timeout is smaller than checkpoint_timeout, the command may timeout
+        // before the backup actually starts
+        if (!startFast && dbDbTimeout(this) <= dbCheckpointTimeout(this))
+        {
+            LOG_WARN_FMT(
+                CFGOPT_START_FAST " is disabled and " CFGOPT_DB_TIMEOUT " (%" PRIu64 "s) is smaller than the " PG_NAME
+                    " checkpoint_timeout (%" PRIu64 "s) - timeout may occur before the backup starts",
+                dbDbTimeout(this) / MSEC_PER_SEC, dbCheckpointTimeout(this) / MSEC_PER_SEC);
+        }
+
+        // If archive check then get the current WAL segment
+        const String *walSegmentCheck = NULL;
+
+        if (archiveCheck)
+        {
+            walSegmentCheck = varStr(
+                dbQueryColumn(
+                    this,
+                    strNewFmt(
+                        "select pg_catalog.pg_%sfile_name(pg_catalog.pg_current_%s_insert_%s())::text",
+                        strZ(pgWalName(dbPgVersion(this))), strZ(pgWalName(dbPgVersion(this))),
+                        strZ(pgLsnName(dbPgVersion(this))))));
+        }
+
         // Start backup
         VariantList *row = dbQueryRow(this, dbBackupStartQuery(dbPgVersion(this), startFast));
 
+        // Make sure the backup start checkpoint was written to pg_control. This helps ensure that we have a consistent view of the
+        // storage with PostgreSQL.
+        const PgControl pgControl = pgControlFromFile(this->storage);
+        const String *const lsnStart = varStr(varLstGet(row, 0));
+
+        if (pgControl.checkpoint < pgLsnFromStr(lsnStart))
+        {
+            THROW_FMT(
+                DbMismatchError, "current checkpoint '%s' is less than backup start '%s'", strZ(pgLsnToStr(pgControl.checkpoint)),
+                strZ(lsnStart));
+        }
+
+        // If archive check then make sure WAL segment was switched on start backup
+        const String *const walSegmentName = varStr(varLstGet(row, 1));
+
+        if (archiveCheck && strEq(walSegmentCheck, walSegmentName))
+        {
+            // If the version supports restore points then force a WAL switch
+            if (dbPgVersion(this) >= PG_VERSION_RESTORE_POINT)
+            {
+                dbWalSwitch(this);
+            }
+            // Else disable the check. All WAL will still be checked at the end of the backup.
+            else
+                walSegmentCheck = NULL;
+        }
+
+        // Check that the WAL timeline matches what is in pg_control
+        if (pgTimelineFromWalSegment(walSegmentName) != dbPgControl(this).timeline)
+        {
+            THROW_FMT(
+                DbMismatchError, "WAL timeline %u does not match " PG_FILE_PGCONTROL " timeline %u",
+                pgTimelineFromWalSegment(walSegmentName), dbPgControl(this).timeline);
+        }
+
         // Return results
         MEM_CONTEXT_PRIOR_BEGIN()
         {
-            result.lsn = strDup(varStr(varLstGet(row, 0)));
-            result.walSegmentName = strDup(varStr(varLstGet(row, 1)));
+            result.lsn = strDup(lsnStart);
+            result.walSegmentName = strDup(walSegmentName);
+            result.walSegmentCheck = strDup(walSegmentCheck);
         }
         MEM_CONTEXT_PRIOR_END();
     }
@@ -363,6 +466,7 @@ dbBackupStart(Db *this, bool startFast, bool stopAuto)
 
     FUNCTION_LOG_RETURN_STRUCT(result);
 }
+
 /**********************************************************************************************************************************/
 // Helper to build stop backup query
 static String *
@@ -453,26 +557,6 @@ dbBackupStop(Db *this)
     FUNCTION_LOG_RETURN_STRUCT(result);
 }
 
-/**********************************************************************************************************************************/
-bool
-dbIsStandby(Db *this)
-{
-    FUNCTION_LOG_BEGIN(logLevelDebug);
-        FUNCTION_LOG_PARAM(DB, this);
-    FUNCTION_LOG_END();
-
-    ASSERT(this != NULL);
-
-    bool result = false;
-
-    if (dbPgVersion(this) >= PG_VERSION_HOT_STANDBY)
-    {
-        result = varBool(dbQueryColumn(this, STRDEF("select pg_catalog.pg_is_in_recovery()")));
-    }
-
-    FUNCTION_LOG_RETURN(BOOL, result);
-}
-
 /**********************************************************************************************************************************/
 VariantList *
 dbList(Db *this)
@@ -487,20 +571,35 @@ dbList(Db *this)
 
 /**********************************************************************************************************************************/
 void
-dbReplayWait(Db *this, const String *targetLsn, TimeMSec timeout)
+dbReplayWait(Db *const this, const String *const targetLsn, const uint32_t targetTimeline, const TimeMSec timeout)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(DB, this);
         FUNCTION_LOG_PARAM(STRING, targetLsn);
+        FUNCTION_LOG_PARAM(UINT, targetTimeline);
         FUNCTION_LOG_PARAM(TIME_MSEC, timeout);
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
     ASSERT(targetLsn != NULL);
+    ASSERT(targetTimeline != 0);
     ASSERT(timeout > 0);
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
+        // Check that the timeline matches the primary
+        if (dbPgControl(this).timeline != targetTimeline)
+            THROW_FMT(DbMismatchError, "standby is on timeline %u but expected %u", dbPgControl(this).timeline, targetTimeline);
+
+        // Standby checkpoint before the backup started must be <= the target LSN. If not, it indicates that the standby was ahead
+        // of the primary and cannot be following it.
+        if (dbPgControl(this).checkpoint > pgLsnFromStr(targetLsn))
+        {
+            THROW_FMT(
+                DbMismatchError, "standby checkpoint '%s' is ahead of target '%s'", strZ(pgLsnToStr(dbPgControl(this).checkpoint)),
+                strZ(targetLsn));
+        }
+
         // Loop until lsn has been reached or timeout
         Wait *wait = waitNew(timeout);
         bool targetReached = false;
@@ -611,6 +710,48 @@ dbReplayWait(Db *this, const String *targetLsn, TimeMSec timeout)
     FUNCTION_LOG_RETURN_VOID();
 }
 
+/**********************************************************************************************************************************/
+void
+dbPing(Db *const this, const bool force)
+{
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(DB, this);
+        FUNCTION_LOG_PARAM(BOOL, force);
+    FUNCTION_LOG_END();
+
+    ASSERT(this != NULL);
+
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        // Ping if forced or interval has elapsed
+        time_t timeNow = time(NULL);
+
+        if (force || timeNow - this->pingTimeLast > DB_PING_SEC)
+        {
+            // Make sure recovery state has not changed
+            if (dbIsInRecovery(this) != dbIsStandby(this))
+            {
+                // If this is the standby then it must have been promoted
+                if (dbIsStandby(this))
+                {
+                    THROW(
+                        DbMismatchError,
+                        "standby is no longer in recovery\n"
+                        "HINT: was the standby promoted during the backup?");
+                }
+                // Else if a primary then something has gone seriously wrong
+                else
+                    THROW(AssertError, "primary has switched to recovery");
+            }
+
+            this->pingTimeLast = timeNow;
+        }
+    }
+    MEM_CONTEXT_TEMP_END();
+
+    FUNCTION_LOG_RETURN_VOID();
+}
+
 /**********************************************************************************************************************************/
 VariantList *
 dbTablespaceList(Db *this)
