@@ -38,6 +38,8 @@ VARIANT_STRDEF_STATIC(INFO_BACKUP_KEY_BACKUP_INFO_REPO_SIZE_VAR,    "backup-info
 VARIANT_STRDEF_STATIC(INFO_BACKUP_KEY_BACKUP_INFO_REPO_SIZE_DELTA_VAR, "backup-info-repo-size-delta");
 VARIANT_STRDEF_STATIC(INFO_BACKUP_KEY_BACKUP_INFO_SIZE_VAR,         "backup-info-size");
 VARIANT_STRDEF_STATIC(INFO_BACKUP_KEY_BACKUP_INFO_SIZE_DELTA_VAR,   "backup-info-size-delta");
+VARIANT_STRDEF_STATIC(INFO_BACKUP_KEY_BACKUP_LSN_START_VAR,         "backup-lsn-start");
+VARIANT_STRDEF_STATIC(INFO_BACKUP_KEY_BACKUP_LSN_STOP_VAR,          "backup-lsn-stop");
 VARIANT_STRDEF_STATIC(INFO_BACKUP_KEY_BACKUP_PRIOR_VAR,             "backup-prior");
 VARIANT_STRDEF_STATIC(INFO_BACKUP_KEY_BACKUP_REFERENCE_VAR,         "backup-reference");
 VARIANT_STRDEF_STATIC(INFO_BACKUP_KEY_BACKUP_TIMESTAMP_START_VAR,   "backup-timestamp-start");
@@ -78,7 +80,7 @@ infoBackupNewInternal(void)
         .pub =
         {
             .memContext = memContextCurrent(),
-            .backup = lstNewP(sizeof(InfoBackupData), .comparator =  lstComparatorStr),
+            .backup = lstNewP(sizeof(InfoBackupData), .comparator = lstComparatorStr),
         },
     };
 
@@ -154,11 +156,13 @@ infoBackupLoadCallback(void *data, const String *section, const String *key, con
                 // When reading timestamps, read as uint64 to ensure always positive value (guarantee no backups before 1970)
                 .backupTimestampStart = (time_t)varUInt64(kvGet(backupKv, INFO_BACKUP_KEY_BACKUP_TIMESTAMP_START_VAR)),
                 .backupTimestampStop= (time_t)varUInt64(kvGet(backupKv, INFO_BACKUP_KEY_BACKUP_TIMESTAMP_STOP_VAR)),
-                .backupType = (BackupType)strIdFromStr(stringIdBit5, varStr(kvGet(backupKv, INFO_BACKUP_KEY_BACKUP_TYPE_VAR))),
+                .backupType = (BackupType)strIdFromStr(varStr(kvGet(backupKv, INFO_BACKUP_KEY_BACKUP_TYPE_VAR))),
 
                 // Possible NULL values
                 .backupArchiveStart = strDup(varStr(kvGet(backupKv, INFO_BACKUP_KEY_BACKUP_ARCHIVE_START_VAR))),
                 .backupArchiveStop = strDup(varStr(kvGet(backupKv, INFO_BACKUP_KEY_BACKUP_ARCHIVE_STOP_VAR))),
+                .backupLsnStart = strDup(varStr(kvGet(backupKv, INFO_BACKUP_KEY_BACKUP_LSN_START_VAR))),
+                .backupLsnStop = strDup(varStr(kvGet(backupKv, INFO_BACKUP_KEY_BACKUP_LSN_STOP_VAR))),
                 .backupPrior = strDup(varStr(kvGet(backupKv, INFO_BACKUP_KEY_BACKUP_PRIOR_VAR))),
                 .backupReference =
                     kvGet(backupKv, INFO_BACKUP_KEY_BACKUP_REFERENCE_VAR) != NULL ?
@@ -245,6 +249,11 @@ infoBackupSaveCallback(void *data, const String *sectionNext, InfoSave *infoSave
             kvPut(backupDataKv, INFO_BACKUP_KEY_BACKUP_ARCHIVE_START_VAR, VARSTR(backupData.backupArchiveStart));
             kvPut(backupDataKv, INFO_BACKUP_KEY_BACKUP_ARCHIVE_STOP_VAR, VARSTR(backupData.backupArchiveStop));
 
+            if (backupData.backupLsnStart != NULL)
+                kvPut(backupDataKv, INFO_BACKUP_KEY_BACKUP_LSN_START_VAR, VARSTR(backupData.backupLsnStart));
+            if (backupData.backupLsnStop != NULL)
+                kvPut(backupDataKv, INFO_BACKUP_KEY_BACKUP_LSN_STOP_VAR, VARSTR(backupData.backupLsnStop));
+
             if (backupData.backupPrior != NULL)
                 kvPut(backupDataKv, INFO_BACKUP_KEY_BACKUP_PRIOR_VAR, VARSTR(backupData.backupPrior));
 
@@ -361,22 +370,22 @@ infoBackupDataAdd(const InfoBackup *this, const Manifest *manifest)
 
         for (unsigned int fileIdx = 0; fileIdx < manifestFileTotal(manifest); fileIdx++)
         {
-            const ManifestFile *file = manifestFile(manifest, fileIdx);
+            const ManifestFile file = manifestFile(manifest, fileIdx);
 
-            backupSize += file->size;
-            backupRepoSize += file->sizeRepo > 0 ? file->sizeRepo : file->size;
+            backupSize += file.size;
+            backupRepoSize += file.sizeRepo > 0 ? file.sizeRepo : file.size;
 
             // If a reference to a file exists, then it is in a previous backup and the delta calculation was already done
-            if (file->reference != NULL)
-                strLstAddIfMissing(referenceList, file->reference);
+            if (file.reference != NULL)
+                strLstAddIfMissing(referenceList, file.reference);
             else
             {
-                backupSizeDelta += file->size;
-                backupRepoSizeDelta += file->sizeRepo > 0 ? file->sizeRepo : file->size;
+                backupSizeDelta += file.size;
+                backupRepoSizeDelta += file.sizeRepo > 0 ? file.sizeRepo : file.size;
             }
 
             // Is there an error in the file?
-            if (file->checksumPageError)
+            if (file.checksumPageError)
                 backupError = true;
         }
 
@@ -399,6 +408,8 @@ infoBackupDataAdd(const InfoBackup *this, const Manifest *manifest)
 
                 .backupArchiveStart = strDup(manData->archiveStart),
                 .backupArchiveStop = strDup(manData->archiveStop),
+                .backupLsnStart = strDup(manData->lsnStart),
+                .backupLsnStop = strDup(manData->lsnStop),
 
                 .optionArchiveCheck = manData->backupOptionArchiveCheck,
                 .optionArchiveCopy = manData->backupOptionArchiveCopy,
@@ -649,7 +660,7 @@ infoBackupLoadFileReconstruct(const Storage *storage, const String *fileName, Ci
 
             // If the manifest does not exist on disk and this backup has not already been deleted from the current list in the
             // infoBackup object, then remove it and its dependencies
-            if (!storageExistsP(storage, manifestFileName) && infoBackupDataByLabel(infoBackup, backupLabel) != NULL)
+            if (!storageExistsP(storage, manifestFileName) && infoBackupLabelExists(infoBackup, backupLabel))
             {
                 StringList *backupList = strLstSort(infoBackupDataDependentList(infoBackup, backupLabel), sortOrderDesc);
 
@@ -695,8 +706,7 @@ infoBackupLoadFileReconstruct(const Storage *storage, const String *fileName, Ci
                         // or there is a backup-prior and it is in the list, then add this backup to the current backup list
                         if (manData->pgId == pgHistory.id && manData->pgSystemId == pgHistory.systemId &&
                             manData->pgVersion == pgHistory.version &&
-                            (manData->backupLabelPrior == NULL ||
-                                infoBackupDataByLabel(infoBackup, manData->backupLabelPrior) != NULL))
+                            (manData->backupLabelPrior == NULL || infoBackupLabelExists(infoBackup, manData->backupLabelPrior)))
                         {
                             LOG_WARN_FMT("backup '%s' found in repository added to " INFO_BACKUP_FILE, strZ(backupLabel));
                             infoBackupDataAdd(infoBackup, manifest);
