@@ -10,17 +10,15 @@ nothing is missing or corrupt.  It is also useful for reporting, e.g. size of ba
 #ifndef INFO_MANIFEST_H
 #define INFO_MANIFEST_H
 
-#include "command/backup/common.h"
-#include "common/compress/helper.h"
-#include "common/crypto/common.h"
-#include "common/type/variantList.h"
-
 /***********************************************************************************************************************************
 Constants
 ***********************************************************************************************************************************/
 #define BACKUP_MANIFEST_FILE                                        "backup.manifest"
     STRING_DECLARE(BACKUP_MANIFEST_FILE_STR);
 
+#define MANIFEST_PATH_BUNDLE                                        "bundle"
+    STRING_DECLARE(MANIFEST_PATH_BUNDLE_STR);
+
 #define MANIFEST_TARGET_PGDATA                                      "pg_data"
     STRING_DECLARE(MANIFEST_TARGET_PGDATA_STR);
 #define MANIFEST_TARGET_PGTBLSPC                                    "pg_tblspc"
@@ -29,12 +27,16 @@ Constants
 /***********************************************************************************************************************************
 Object type
 ***********************************************************************************************************************************/
-#define MANIFEST_TYPE                                               Manifest
-#define MANIFEST_PREFIX                                             manifest
-
 typedef struct Manifest Manifest;
 
+#include "command/backup/common.h"
+#include "common/compress/helper.h"
+#include "common/crypto/common.h"
 #include "common/crypto/hash.h"
+#include "common/type/variantList.h"
+#include "common/type/object.h"
+#include "info/info.h"
+#include "info/infoBackup.h"
 #include "storage/storage.h"
 
 /***********************************************************************************************************************************
@@ -50,6 +52,7 @@ typedef struct ManifestData
     time_t backupTimestampStart;                                    // When did the backup start?
     time_t backupTimestampStop;                                     // When did the backup stop?
     BackupType backupType;                                          // Type of backup: full, diff, incr
+    bool bundle;                                                    // Does the backup bundle files?
 
     // ??? Note that these fields are redundant and verbose since storing the start/stop lsn as a uint64 would be sufficient.
     // However, we currently lack the functions to transform these values back and forth so this will do for now.
@@ -61,6 +64,7 @@ typedef struct ManifestData
     unsigned int pgId;                                              // PostgreSQL id in backup.info
     unsigned int pgVersion;                                         // PostgreSQL version
     uint64_t pgSystemId;                                            // PostgreSQL system identifier
+    unsigned int pgCatalogVersion;                                  // PostgreSQL catalog version
 
     bool backupOptionArchiveCheck;                                  // Will WAL segments be checked at the end of the backup?
     bool backupOptionArchiveCopy;                                   // Will WAL segments be copied to the backup?
@@ -92,15 +96,16 @@ File type
 typedef struct ManifestFile
 {
     const String *name;                                             // File name (must be first member in struct)
-    bool primary:1;                                                 // Should this file be copied from the primary?
     bool checksumPage:1;                                            // Does this file have page checksums?
     bool checksumPageError:1;                                       // Is there an error in the page checksum?
     mode_t mode;                                                    // File mode
     char checksumSha1[HASH_TYPE_SHA1_SIZE_HEX + 1];                 // SHA1 checksum
-    const VariantList *checksumPageErrorList;                       // List of page checksum errors if there are any
+    const String *checksumPageErrorList;                            // List of page checksum errors if there are any
     const String *user;                                             // User name
     const String *group;                                            // Group name
     const String *reference;                                        // Reference to a prior backup
+    uint64_t bundleId;                                              // Bundle id
+    uint64_t bundleOffset;                                          // Bundle offset
     uint64_t size;                                                  // Original size
     uint64_t sizeRepo;                                              // Size in repo
     time_t timestamp;                                               // Original timestamp
@@ -152,12 +157,50 @@ Constructors
 ***********************************************************************************************************************************/
 // Build a new manifest for a PostgreSQL data directory
 Manifest *manifestNewBuild(
-    const Storage *storagePg, unsigned int pgVersion, bool online, bool checksumPage, const StringList *excludeList,
-    const VariantList *tablespaceList);
+    const Storage *storagePg, unsigned int pgVersion, unsigned int pgCatalogVersion, bool online, bool checksumPage, bool bundle,
+    const StringList *excludeList, const VariantList *tablespaceList);
 
 // Load a manifest from IO
 Manifest *manifestNewLoad(IoRead *read);
 
+/***********************************************************************************************************************************
+Getters/Setters
+***********************************************************************************************************************************/
+typedef struct ManifestPub
+{
+    MemContext *memContext;                                         // Mem context
+    Info *info;                                                     // Base info object
+    ManifestData data;                                              // Manifest data and options
+    List *dbList;                                                   // List of databases
+    List *fileList;                                                 // List of files
+    List *linkList;                                                 // List of links
+    List *pathList;                                                 // List of paths
+    List *targetList;                                               // List of targets
+} ManifestPub;
+
+// Get/set the cipher subpassphrase
+__attribute__((always_inline)) static inline const String *
+manifestCipherSubPass(const Manifest *const this)
+{
+    return infoCipherPass(THIS_PUB(Manifest)->info);
+}
+
+__attribute__((always_inline)) static inline void
+manifestCipherSubPassSet(Manifest *const this, const String *const cipherSubPass)
+{
+    infoCipherPassSet(THIS_PUB(Manifest)->info, cipherSubPass);
+}
+
+// Get manifest configuration and options
+__attribute__((always_inline)) static inline const ManifestData *
+manifestData(const Manifest *const this)
+{
+    return &(THIS_PUB(Manifest)->data);
+}
+
+// Set backup label
+void manifestBackupLabelSet(Manifest *this, const String *backupLabel);
+
 /***********************************************************************************************************************************
 Build functions
 ***********************************************************************************************************************************/
@@ -177,11 +220,15 @@ void manifestBuildComplete(
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
-// Ensure that symlinks do not point to the same directory or a subdirectory of another link
+// Ensure that symlinks do not point to the same file, directory, or subdirectory of another link
 void manifestLinkCheck(const Manifest *this);
 
 // Move to a new parent mem context
-Manifest *manifestMove(Manifest *this, MemContext *parentNew);
+__attribute__((always_inline)) static inline Manifest *
+manifestMove(Manifest *const this, MemContext *const parentNew)
+{
+    return objMove(this, parentNew);
+}
 
 // Manifest save
 void manifestSave(Manifest *this, IoWrite *write);
@@ -192,77 +239,198 @@ void manifestValidate(Manifest *this, bool strict);
 /***********************************************************************************************************************************
 Db functions and getters/setters
 ***********************************************************************************************************************************/
-const ManifestDb *manifestDb(const Manifest *this, unsigned int dbIdx);
+__attribute__((always_inline)) static inline const ManifestDb *
+manifestDb(const Manifest *const this, const unsigned int dbIdx)
+{
+    return lstGet(THIS_PUB(Manifest)->dbList, dbIdx);
+}
+
 const ManifestDb *manifestDbFind(const Manifest *this, const String *name);
-const ManifestDb *manifestDbFindDefault(const Manifest *this, const String *name, const ManifestDb *dbDefault);
-unsigned int manifestDbTotal(const Manifest *this);
+
+// If the database requested is not found in the list, return the default passed rather than throw an error
+__attribute__((always_inline)) static inline const ManifestDb *
+manifestDbFindDefault(const Manifest *const this, const String *const name, const ManifestDb *const dbDefault)
+{
+    ASSERT_INLINE(name != NULL);
+    return lstFindDefault(THIS_PUB(Manifest)->dbList, &name, (void *)dbDefault);
+}
+
+__attribute__((always_inline)) static inline unsigned int
+manifestDbTotal(const Manifest *const this)
+{
+    return lstSize(THIS_PUB(Manifest)->dbList);
+}
 
 /***********************************************************************************************************************************
 File functions and getters/setters
 ***********************************************************************************************************************************/
-const ManifestFile *manifestFile(const Manifest *this, unsigned int fileIdx);
-void manifestFileAdd(Manifest *this, const ManifestFile *file);
-const ManifestFile *manifestFileFind(const Manifest *this, const String *name);
-const ManifestFile *manifestFileFindDefault(const Manifest *this, const String *name, const ManifestFile *fileDefault);
+typedef struct ManifestFilePack ManifestFilePack;
+
+// Unpack file pack returned by manifestFilePackGet()
+ManifestFile manifestFileUnpack(const Manifest *manifest, const ManifestFilePack *filePack);
+
+// Get file in pack format by index
+__attribute__((always_inline)) static inline const ManifestFilePack *
+manifestFilePackGet(const Manifest *const this, const unsigned int fileIdx)
+{
+    return *(ManifestFilePack **)lstGet(THIS_PUB(Manifest)->fileList, fileIdx);
+}
+
+// Get file name
+__attribute__((always_inline)) static inline const String *
+manifestFileNameGet(const Manifest *const this, const unsigned int fileIdx)
+{
+    return (const String *)manifestFilePackGet(this, fileIdx);
+}
+
+// Get file by index
+__attribute__((always_inline)) static inline ManifestFile
+manifestFile(const Manifest *const this, const unsigned int fileIdx)
+{
+    return manifestFileUnpack(this, manifestFilePackGet(this, fileIdx));
+}
+
+// Add a file
+void manifestFileAdd(Manifest *this, ManifestFile *file);
+
+// Find file in pack format by name
+const ManifestFilePack *manifestFilePackFind(const Manifest *this, const String *name);
+
+// Find file by name
+__attribute__((always_inline)) static inline ManifestFile
+manifestFileFind(const Manifest *const this, const String *const name)
+{
+    ASSERT_INLINE(name != NULL);
+    return manifestFileUnpack(this, manifestFilePackFind(this, name));
+}
+
+// Does the file exist?
+__attribute__((always_inline)) static inline bool
+manifestFileExists(const Manifest *const this, const String *const name)
+{
+    ASSERT_INLINE(name != NULL);
+    return lstFindDefault(THIS_PUB(Manifest)->fileList, &name, NULL) != NULL;
+}
+
 void manifestFileRemove(const Manifest *this, const String *name);
-unsigned int manifestFileTotal(const Manifest *this);
+
+__attribute__((always_inline)) static inline unsigned int
+manifestFileTotal(const Manifest *const this)
+{
+    return lstSize(THIS_PUB(Manifest)->fileList);
+}
 
 // Update a file with new data
 void manifestFileUpdate(
     Manifest *this, const String *name, uint64_t size, uint64_t sizeRepo, const char *checksumSha1, const Variant *reference,
-    bool checksumPage, bool checksumPageError, const VariantList *checksumPageErrorList);
+    bool checksumPage, bool checksumPageError, const String *checksumPageErrorList, uint64_t bundleId, uint64_t bundleOffset);
 
 /***********************************************************************************************************************************
 Link functions and getters/setters
 ***********************************************************************************************************************************/
-const ManifestLink *manifestLink(const Manifest *this, unsigned int linkIdx);
+__attribute__((always_inline)) static inline const ManifestLink *
+manifestLink(const Manifest *const this, const unsigned int linkIdx)
+{
+    return lstGet(THIS_PUB(Manifest)->linkList, linkIdx);
+}
+
+void manifestLinkAdd(Manifest *this, const ManifestLink *link);
 const ManifestLink *manifestLinkFind(const Manifest *this, const String *name);
-const ManifestLink *manifestLinkFindDefault(const Manifest *this, const String *name, const ManifestLink *linkDefault);
+
+// If the link requested is not found in the list, return the default passed rather than throw an error
+__attribute__((always_inline)) static inline const ManifestLink *
+manifestLinkFindDefault(const Manifest *const this, const String *const name, const ManifestLink *const linkDefault)
+{
+    ASSERT_INLINE(name != NULL);
+    return lstFindDefault(THIS_PUB(Manifest)->linkList, &name, (void *)linkDefault);
+}
+
 void manifestLinkRemove(const Manifest *this, const String *name);
-unsigned int manifestLinkTotal(const Manifest *this);
+
+__attribute__((always_inline)) static inline unsigned int
+manifestLinkTotal(const Manifest *const this)
+{
+    return lstSize(THIS_PUB(Manifest)->linkList);
+}
+
 void manifestLinkUpdate(const Manifest *this, const String *name, const String *path);
 
 /***********************************************************************************************************************************
 Path functions and getters/setters
 ***********************************************************************************************************************************/
-const ManifestPath *manifestPath(const Manifest *this, unsigned int pathIdx);
+__attribute__((always_inline)) static inline const ManifestPath *
+manifestPath(const Manifest *const this, const unsigned int pathIdx)
+{
+    return lstGet(THIS_PUB(Manifest)->pathList, pathIdx);
+}
+
 const ManifestPath *manifestPathFind(const Manifest *this, const String *name);
-const ManifestPath *manifestPathFindDefault(const Manifest *this, const String *name, const ManifestPath *pathDefault);
+
+// If the path requested is not found in the list, return the default passed rather than throw an error
+__attribute__((always_inline)) static inline const ManifestPath *
+manifestPathFindDefault(const Manifest *const this, const String *const name, const ManifestPath *const pathDefault)
+{
+    ASSERT_INLINE(name != NULL);
+    return lstFindDefault(THIS_PUB(Manifest)->pathList, &name, (void *)pathDefault);
+}
 
 // Data directory relative path for any manifest file/link/path/target name
 String *manifestPathPg(const String *manifestPath);
 
-unsigned int manifestPathTotal(const Manifest *this);
+__attribute__((always_inline)) static inline unsigned int
+manifestPathTotal(const Manifest *const this)
+{
+    return lstSize(THIS_PUB(Manifest)->pathList);
+}
 
 /***********************************************************************************************************************************
 Target functions and getters/setters
 ***********************************************************************************************************************************/
-const ManifestTarget *manifestTarget(const Manifest *this, unsigned int targetIdx);
+__attribute__((always_inline)) static inline const ManifestTarget *
+manifestTarget(const Manifest *const this, const unsigned int targetIdx)
+{
+    return lstGet(THIS_PUB(Manifest)->targetList, targetIdx);
+}
+
+void manifestTargetAdd(Manifest *this, const ManifestTarget *target);
+const ManifestTarget *manifestTargetFind(const Manifest *this, const String *name);
+
+// If the target requested is not found in the list, return the default passed rather than throw an error
+__attribute__((always_inline)) static inline const ManifestTarget *
+manifestTargetFindDefault(const Manifest *const this, const String *const name, const ManifestTarget *const targetDefault)
+{
+    ASSERT_INLINE(name != NULL);
+    return lstFindDefault(THIS_PUB(Manifest)->targetList, &name, (void *)targetDefault);
+}
 
 // Base target, i.e. the target that is the data directory
-const ManifestTarget *manifestTargetBase(const Manifest *this);
-
-const ManifestTarget *manifestTargetFind(const Manifest *this, const String *name);
+__attribute__((always_inline)) static inline const ManifestTarget *
+manifestTargetBase(const Manifest *const this)
+{
+    return manifestTargetFind(this, MANIFEST_TARGET_PGDATA_STR);
+}
 
 // Absolute path to the target
 String *manifestTargetPath(const Manifest *this, const ManifestTarget *target);
 
 void manifestTargetRemove(const Manifest *this, const String *name);
-unsigned int manifestTargetTotal(const Manifest *this);
+
+__attribute__((always_inline)) static inline unsigned int
+manifestTargetTotal(const Manifest *const this)
+{
+    return lstSize(THIS_PUB(Manifest)->targetList);
+}
+
 void manifestTargetUpdate(const Manifest *this, const String *name, const String *path, const String *file);
 
 /***********************************************************************************************************************************
-Getters/Setters
+Destructor
 ***********************************************************************************************************************************/
-// Get/set the cipher subpassphrase
-const String *manifestCipherSubPass(const Manifest *this);
-void manifestCipherSubPassSet(Manifest *this, const String *cipherSubPass);
-
-// Get manifest configuration and options
-const ManifestData *manifestData(const Manifest *this);
-
-// Set backup label
-void manifestBackupLabelSet(Manifest *this, const String *backupLabel);
+__attribute__((always_inline)) static inline void
+manifestFree(Manifest *const this)
+{
+    objFree(this);
+}
 
 /***********************************************************************************************************************************
 Helper functions
