@@ -198,26 +198,6 @@ static const PgInterface pgInterface[] =
         .walIs = pgInterfaceWalIs090,
         .wal = pgInterfaceWal090,
     },
-    {
-        .version = PG_VERSION_84,
-
-        .controlIs = pgInterfaceControlIs084,
-        .control = pgInterfaceControl084,
-        .controlVersion = pgInterfaceControlVersion084,
-
-        .walIs = pgInterfaceWalIs084,
-        .wal = pgInterfaceWal084,
-    },
-    {
-        .version = PG_VERSION_83,
-
-        .controlIs = pgInterfaceControlIs083,
-        .control = pgInterfaceControl083,
-        .controlVersion = pgInterfaceControlVersion083,
-
-        .walIs = pgInterfaceWalIs083,
-        .wal = pgInterfaceWal083,
-    },
 };
 
 // Total PostgreSQL versions in pgInterface
@@ -458,20 +438,17 @@ pgTablespaceId(unsigned int pgVersion, unsigned int pgCatalogVersion)
 
     String *result = NULL;
 
-    if (pgVersion >= PG_VERSION_90)
+    MEM_CONTEXT_TEMP_BEGIN()
     {
-        MEM_CONTEXT_TEMP_BEGIN()
-        {
-            String *pgVersionStr = pgVersionToStr(pgVersion);
+        String *pgVersionStr = pgVersionToStr(pgVersion);
 
-            MEM_CONTEXT_PRIOR_BEGIN()
-            {
-                result = strNewFmt("PG_%s_%u", strZ(pgVersionStr), pgCatalogVersion);
-            }
-            MEM_CONTEXT_PRIOR_END();
+        MEM_CONTEXT_PRIOR_BEGIN()
+        {
+            result = strNewFmt("PG_%s_%u", strZ(pgVersionStr), pgCatalogVersion);
         }
-        MEM_CONTEXT_TEMP_END();
+        MEM_CONTEXT_PRIOR_END();
     }
+    MEM_CONTEXT_TEMP_END();
 
     FUNCTION_TEST_RETURN(result);
 }
