@@ -163,7 +163,7 @@ protocolLocalParam(ProtocolStorageType protocolStorageType, unsigned int hostIdx
         // Only enable file logging on the local when requested
         kvPut(
             optionReplace, VARSTRDEF(CFGOPT_LOG_LEVEL_FILE),
-            cfgOptionBool(cfgOptLogSubprocess) ? VARSTR(cfgOptionStr(cfgOptLogLevelFile)) : VARSTRDEF("off"));
+            cfgOptionBool(cfgOptLogSubprocess) ? VARUINT64(cfgOptionStrId(cfgOptLogLevelFile)) : VARSTRDEF("off"));
 
         // Always output errors on stderr for debugging purposes
         kvPut(optionReplace, VARSTRDEF(CFGOPT_LOG_LEVEL_STDERR), VARSTRDEF("error"));
@@ -373,7 +373,7 @@ protocolServer(IoServer *const tlsServer, IoSession *const socketSession)
         IoSession *const tlsSession = ioServerAccept(tlsServer, socketSession);
 
         result = protocolServerNew(
-            PROTOCOL_SERVICE_REMOTE_STR, PROTOCOL_SERVICE_REMOTE_STR, ioSessionIoRead(tlsSession),
+            PROTOCOL_SERVICE_REMOTE_STR, PROTOCOL_SERVICE_REMOTE_STR, ioSessionIoReadP(tlsSession),
             ioSessionIoWrite(tlsSession));
 
         // If session is authenticated
@@ -382,7 +382,8 @@ protocolServer(IoServer *const tlsServer, IoSession *const socketSession)
             TRY_BEGIN()
             {
                 // Get list of authorized stanzas for this client
-                CHECK(cfgOptionTest(cfgOptTlsServerAuth));
+                CHECK(AssertError, cfgOptionTest(cfgOptTlsServerAuth), "missing auth data");
+
                 const String *const clientAuthList = strDup(
                     varStr(kvGet(cfgOptionKv(cfgOptTlsServerAuth), VARSTR(ioSessionPeerName(tlsSession)))));
 
@@ -392,7 +393,7 @@ protocolServer(IoServer *const tlsServer, IoSession *const socketSession)
 
                 // Get parameter list from the client and load it
                 const ProtocolServerCommandGetResult command = protocolServerCommandGet(result);
-                CHECK(command.id == PROTOCOL_COMMAND_CONFIG);
+                CHECK(FormatError, command.id == PROTOCOL_COMMAND_CONFIG, "expected config command");
 
                 StringList *const paramList = pckReadStrLstP(pckReadNew(command.param));
                 strLstInsert(paramList, 0, cfgExe());
@@ -551,7 +552,7 @@ protocolRemoteParam(ProtocolStorageType protocolStorageType, unsigned int hostId
     // Only enable file logging on the remote when requested
     kvPut(
         optionReplace, VARSTRDEF(CFGOPT_LOG_LEVEL_FILE),
-        cfgOptionBool(cfgOptLogSubprocess) ? VARSTR(cfgOptionStr(cfgOptLogLevelFile)) : VARSTRDEF("off"));
+        cfgOptionBool(cfgOptLogSubprocess) ? VARUINT64(cfgOptionStrId(cfgOptLogLevelFile)) : VARSTRDEF("off"));
 
     // Always output errors on stderr for debugging purposes
     kvPut(optionReplace, VARSTRDEF(CFGOPT_LOG_LEVEL_STDERR), VARSTRDEF("error"));
@@ -669,18 +670,18 @@ protocolRemoteExec(
             ASSERT(remoteType == CFGOPTVAL_REPO_HOST_TYPE_TLS);
 
             // Negotiate TLS
-            helper->ioClient = tlsClientNew(
+            helper->ioClient = tlsClientNewP(
                 sckClientNew(
                     host, cfgOptionIdxUInt(isRepo ? cfgOptRepoHostPort : cfgOptPgHostPort, hostIdx),
                     cfgOptionUInt64(cfgOptIoTimeout), cfgOptionUInt64(cfgOptProtocolTimeout)),
                 host, cfgOptionUInt64(cfgOptIoTimeout), cfgOptionUInt64(cfgOptProtocolTimeout), true,
-                cfgOptionIdxStrNull(isRepo ? cfgOptRepoHostCaFile : cfgOptPgHostCaFile, hostIdx),
-                cfgOptionIdxStrNull(isRepo ? cfgOptRepoHostCaPath : cfgOptPgHostCaPath, hostIdx),
-                cfgOptionIdxStr(isRepo ? cfgOptRepoHostCertFile : cfgOptPgHostCertFile, hostIdx),
-                cfgOptionIdxStr(isRepo ? cfgOptRepoHostKeyFile : cfgOptPgHostKeyFile, hostIdx));
+                .caFile = cfgOptionIdxStrNull(isRepo ? cfgOptRepoHostCaFile : cfgOptPgHostCaFile, hostIdx),
+                .caPath = cfgOptionIdxStrNull(isRepo ? cfgOptRepoHostCaPath : cfgOptPgHostCaPath, hostIdx),
+                .certFile = cfgOptionIdxStr(isRepo ? cfgOptRepoHostCertFile : cfgOptPgHostCertFile, hostIdx),
+                .keyFile = cfgOptionIdxStr(isRepo ? cfgOptRepoHostKeyFile : cfgOptPgHostKeyFile, hostIdx));
             helper->ioSession = ioClientOpen(helper->ioClient);
 
-            read = ioSessionIoRead(helper->ioSession);
+            read = ioSessionIoReadP(helper->ioSession);
             write = ioSessionIoWrite(helper->ioSession);
 
             break;
@@ -753,7 +754,7 @@ protocolRemoteGet(ProtocolStorageType protocolStorageType, unsigned int hostIdx)
     if (cfgOptionTest(cfgOptProcess))
         processId = cfgOptionUInt(cfgOptProcess);
 
-    CHECK(hostIdx < protocolHelper.clientRemoteSize);
+    CHECK(AssertError, hostIdx < protocolHelper.clientRemoteSize, "invalid host");
 
     // Create protocol object
     ProtocolHelperClient *protocolHelperClient = &protocolHelper.clientRemote[hostIdx];
@@ -777,7 +778,7 @@ protocolRemoteGet(ProtocolStorageType protocolStorageType, unsigned int hostIdx)
 
                 VariantList *optionList = configOptionRemote(protocolHelperClient->client, param);
 
-                if (!strEq(varStr(varLstGet(optionList, 0)), strIdToStr(cipherTypeNone)))
+                if (varUInt64(varLstGet(optionList, 0)) != cipherTypeNone)
                 {
                     cfgOptionIdxSet(cfgOptRepoCipherType, hostIdx, cfgSourceConfig, varLstGet(optionList, 0));
                     cfgOptionIdxSet(cfgOptRepoCipherPass, hostIdx, cfgSourceConfig, varLstGet(optionList, 1));
