@@ -7,9 +7,8 @@ Posix Storage Read
 #include <unistd.h>
 
 #include "common/debug.h"
-#include "common/io/read.intern.h"
+#include "common/io/read.h"
 #include "common/log.h"
-#include "common/memContext.h"
 #include "common/type/object.h"
 #include "storage/posix/read.h"
 #include "storage/posix/storage.intern.h"
@@ -18,12 +17,8 @@ Posix Storage Read
 /***********************************************************************************************************************************
 Object types
 ***********************************************************************************************************************************/
-#define STORAGE_READ_POSIX_TYPE                                     StorageReadPosix
-#define STORAGE_READ_POSIX_PREFIX                                   storageReadPosix
-
 typedef struct StorageReadPosix
 {
-    MemContext *memContext;                                         // Object mem context
     StorageReadInterface interface;                                 // Interface
     StoragePosix *storage;                                          // Storage that created this object
 
@@ -44,12 +39,22 @@ Macros for function logging
 /***********************************************************************************************************************************
 Close file descriptor
 ***********************************************************************************************************************************/
-OBJECT_DEFINE_FREE_RESOURCE_BEGIN(STORAGE_READ_POSIX, LOG, logLevelTrace)
+static void
+storageReadPosixFreeResource(THIS_VOID)
 {
+    THIS(StorageReadPosix);
+
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(STORAGE_READ_POSIX, this);
+    FUNCTION_LOG_END();
+
+    ASSERT(this != NULL);
+
     if (this->fd != -1)
         THROW_ON_SYS_ERROR_FMT(close(this->fd) == -1, FileCloseError, STORAGE_ERROR_READ_CLOSE, strZ(this->interface.name));
+
+    FUNCTION_LOG_RETURN_VOID();
 }
-OBJECT_DEFINE_FREE_RESOURCE_END(LOG);
 
 /***********************************************************************************************************************************
 Open the file
@@ -66,8 +71,6 @@ storageReadPosixOpen(THIS_VOID)
     ASSERT(this != NULL);
     ASSERT(this->fd == -1);
 
-    bool result = false;
-
     // Open the file
     this->fd = open(strZ(this->interface.name), O_RDONLY, 0);
 
@@ -82,14 +85,22 @@ storageReadPosixOpen(THIS_VOID)
         else
             THROW_SYS_ERROR_FMT(FileOpenError, STORAGE_ERROR_READ_OPEN, strZ(this->interface.name));                // {vm_covered}
     }
-    // On success set free callback to ensure the file descriptor is freed
-    if (this->fd != -1)
+    // Else success
+    else
     {
-        memContextCallbackSet(this->memContext, storageReadPosixFreeResource, this);
-        result = true;
+        // Set free callback to ensure the file descriptor is freed
+        memContextCallbackSet(THIS_MEM_CONTEXT(), storageReadPosixFreeResource, this);
+
+        // Seek to offset
+        if (this->interface.offset != 0)
+        {
+            THROW_ON_SYS_ERROR_FMT(
+                lseek(this->fd, (off_t)this->interface.offset, SEEK_SET) == -1, FileOpenError, STORAGE_ERROR_READ_SEEK,
+                this->interface.offset, strZ(this->interface.name));
+        }
     }
 
-    FUNCTION_LOG_RETURN(BOOL, result);
+    FUNCTION_LOG_RETURN(BOOL, this->fd != -1);
 }
 
 /***********************************************************************************************************************************
@@ -154,7 +165,7 @@ storageReadPosixClose(THIS_VOID)
 
     ASSERT(this != NULL);
 
-    memContextCallbackClear(this->memContext);
+    memContextCallbackClear(THIS_MEM_CONTEXT());
     storageReadPosixFreeResource(this);
     this->fd = -1;
 
@@ -197,11 +208,14 @@ storageReadPosixFd(const THIS_VOID)
 
 /**********************************************************************************************************************************/
 StorageRead *
-storageReadPosixNew(StoragePosix *storage, const String *name, bool ignoreMissing, const Variant *limit)
+storageReadPosixNew(
+    StoragePosix *const storage, const String *const name, const bool ignoreMissing, const uint64_t offset,
+    const Variant *const limit)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
         FUNCTION_LOG_PARAM(STRING, name);
         FUNCTION_LOG_PARAM(BOOL, ignoreMissing);
+        FUNCTION_LOG_PARAM(UINT64, offset);
         FUNCTION_LOG_PARAM(VARIANT, limit);
     FUNCTION_LOG_END();
 
@@ -209,13 +223,12 @@ storageReadPosixNew(StoragePosix *storage, const String *name, bool ignoreMissin
 
     StorageRead *this = NULL;
 
-    MEM_CONTEXT_NEW_BEGIN("StorageReadPosix")
+    OBJ_NEW_BEGIN(StorageReadPosix)
     {
-        StorageReadPosix *driver = memNew(sizeof(StorageReadPosix));
+        StorageReadPosix *driver = OBJ_NEW_ALLOC();
 
         *driver = (StorageReadPosix)
         {
-            .memContext = MEM_CONTEXT_NEW(),
             .storage = storage,
             .fd = -1,
 
@@ -226,9 +239,10 @@ storageReadPosixNew(StoragePosix *storage, const String *name, bool ignoreMissin
 
             .interface = (StorageReadInterface)
             {
-                .type = STORAGE_POSIX_TYPE_STR,
+                .type = STORAGE_POSIX_TYPE,
                 .name = strDup(name),
                 .ignoreMissing = ignoreMissing,
+                .offset = offset,
                 .limit = varDup(limit),
 
                 .ioInterface = (IoReadInterface)
@@ -244,7 +258,7 @@ storageReadPosixNew(StoragePosix *storage, const String *name, bool ignoreMissin
 
         this = storageReadNew(driver, &driver->interface);
     }
-    MEM_CONTEXT_NEW_END();
+    OBJ_NEW_END();
 
     FUNCTION_LOG_RETURN(STORAGE_READ, this);
 }
