@@ -8,8 +8,9 @@ Posix Storage Read
 #include "storage/read.h"
 
 /***********************************************************************************************************************************
-Constructor
+Constructors
 ***********************************************************************************************************************************/
-StorageRead *storageReadPosixNew(StoragePosix *storage, const String *name, bool ignoreMissing, const Variant *limit);
+StorageRead *storageReadPosixNew(
+    StoragePosix *storage, const String *name, bool ignoreMissing, uint64_t offset, const Variant *limit);
 
 #endif
