@@ -14,18 +14,12 @@ Posix Storage
 
 #include "common/debug.h"
 #include "common/log.h"
-#include "common/memContext.h"
 #include "common/regExp.h"
 #include "common/user.h"
 #include "storage/posix/read.h"
 #include "storage/posix/storage.intern.h"
 #include "storage/posix/write.h"
 
-/***********************************************************************************************************************************
-Storage type
-***********************************************************************************************************************************/
-STRING_EXTERN(STORAGE_POSIX_TYPE_STR,                               STORAGE_POSIX_TYPE);
-
 /***********************************************************************************************************************************
 Define PATH_MAX if it is not defined
 ***********************************************************************************************************************************/
@@ -39,7 +33,6 @@ Object type
 struct StoragePosix
 {
     STORAGE_COMMON_MEMBER;
-    MemContext *memContext;                                         // Object memory context
 };
 
 /**********************************************************************************************************************************/
@@ -73,17 +66,10 @@ storagePosixInfo(THIS_VOID, const String *file, StorageInfoLevel level, StorageI
     {
         result.exists = true;
 
-        // Add basic level info
-        if (result.level >= storageInfoLevelBasic)
+        // Add type info (no need set file type since it is the default)
+        if (result.level >= storageInfoLevelType && !S_ISREG(statFile.st_mode))
         {
-            result.timeModified = statFile.st_mtime;
-
-            if (S_ISREG(statFile.st_mode))
-            {
-                result.type = storageTypeFile;
-                result.size = (uint64_t)statFile.st_size;
-            }
-            else if (S_ISDIR(statFile.st_mode))
+            if (S_ISDIR(statFile.st_mode))
                 result.type = storageTypePath;
             else if (S_ISLNK(statFile.st_mode))
                 result.type = storageTypeLink;
@@ -91,6 +77,15 @@ storagePosixInfo(THIS_VOID, const String *file, StorageInfoLevel level, StorageI
                 result.type = storageTypeSpecial;
         }
 
+        // Add basic level info
+        if (result.level >= storageInfoLevelBasic)
+        {
+            result.timeModified = statFile.st_mtime;
+
+            if (result.type == storageTypeFile)
+                result.size = (uint64_t)statFile.st_size;
+        }
+
         // Add detail level info
         if (result.level >= storageInfoLevelDetail)
         {
@@ -109,7 +104,7 @@ storagePosixInfo(THIS_VOID, const String *file, StorageInfoLevel level, StorageI
                     (linkDestinationSize = readlink(strZ(file), linkDestination, sizeof(linkDestination) - 1)) == -1,
                     FileReadError, "unable to get destination for link '%s'", strZ(file));
 
-                result.linkDestination = strNewN(linkDestination, (size_t)linkDestinationSize);
+                result.linkDestination = strNewZN(linkDestination, (size_t)linkDestinationSize);
             }
         }
     }
@@ -315,13 +310,14 @@ storagePosixNewRead(THIS_VOID, const String *file, bool ignoreMissing, StorageIn
         FUNCTION_LOG_PARAM(STORAGE_POSIX, this);
         FUNCTION_LOG_PARAM(STRING, file);
         FUNCTION_LOG_PARAM(BOOL, ignoreMissing);
+        FUNCTION_LOG_PARAM(UINT64, param.offset);
         FUNCTION_LOG_PARAM(VARIANT, param.limit);
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
     ASSERT(file != NULL);
 
-    FUNCTION_LOG_RETURN(STORAGE_READ, storageReadPosixNew(this, file, ignoreMissing, param.limit));
+    FUNCTION_LOG_RETURN(STORAGE_READ, storageReadPosixNew(this, file, ignoreMissing, param.offset, param.limit));
 }
 
 /**********************************************************************************************************************************/
@@ -550,7 +546,7 @@ storagePosixRemove(THIS_VOID, const String *file, StorageInterfaceRemoveParam pa
 /**********************************************************************************************************************************/
 static const StorageInterface storageInterfacePosix =
 {
-    .feature = 1 << storageFeaturePath | 1 << storageFeatureCompress | 1 << storageFeatureLimitRead,
+    .feature = 1 << storageFeaturePath,
 
     .info = storagePosixInfo,
     .infoList = storagePosixInfoList,
@@ -565,11 +561,11 @@ static const StorageInterface storageInterfacePosix =
 
 Storage *
 storagePosixNewInternal(
-    const String *type, const String *path, mode_t modeFile, mode_t modePath, bool write,
+    StringId type, const String *path, mode_t modeFile, mode_t modePath, bool write,
     StoragePathExpressionCallback pathExpressionFunction, bool pathSync)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
-        FUNCTION_LOG_PARAM(STRING, type);
+        FUNCTION_LOG_PARAM(STRING_ID, type);
         FUNCTION_LOG_PARAM(STRING, path);
         FUNCTION_LOG_PARAM(MODE, modeFile);
         FUNCTION_LOG_PARAM(MODE, modePath);
@@ -578,24 +574,23 @@ storagePosixNewInternal(
         FUNCTION_LOG_PARAM(BOOL, pathSync);
     FUNCTION_LOG_END();
 
-    ASSERT(type != NULL);
+    ASSERT(type != 0);
     ASSERT(path != NULL);
     ASSERT(modeFile != 0);
     ASSERT(modePath != 0);
 
-    // Initialze user module
+    // Initialize user module
     userInit();
 
     // Create the object
     Storage *this = NULL;
 
-    MEM_CONTEXT_NEW_BEGIN("StoragePosix")
+    OBJ_NEW_BEGIN(StoragePosix)
     {
-        StoragePosix *driver = memNew(sizeof(StoragePosix));
+        StoragePosix *driver = OBJ_NEW_ALLOC();
 
         *driver = (StoragePosix)
         {
-            .memContext = MEM_CONTEXT_NEW(),
             .interface = storageInterfacePosix,
         };
 
@@ -604,14 +599,14 @@ storagePosixNewInternal(
             driver->interface.pathSync = NULL;
 
         // If this is a posix driver then add link features
-        if (strEq(type, STORAGE_POSIX_TYPE_STR))
+        if (type == STORAGE_POSIX_TYPE)
             driver->interface.feature |=
                 1 << storageFeatureHardLink | 1 << storageFeatureSymLink | 1 << storageFeaturePathSync |
                 1 << storageFeatureInfoDetail;
 
         this = storageNew(type, path, modeFile, modePath, write, pathExpressionFunction, driver, driver->interface);
     }
-    MEM_CONTEXT_NEW_END();
+    OBJ_NEW_END();
 
     FUNCTION_LOG_RETURN(STORAGE, this);
 }
@@ -630,6 +625,6 @@ storagePosixNew(const String *path, StoragePosixNewParam param)
     FUNCTION_LOG_RETURN(
         STORAGE,
         storagePosixNewInternal(
-            STORAGE_POSIX_TYPE_STR, path, param.modeFile == 0 ? STORAGE_MODE_FILE_DEFAULT : param.modeFile,
+            STORAGE_POSIX_TYPE, path, param.modeFile == 0 ? STORAGE_MODE_FILE_DEFAULT : param.modeFile,
             param.modePath == 0 ? STORAGE_MODE_PATH_DEFAULT : param.modePath, param.write, param.pathExpressionFunction, true));
 }
