@@ -31,6 +31,9 @@ S3 HTTP headers
 STRING_STATIC(S3_HEADER_CONTENT_SHA256_STR,                         "x-amz-content-sha256");
 STRING_STATIC(S3_HEADER_DATE_STR,                                   "x-amz-date");
 STRING_STATIC(S3_HEADER_TOKEN_STR,                                  "x-amz-security-token");
+STRING_STATIC(S3_HEADER_SRVSDENC_STR,                               "x-amz-server-side-encryption");
+STRING_STATIC(S3_HEADER_SRVSDENC_KMS_STR,                           "aws:kms");
+STRING_STATIC(S3_HEADER_SRVSDENC_KMSKEYID_STR,                      "x-amz-server-side-encryption-aws-kms-key-id");
 
 /***********************************************************************************************************************************
 S3 query tokens
@@ -46,14 +49,12 @@ STRING_STATIC(S3_QUERY_VALUE_LIST_TYPE_2_STR,                       "2");
 /***********************************************************************************************************************************
 XML tags
 ***********************************************************************************************************************************/
-STRING_STATIC(S3_XML_TAG_CODE_STR,                                  "Code");
 STRING_STATIC(S3_XML_TAG_COMMON_PREFIXES_STR,                       "CommonPrefixes");
 STRING_STATIC(S3_XML_TAG_CONTENTS_STR,                              "Contents");
 STRING_STATIC(S3_XML_TAG_DELETE_STR,                                "Delete");
 STRING_STATIC(S3_XML_TAG_ERROR_STR,                                 "Error");
 STRING_STATIC(S3_XML_TAG_KEY_STR,                                   "Key");
 STRING_STATIC(S3_XML_TAG_LAST_MODIFIED_STR,                         "LastModified");
-STRING_STATIC(S3_XML_TAG_MESSAGE_STR,                               "Message");
 STRING_STATIC(S3_XML_TAG_NEXT_CONTINUATION_TOKEN_STR,               "NextContinuationToken");
 STRING_STATIC(S3_XML_TAG_OBJECT_STR,                                "Object");
 STRING_STATIC(S3_XML_TAG_PREFIX_STR,                                "Prefix");
@@ -90,6 +91,7 @@ struct StorageS3
     String *accessKey;                                              // Access key
     String *secretAccessKey;                                        // Secret access key
     String *securityToken;                                          // Security token, if any
+    const String *kmsKeyId;                                         // Server-side encryption key
     size_t partSize;                                                // Part size for multi-part upload
     unsigned int deleteMax;                                         // Maximum objects that can be deleted in one request
     StorageS3UriStyle uriStyle;                                     // Path or host style URIs
@@ -331,15 +333,15 @@ storageS3AuthAuto(StorageS3 *const this, const HttpHeader *const header)
     {
         // Check the code field for errors
         const Variant *code = kvGetDefault(credential, S3_JSON_TAG_CODE_VAR, VARSTRDEF("code field is missing"));
-        CHECK(code != NULL);
+        CHECK(FormatError, code != NULL, "error code missing");
 
         if (!varEq(code, S3_JSON_VALUE_SUCCESS_VAR))
             THROW_FMT(FormatError, "unable to retrieve temporary credentials: %s", strZ(varStr(code)));
 
         // Make sure the required values are present
-        CHECK(kvGet(credential, S3_JSON_TAG_ACCESS_KEY_ID_VAR) != NULL);
-        CHECK(kvGet(credential, S3_JSON_TAG_SECRET_ACCESS_KEY_VAR) != NULL);
-        CHECK(kvGet(credential, S3_JSON_TAG_TOKEN_VAR) != NULL);
+        CHECK(FormatError, kvGet(credential, S3_JSON_TAG_ACCESS_KEY_ID_VAR) != NULL, "access key missing");
+        CHECK(FormatError, kvGet(credential, S3_JSON_TAG_SECRET_ACCESS_KEY_VAR) != NULL, "secret access key missing");
+        CHECK(FormatError, kvGet(credential, S3_JSON_TAG_TOKEN_VAR) != NULL, "token missing");
 
         // Copy credentials
         this->accessKey = strDup(varStr(kvGet(credential, S3_JSON_TAG_ACCESS_KEY_ID_VAR)));
@@ -349,7 +351,7 @@ storageS3AuthAuto(StorageS3 *const this, const HttpHeader *const header)
     MEM_CONTEXT_END();
 
     // Update expiration time
-    CHECK(kvGet(credential, S3_JSON_TAG_EXPIRATION_VAR) != NULL);
+    CHECK(FormatError, kvGet(credential, S3_JSON_TAG_EXPIRATION_VAR) != NULL, "expiration missing");
     this->credExpirationTime = storageS3CvtTime(varStr(kvGet(credential, S3_JSON_TAG_EXPIRATION_VAR)));
 
     FUNCTION_LOG_RETURN_VOID();
@@ -383,7 +385,7 @@ storageS3AuthWebId(StorageS3 *const this, const HttpHeader *const header)
         this->credHttpClient, HTTP_VERB_GET_STR, FSLASH_STR, .header = header, .query = query);
     HttpResponse *const response = httpRequestResponse(request, true);
 
-    CHECK(httpResponseCode(response) != HTTP_RESPONSE_CODE_NOT_FOUND);
+    CHECK(FormatError, httpResponseCode(response) != HTTP_RESPONSE_CODE_NOT_FOUND, "invalid response code");
 
     // Copy credentials
     const XmlNode *const xmlCred =
@@ -420,8 +422,10 @@ storageS3RequestAsync(StorageS3 *this, const String *verb, const String *path, S
         FUNCTION_LOG_PARAM(STORAGE_S3, this);
         FUNCTION_LOG_PARAM(STRING, verb);
         FUNCTION_LOG_PARAM(STRING, path);
+        FUNCTION_LOG_PARAM(HTTP_HEADER, param.header);
         FUNCTION_LOG_PARAM(HTTP_QUERY, param.query);
         FUNCTION_LOG_PARAM(BUFFER, param.content);
+        FUNCTION_LOG_PARAM(BOOL, param.sseKms);
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
@@ -432,7 +436,8 @@ storageS3RequestAsync(StorageS3 *this, const String *verb, const String *path, S
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        HttpHeader *requestHeader = httpHeaderNew(this->headerRedactList);
+        HttpHeader *requestHeader = param.header == NULL ?
+            httpHeaderNew(this->headerRedactList) : httpHeaderDup(param.header, this->headerRedactList);
 
         // Set content length
         httpHeaderAdd(
@@ -447,6 +452,13 @@ storageS3RequestAsync(StorageS3 *this, const String *verb, const String *path, S
                 strNewEncode(encodeBase64, cryptoHashOne(HASH_TYPE_MD5_STR, param.content)));
         }
 
+        // Set KMS headers when requested
+        if (param.sseKms && this->kmsKeyId != NULL)
+        {
+            httpHeaderPut(requestHeader, S3_HEADER_SRVSDENC_STR, S3_HEADER_SRVSDENC_KMS_STR);
+            httpHeaderPut(requestHeader, S3_HEADER_SRVSDENC_KMSKEYID_STR, this->kmsKeyId);
+        }
+
         // When using path-style URIs the bucket name needs to be prepended
         if (this->uriStyle == storageS3UriStylePath)
             path = strNewFmt("/%s%s", strZ(this->bucket), strZ(path));
@@ -545,16 +557,19 @@ storageS3Request(StorageS3 *this, const String *verb, const String *path, Storag
         FUNCTION_LOG_PARAM(STORAGE_S3, this);
         FUNCTION_LOG_PARAM(STRING, verb);
         FUNCTION_LOG_PARAM(STRING, path);
+        FUNCTION_LOG_PARAM(HTTP_HEADER, param.header);
         FUNCTION_LOG_PARAM(HTTP_QUERY, param.query);
         FUNCTION_LOG_PARAM(BUFFER, param.content);
         FUNCTION_LOG_PARAM(BOOL, param.allowMissing);
         FUNCTION_LOG_PARAM(BOOL, param.contentIo);
+        FUNCTION_LOG_PARAM(BOOL, param.sseKms);
     FUNCTION_LOG_END();
 
     FUNCTION_LOG_RETURN(
         HTTP_RESPONSE,
         storageS3ResponseP(
-            storageS3RequestAsyncP(this, verb, path, .query = param.query, .content = param.content),
+            storageS3RequestAsyncP(
+                this, verb, path, .header = param.header, .query = param.query, .content = param.content, .sseKms = param.sseKms),
             .allowMissing = param.allowMissing, .contentIo = param.contentIo));
 }
 
@@ -640,7 +655,7 @@ storageS3ListInternal(
                 }
                 // Else get the response immediately from a sync request
                 else
-                    response = storageS3RequestP(this, HTTP_VERB_GET_STR, FSLASH_STR, query);
+                    response = storageS3RequestP(this, HTTP_VERB_GET_STR, FSLASH_STR, .query = query);
 
                 XmlNode *xmlRoot = xmlDocumentRoot(xmlDocumentNewBuf(httpResponseContent(response)));
 
@@ -655,7 +670,7 @@ storageS3ListInternal(
                     // Store request in the outer temp context
                     MEM_CONTEXT_PRIOR_BEGIN()
                     {
-                        request = storageS3RequestAsyncP(this, HTTP_VERB_GET_STR, FSLASH_STR, query);
+                        request = storageS3RequestAsyncP(this, HTTP_VERB_GET_STR, FSLASH_STR, .query = query);
                     }
                     MEM_CONTEXT_PRIOR_END();
                 }
@@ -754,11 +769,11 @@ storageS3Info(THIS_VOID, const String *file, StorageInfoLevel level, StorageInte
         const HttpHeader *httpHeader = httpResponseHeader(httpResponse);
 
         const String *const contentLength = httpHeaderGet(httpHeader, HTTP_HEADER_CONTENT_LENGTH_STR);
-        CHECK(contentLength != NULL);
+        CHECK(FormatError, contentLength != NULL, "content length missing");
         result.size = cvtZToUInt64(strZ(contentLength));
 
         const String *const lastModified = httpHeaderGet(httpHeader, HTTP_HEADER_LAST_MODIFIED_STR);
-        CHECK(lastModified != NULL);
+        CHECK(FormatError, lastModified != NULL, "last modified missing");
         result.timeModified = httpDateToTime(lastModified);
     }
 
@@ -801,13 +816,14 @@ storageS3NewRead(THIS_VOID, const String *file, bool ignoreMissing, StorageInter
         FUNCTION_LOG_PARAM(STORAGE_S3, this);
         FUNCTION_LOG_PARAM(STRING, file);
         FUNCTION_LOG_PARAM(BOOL, ignoreMissing);
-        (void)param;                                                // No parameters are used
+        FUNCTION_LOG_PARAM(UINT64, param.offset);
+        FUNCTION_LOG_PARAM(VARIANT, param.limit);
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
     ASSERT(file != NULL);
 
-    FUNCTION_LOG_RETURN(STORAGE_READ, storageReadS3New(this, file, ignoreMissing));
+    FUNCTION_LOG_RETURN(STORAGE_READ, storageReadS3New(this, file, ignoreMissing, param.offset, param.limit));
 }
 
 /**********************************************************************************************************************************/
@@ -864,15 +880,13 @@ storageS3PathRemoveInternal(StorageS3 *this, HttpRequest *request, XmlDocument *
         {
             XmlNodeList *errorList = xmlNodeChildList(xmlDocumentRoot(xmlDocumentNewBuf(response)), S3_XML_TAG_ERROR_STR);
 
-            if (xmlNodeLstSize(errorList) > 0)
+            // Attempt to remove errored files one at a time rather than retrying the batch
+            for (unsigned int errorIdx = 0; errorIdx < xmlNodeLstSize(errorList); errorIdx++)
             {
-                XmlNode *error = xmlNodeLstGet(errorList, 0);
-
-                THROW_FMT(
-                    FileRemoveError, STORAGE_ERROR_PATH_REMOVE_FILE ": [%s] %s",
-                    strZ(xmlNodeContent(xmlNodeChild(error, S3_XML_TAG_KEY_STR, true))),
-                    strZ(xmlNodeContent(xmlNodeChild(error, S3_XML_TAG_CODE_STR, true))),
-                    strZ(xmlNodeContent(xmlNodeChild(error, S3_XML_TAG_MESSAGE_STR, true))));
+                storageS3RequestP(
+                    this, HTTP_VERB_DELETE_STR,
+                    strNewFmt(
+                        "/%s", strZ(xmlNodeContent(xmlNodeChild(xmlNodeLstGet(errorList, errorIdx), S3_XML_TAG_KEY_STR, true)))));
             }
         }
 
@@ -1017,9 +1031,9 @@ Storage *
 storageS3New(
     const String *path, bool write, StoragePathExpressionCallback pathExpressionFunction, const String *bucket,
     const String *endPoint, StorageS3UriStyle uriStyle, const String *region, StorageS3KeyType keyType, const String *accessKey,
-    const String *secretAccessKey, const String *securityToken, const String *credRole, const String *const webIdToken,
-    size_t partSize, const String *host, unsigned int port, TimeMSec timeout, bool verifyPeer, const String *caFile,
-    const String *caPath)
+    const String *secretAccessKey, const String *securityToken, const String *const kmsKeyId, const String *credRole,
+    const String *const webIdToken, size_t partSize, const String *host, unsigned int port, TimeMSec timeout, bool verifyPeer,
+    const String *caFile, const String *caPath)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(STRING, path);
@@ -1033,6 +1047,7 @@ storageS3New(
         FUNCTION_TEST_PARAM(STRING, accessKey);
         FUNCTION_TEST_PARAM(STRING, secretAccessKey);
         FUNCTION_TEST_PARAM(STRING, securityToken);
+        FUNCTION_TEST_PARAM(STRING, kmsKeyId);
         FUNCTION_TEST_PARAM(STRING, credRole);
         FUNCTION_TEST_PARAM(STRING, webIdToken);
         FUNCTION_LOG_PARAM(SIZE, partSize);
@@ -1062,6 +1077,7 @@ storageS3New(
             .bucket = strDup(bucket),
             .region = strDup(region),
             .keyType = keyType,
+            .kmsKeyId = strDup(kmsKeyId),
             .partSize = partSize,
             .deleteMax = STORAGE_S3_DELETE_MAX,
             .uriStyle = uriStyle,
@@ -1077,8 +1093,8 @@ storageS3New(
             host = driver->bucketEndpoint;
 
         driver->httpClient = httpClientNew(
-            tlsClientNew(
-                sckClientNew(host, port, timeout, timeout), host, timeout, timeout, verifyPeer, caFile, caPath, NULL, NULL),
+            tlsClientNewP(
+                sckClientNew(host, port, timeout, timeout), host, timeout, timeout, verifyPeer, .caFile = caFile, .caPath = caPath),
             timeout);
 
         // Initialize authentication
@@ -1110,9 +1126,9 @@ storageS3New(
                 driver->credHost = S3_STS_HOST_STR;
                 driver->credExpirationTime = time(NULL);
                 driver->credHttpClient = httpClientNew(
-                    tlsClientNew(
+                    tlsClientNewP(
                         sckClientNew(driver->credHost, S3_STS_PORT, timeout, timeout), driver->credHost, timeout, timeout, true,
-                        caFile, caPath, NULL, NULL),
+                        .caFile = caFile, .caPath = caPath),
                     timeout);
 
                 break;
