@@ -1,13 +1,22 @@
 /***********************************************************************************************************************************
 Storage Interface Internal
+
+Storage drivers are implemented using this interface.
+
+The interface has required and optional functions. Currently the optional functions are only implemented by the Posix driver which
+can store either a repository or a PostgreSQL cluster. Drivers that are intended to store repositories only need to implement the
+required functions.
+
+The behavior of required functions is further modified by storage features defined by the StorageFeature enum. Details are included
+in the description of each function.
 ***********************************************************************************************************************************/
 #ifndef STORAGE_STORAGE_INTERN_H
 #define STORAGE_STORAGE_INTERN_H
 
 #include "common/type/param.h"
-#include "storage/read.intern.h"
-#include "storage/storage.h"
-#include "storage/write.intern.h"
+#include "storage/info.h"
+#include "storage/read.h"
+#include "storage/write.h"
 
 /***********************************************************************************************************************************
 Default file and path modes
@@ -21,13 +30,11 @@ Error messages
 #define STORAGE_ERROR_READ_CLOSE                                    "unable to close file '%s' after read"
 #define STORAGE_ERROR_READ_OPEN                                     "unable to open file '%s' for read"
 #define STORAGE_ERROR_READ_MISSING                                  "unable to open missing file '%s' for read"
+#define STORAGE_ERROR_READ_SEEK                                     "unable to seek to %" PRIu64 " in file '%s'"
 
 #define STORAGE_ERROR_INFO                                          "unable to get info for path/file '%s'"
 #define STORAGE_ERROR_INFO_MISSING                                  "unable to get info for missing path/file '%s'"
 
-#define STORAGE_ERROR_LIST                                          "unable to list files for path '%s'"
-#define STORAGE_ERROR_LIST_MISSING                                  "unable to list files for missing path '%s'"
-
 #define STORAGE_ERROR_LIST_INFO                                     "unable to list file info for path '%s'"
 #define STORAGE_ERROR_LIST_INFO_MISSING                             "unable to list file info for missing path '%s'"
 
@@ -53,19 +60,12 @@ typedef String *StoragePathExpressionCallback(const String *expression, const St
 /***********************************************************************************************************************************
 Required interface functions
 ***********************************************************************************************************************************/
-// Does a file exist? This function is only for files, not paths.
-typedef struct StorageInterfaceExistsParam
-{
-    VAR_PARAM_HEADER;
-} StorageInterfaceExistsParam;
-
-typedef bool StorageInterfaceExists(void *thisVoid, const String *file, StorageInterfaceExistsParam param);
-
-#define storageInterfaceExistsP(thisVoid, file, ...)                                                                               \
-    STORAGE_COMMON_INTERFACE(thisVoid).exists(thisVoid, file, (StorageInterfaceExistsParam){VAR_PARAM_INIT, __VA_ARGS__})
-
-// ---------------------------------------------------------------------------------------------------------------------------------
-// Get information about a file
+// Get information about a file/link/path
+//
+// The level parameter controls the amount of information that will be returned. See the StorageInfo type and StorageInfoLevel enum
+// for details about information that must be provided at each level. The driver should only return the amount of information
+// requested even if more is available. All drivers must implement the storageInfoLevelExists and storageInfoLevelBasic levels. Only
+// drivers with the storageFeatureInfoDetail feature must implement the storageInfoLevelDetail level.
 typedef struct StorageInterfaceInfoParam
 {
     VAR_PARAM_HEADER;
@@ -74,25 +74,11 @@ typedef struct StorageInterfaceInfoParam
     bool followLink;
 } StorageInterfaceInfoParam;
 
-typedef StorageInfo StorageInterfaceInfo(void *thisVoid, const String *file, StorageInterfaceInfoParam param);
+typedef StorageInfo StorageInterfaceInfo(
+    void *thisVoid, const String *file, StorageInfoLevel level, StorageInterfaceInfoParam param);
 
-#define storageInterfaceInfoP(thisVoid, file, ...)                                                                                 \
-    STORAGE_COMMON_INTERFACE(thisVoid).info(thisVoid, file, (StorageInterfaceInfoParam){VAR_PARAM_INIT, __VA_ARGS__})
-
-// ---------------------------------------------------------------------------------------------------------------------------------
-// Get a list of files
-typedef struct StorageInterfaceListParam
-{
-    VAR_PARAM_HEADER;
-
-    // Regular expression used to filter the results
-    const String *expression;
-} StorageInterfaceListParam;
-
-typedef StringList *StorageInterfaceList(void *thisVoid, const String *path, StorageInterfaceListParam param);
-
-#define storageInterfaceListP(thisVoid, path, ...)                                                                                 \
-    STORAGE_COMMON_INTERFACE(thisVoid).list(thisVoid, path, (StorageInterfaceListParam){VAR_PARAM_INIT, __VA_ARGS__})
+#define storageInterfaceInfoP(thisVoid, file, level, ...)                                                                          \
+    STORAGE_COMMON_INTERFACE(thisVoid).info(thisVoid, file, level, (StorageInterfaceInfoParam){VAR_PARAM_INIT, __VA_ARGS__})
 
 // ---------------------------------------------------------------------------------------------------------------------------------
 // Create a file read object.  The file should not be opened immediately -- open() will be called on the IoRead interface when the
@@ -101,10 +87,12 @@ typedef struct StorageInterfaceNewReadParam
 {
     VAR_PARAM_HEADER;
 
-    // Is the file compressible?  This is useful when the file must be moved across a network and some temporary compression is
-    // helpful.
+    // Is the file compressible? This is used when the file must be moved across a network and temporary compression is helpful.
     bool compressible;
 
+    // Where to start reading in the file
+    const uint64_t offset;
+
     // Limit bytes read from the file. NULL for no limit.
     const Variant *limit;
 } StorageInterfaceNewReadParam;
@@ -141,12 +129,11 @@ typedef struct StorageInterfaceNewWriteParam
     bool syncFile;
     bool syncPath;
 
-    // Ensure the file written atomically.  If this is false it's OK to write atomically if that's all the storage supperts
-    // (e.g. S3).  Non-atomic writes are used in some places where there is a performance advantage and atomicity is not needed.
+    // Ensure the file is written atomically. If this is false it's OK to write atomically if that's all the storage supports
+    // (e.g. S3). Non-atomic writes are used in some places where there is a performance advantage and atomicity is not needed.
     bool atomic;
 
-    // Is the file compressible?  This is useful when the file must be moved across a network and some temporary compression is
-    // helpful.
+    // Is the file compressible?  This is used when the file must be moved across a network and temporary compression is helpful.
     bool compressible;
 } StorageInterfaceNewWriteParam;
 
@@ -157,17 +144,29 @@ typedef StorageWrite *StorageInterfaceNewWrite(void *thisVoid, const String *fil
 
 // ---------------------------------------------------------------------------------------------------------------------------------
 // Get info for a path and all paths/files in the path (does not recurse)
+//
+// See storageInterfaceInfoP() for usage of the level parameter.
 typedef struct StorageInterfaceInfoListParam
 {
     VAR_PARAM_HEADER;
+
+    // Regular expression used to filter the results. The expression is always checked in the callback passed to
+    // storageInterfaceInfoListP() so checking the expression in the driver is entirely optional. The driver should only use the
+    // expression if it can improve performance or limit network transfer.
+    //
+    // Partial matching of the expression is fine as long as nothing that should match is excluded, e.g. it is OK to prefix match
+    // using the prefix returned from regExpPrefix(). This may cause extra results to be sent to the callback but won't exclude
+    // anything that matches the expression exactly.
+    const String *expression;
 } StorageInterfaceInfoListParam;
 
 typedef bool StorageInterfaceInfoList(
-    void *thisVoid, const String *path, StorageInfoListCallback callback, void *callbackData, StorageInterfaceInfoListParam param);
+    void *thisVoid, const String *path, StorageInfoLevel level, void (*callback)(void *callbackData, const StorageInfo *info),
+    void *callbackData, StorageInterfaceInfoListParam param);
 
-#define storageInterfaceInfoListP(thisVoid, path, callback, callbackData, ...)                                                     \
+#define storageInterfaceInfoListP(thisVoid, path, level, callback, callbackData, ...)                                              \
     STORAGE_COMMON_INTERFACE(thisVoid).infoList(                                                                                   \
-        thisVoid, path, callback, callbackData, (StorageInterfaceInfoListParam){VAR_PARAM_INIT, __VA_ARGS__})
+        thisVoid, path, level, callback, callbackData, (StorageInterfaceInfoListParam){VAR_PARAM_INIT, __VA_ARGS__})
 
 // ---------------------------------------------------------------------------------------------------------------------------------
 // Remove a path (and optionally recurse)
@@ -200,7 +199,7 @@ typedef void StorageInterfaceRemove(void *thisVoid, const String *file, StorageI
 /***********************************************************************************************************************************
 Optional interface functions
 ***********************************************************************************************************************************/
-// Move a file atomically
+// Move a path/file atomically
 typedef struct StorageInterfaceMoveParam
 {
     VAR_PARAM_HEADER;
@@ -227,18 +226,6 @@ typedef void StorageInterfacePathCreate(
     STORAGE_COMMON_INTERFACE(thisVoid).pathCreate(                                                                                 \
         thisVoid, path, errorOnExists, noParentCreate, mode, (StorageInterfacePathCreateParam){VAR_PARAM_INIT, __VA_ARGS__})
 
-// ---------------------------------------------------------------------------------------------------------------------------------
-// Does a path exist?
-typedef struct StorageInterfacePathExistsParam
-{
-    VAR_PARAM_HEADER;
-} StorageInterfacePathExistsParam;
-
-typedef bool StorageInterfacePathExists(void *thisVoid, const String *path, StorageInterfacePathExistsParam param);
-
-#define storageInterfacePathExistsP(thisVoid, path, ...)                                                                           \
-    STORAGE_COMMON_INTERFACE(thisVoid).pathExists(thisVoid, path, (StorageInterfacePathExistsParam){VAR_PARAM_INIT, __VA_ARGS__})
-
 // ---------------------------------------------------------------------------------------------------------------------------------
 // Sync a path
 typedef struct StorageInterfacePathSyncParam
@@ -252,7 +239,22 @@ typedef void StorageInterfacePathSync(void *thisVoid, const String *path, Storag
     STORAGE_COMMON_INTERFACE(thisVoid).pathSync(thisVoid, path, (StorageInterfacePathSyncParam){VAR_PARAM_INIT, __VA_ARGS__})
 
 /***********************************************************************************************************************************
-Constructor
+Storage type and helper function struct
+
+An array of this struct must be passed to storageHelperInit() to enable storage drivers other than built-in Posix.
+***********************************************************************************************************************************/
+typedef Storage *(*StorageHelperFunction)(unsigned int repoIdx, bool write, StoragePathExpressionCallback pathExpressionCallback);
+
+typedef struct StorageHelper
+{
+    StringId type;                                                  // StringId that identifies the storage driver
+    StorageHelperFunction helper;                                   // Function that creates the storage
+} StorageHelper;
+
+#define STORAGE_END_HELPER                                          {.type = 0}
+
+/***********************************************************************************************************************************
+Constructors
 ***********************************************************************************************************************************/
 typedef struct StorageInterface
 {
@@ -260,10 +262,8 @@ typedef struct StorageInterface
     uint64_t feature;
 
     // Required functions
-    StorageInterfaceExists *exists;
     StorageInterfaceInfo *info;
     StorageInterfaceInfoList *infoList;
-    StorageInterfaceList *list;
     StorageInterfaceNewRead *newRead;
     StorageInterfaceNewWrite *newWrite;
     StorageInterfacePathRemove *pathRemove;
@@ -272,7 +272,6 @@ typedef struct StorageInterface
     // Optional functions
     StorageInterfaceMove *move;
     StorageInterfacePathCreate *pathCreate;
-    StorageInterfacePathExists *pathExists;
     StorageInterfacePathSync *pathSync;
 } StorageInterface;
 
@@ -280,7 +279,7 @@ typedef struct StorageInterface
     storageNew(type, path, modeFile, modePath, write, pathExpressionFunction, driver, (StorageInterface){__VA_ARGS__})
 
 Storage *storageNew(
-    const String *type, const String *path, mode_t modeFile, mode_t modePath, bool write,
+    StringId type, const String *path, mode_t modeFile, mode_t modePath, bool write,
     StoragePathExpressionCallback pathExpressionFunction, void *driver, StorageInterface interface);
 
 /***********************************************************************************************************************************
@@ -302,8 +301,26 @@ typedef struct StorageCommon
 /***********************************************************************************************************************************
 Getters/Setters
 ***********************************************************************************************************************************/
-void *storageDriver(const Storage *this);
-StorageInterface storageInterface(const Storage *this);
+typedef struct StoragePub
+{
+    StringId type;                                                  // Storage type
+    void *driver;                                                   // Storage driver
+    StorageInterface interface;                                     // Storage interface
+} StoragePub;
+
+// Storage driver
+__attribute__((always_inline)) static inline void *
+storageDriver(const Storage *const this)
+{
+    return THIS_PUB(Storage)->driver;
+}
+
+// Storage interface
+__attribute__((always_inline)) static inline StorageInterface
+storageInterface(const Storage *const this)
+{
+    return THIS_PUB(Storage)->interface;
+}
 
 /***********************************************************************************************************************************
 Macros for function logging
