@@ -48,6 +48,7 @@ sub new
         $self->{strCommandMain},
         $self->{strPgSqlBin},
         $self->{strTestPath},
+        $self->{strRepoPath},
     ) =
         logDebugParam
         (
@@ -60,6 +61,7 @@ sub new
             {name => 'strCommandMain', trace => true},
             {name => 'strPgSqlBin', required => false, trace => true},
             {name => 'strTestPath', trace => true},
+            {name => 'strRepoPath', trace => true},
         );
 
     # Initialize the test log
@@ -167,7 +169,7 @@ sub supplementalAdd
         close($hFile);
     }
 
-    # Only ouput when the content of this file has changed
+    # Only output when the content of this file has changed
     if (!defined($hyExpectCache->{$strFileName}) || $hyExpectCache->{$strFileName} ne $strContent)
     {
         # $hyExpectCache->{$strFileName} = $strContent;
@@ -366,6 +368,9 @@ sub regExpReplaceAll
     # Replace the test path
     $strLine =~ s/$self->{strTestPath}/[TEST_PATH]/g;
 
+    # Replace the repo path
+    $strLine =~ s/$self->{strRepoPath}/[REPO_PATH]/g;
+
     # Replace the pgsql path (if exists)
     if (defined($self->{strPgSqlBin}))
     {
@@ -416,6 +421,8 @@ sub regExpReplaceAll
     $strLine = $self->regExpReplace($strLine, 'USER', '[^ ]+\@db\-primary', '^[^\@]+');
     $strLine = $self->regExpReplace($strLine, 'USER', '[\( ]{1}' . TEST_USER . '[\,\)]{1}', TEST_USER);
 
+    $strLine = $self->regExpReplace($strLine, 'EXEC-ID', '--exec-id=[^ ]+', '[^=]+$', false);
+
     $strLine = $self->regExpReplace($strLine, 'CIPHER-PASS', '^cipher\-pass\=.+$', '[^\=]+$');
 
     $strLine = $self->regExpReplace($strLine, 'PORT', 'db[1-9]{0,1}-port=[0-9]+', '[0-9]+$');
