@@ -15,6 +15,7 @@ use Exporter qw(import);
 
 use pgBackRestDoc::Common::Exception;
 use pgBackRestDoc::Common::Log;
+use pgBackRestDoc::Common::String;
 
 use pgBackRestTest::Common::DbVersion;
 
@@ -29,16 +30,14 @@ use constant VM_DB_TEST                                             => 'db-test'
     push @EXPORT, qw(VM_DB_TEST);
 use constant VMDEF_DEBUG_INTEGRATION                                => 'debug-integration';
     push @EXPORT, qw(VMDEF_DEBUG_INTEGRATION);
-use constant VM_CONTROL_MASTER                                      => 'control-master';
-    push @EXPORT, qw(VM_CONTROL_MASTER);
+use constant VM_CONTROL_MTR                                         => 'control-mtr';
+    push @EXPORT, qw(VM_CONTROL_MTR);
 # Will coverage testing be run for C?
 use constant VMDEF_COVERAGE_C                                       => 'coverage-c';
 use constant VM_DEPRECATED                                          => 'deprecated';
     push @EXPORT, qw(VM_DEPRECATED);
 use constant VM_IMAGE                                               => 'image';
     push @EXPORT, qw(VM_IMAGE);
-use constant VM_OS                                                  => 'os';
-    push @EXPORT, qw(VM_OS);
 use constant VM_OS_BASE                                             => 'os-base';
     push @EXPORT, qw(VM_OS_BASE);
 use constant VM_OS_REPO                                             => 'os-repo';
@@ -62,19 +61,11 @@ use constant VM_OS_BASE_DEBIAN                                      => 'debian';
 use constant VM_OS_BASE_RHEL                                        => 'rhel';
     push @EXPORT, qw(VM_OS_BASE_RHEL);
 
-####################################################################################################################################
-# Valid OS list
-####################################################################################################################################
-use constant VM_OS_CENTOS                                           => 'centos';
-    push @EXPORT, qw(VM_OS_CENTOS);
-use constant VM_OS_DEBIAN                                           => 'debian';
-    push @EXPORT, qw(VM_OS_DEBIAN);
-use constant VM_OS_UBUNTU                                           => 'ubuntu';
-    push @EXPORT, qw(VM_OS_DEBIAN);
-
 ####################################################################################################################################
 # Valid architecture list
 ####################################################################################################################################
+use constant VM_ARCH_AARCH64                                        => 'aarch64';
+    push @EXPORT, qw(VM_ARCH_AARCH64);
 use constant VM_ARCH_I386                                           => 'i386';
     push @EXPORT, qw(VM_ARCH_I386);
 use constant VM_ARCH_AMD64                                          => 'amd64';
@@ -89,45 +80,33 @@ use constant VM_ALL                                                 => 'all';
 use constant VM_NONE                                                => 'none';
     push @EXPORT, qw(VM_NONE);
 
-use constant VM_CO6                                                 => 'co6';
-    push @EXPORT, qw(VM_CO6);
-use constant VM_CO7                                                 => 'co7';
-    push @EXPORT, qw(VM_CO7);
-use constant VM_F32                                                 => 'f32';
-    push @EXPORT, qw(VM_F32);
-use constant VM_U12                                                 => 'u12';
-    push @EXPORT, qw(VM_U12);
-use constant VM_U14                                                 => 'u14';
-    push @EXPORT, qw(VM_U14);
-use constant VM_U16                                                 => 'u16';
-    push @EXPORT, qw(VM_U16);
+use constant VM_RH7                                                 => 'rh7';
+    push @EXPORT, qw(VM_RH7);
+use constant VM_RH8                                                 => 'rh8';
+    push @EXPORT, qw(VM_RH8);
+use constant VM_F33                                                 => 'f33';
+    push @EXPORT, qw(VM_F33);
 use constant VM_U18                                                 => 'u18';
     push @EXPORT, qw(VM_U18);
-use constant VM_D8                                                  => 'd8';
-    push @EXPORT, qw(VM_D8);
+use constant VM_U20                                                 => 'u20';
+    push @EXPORT, qw(VM_U20);
 use constant VM_D9                                                  => 'd9';
     push @EXPORT, qw(VM_D9);
 
 # Defines the vm that will be used for expect testing
-use constant VM_EXPECT                                              => VM_CO7;
+use constant VM_EXPECT                                              => VM_RH7;
     push @EXPORT, qw(VM_EXPECT);
 
-# Defines the host VM (the VM that the containers run in)
-use constant VM_HOST_DEFAULT                                        => VM_U18;
-    push @EXPORT, qw(VM_HOST_DEFAULT);
-
 # VM aliases for run matrices (numbered oldest to newest)
-use constant VM1                                                    => VM_CO6;
-    push @EXPORT, qw(VM1);
-use constant VM2                                                    => VM_U12;
+use constant VM2                                                    => VM_D9;
     push @EXPORT, qw(VM2);
-use constant VM3                                                    => VM_CO7;
+use constant VM3                                                    => VM_RH7;
     push @EXPORT, qw(VM3);
-use constant VM4                                                    => VM_U18;
+use constant VM4                                                    => VM_U20;
     push @EXPORT, qw(VM4);
 
 # List of default test VMs
-use constant VM_LIST                                                => (VM2, VM1, VM3, VM4);
+use constant VM_LIST                                                => (VM2, VM3, VM4);
     push @EXPORT, qw(VM_LIST);
 
 my $oyVm =
@@ -136,7 +115,6 @@ my $oyVm =
     &VM_NONE =>
     {
         &VM_OS_BASE => VM_OS_BASE_DEBIAN,
-        &VM_OS => VM_OS_UBUNTU,
         &VM_ARCH => VM_ARCH_AMD64,
         &VMDEF_COVERAGE_C => true,
         &VMDEF_PGSQL_BIN => '/usr/lib/postgresql/{[version]}/bin',
@@ -154,43 +132,10 @@ my $oyVm =
         ],
     },
 
-    # CentOS 6
-    &VM_CO6 =>
+    # RHEL 7
+    &VM_RH7 =>
     {
         &VM_OS_BASE => VM_OS_BASE_RHEL,
-        &VM_OS => VM_OS_CENTOS,
-        &VM_IMAGE => 'centos:6',
-        &VM_ARCH => VM_ARCH_AMD64,
-        &VMDEF_PGSQL_BIN => '/usr/pgsql-{[version]}/bin',
-
-        &VMDEF_WITH_ZST => true,
-
-        &VM_DB =>
-        [
-            PG_VERSION_91,
-            PG_VERSION_92,
-            PG_VERSION_95,
-            PG_VERSION_96,
-            PG_VERSION_10,
-            PG_VERSION_11,
-            PG_VERSION_12,
-            PG_VERSION_13,
-        ],
-
-        &VM_DB_TEST =>
-        [
-            PG_VERSION_91,
-            PG_VERSION_92,
-            PG_VERSION_95,
-            PG_VERSION_10,
-        ],
-    },
-
-    # CentOS 7
-    &VM_CO7 =>
-    {
-        &VM_OS_BASE => VM_OS_BASE_RHEL,
-        &VM_OS => VM_OS_CENTOS,
         &VM_IMAGE => 'centos:7',
         &VM_ARCH => VM_ARCH_AMD64,
         &VMDEF_PGSQL_BIN => '/usr/pgsql-{[version]}/bin',
@@ -200,8 +145,6 @@ my $oyVm =
 
         &VM_DB =>
         [
-            PG_VERSION_92,
-            PG_VERSION_94,
             PG_VERSION_95,
             PG_VERSION_96,
             PG_VERSION_10,
@@ -216,12 +159,11 @@ my $oyVm =
         ],
     },
 
-    # Fedora 32
-    &VM_F32 =>
+    # Fedora 33
+    &VM_F33 =>
     {
         &VM_OS_BASE => VM_OS_BASE_RHEL,
-        &VM_OS => VM_OS_CENTOS,
-        &VM_IMAGE => 'fedora:32',
+        &VM_IMAGE => 'fedora:33',
         &VM_ARCH => VM_ARCH_AMD64,
         &VMDEF_PGSQL_BIN => '/usr/pgsql-{[version]}/bin',
         &VMDEF_COVERAGE_C => true,
@@ -231,11 +173,11 @@ my $oyVm =
 
         &VM_DB =>
         [
-            PG_VERSION_95,
             PG_VERSION_96,
             PG_VERSION_10,
             PG_VERSION_11,
             PG_VERSION_12,
+            PG_VERSION_13,
         ],
 
         &VM_DB_TEST =>
@@ -244,156 +186,25 @@ my $oyVm =
         ],
     },
 
-    # Debian 8
-    &VM_D8 =>
-    {
-        &VM_OS_BASE => VM_OS_BASE_DEBIAN,
-        &VM_OS => VM_OS_DEBIAN,
-        &VM_OS_REPO => 'jessie',
-        &VM_IMAGE => 'debian:8',
-        &VM_ARCH => VM_ARCH_AMD64,
-        &VMDEF_PGSQL_BIN => '/usr/lib/postgresql/{[version]}/bin',
-
-        &VM_DB =>
-        [
-            PG_VERSION_84,
-            PG_VERSION_90,
-            PG_VERSION_91,
-            PG_VERSION_92,
-            PG_VERSION_93,
-            PG_VERSION_94,
-            PG_VERSION_95,
-            PG_VERSION_96,
-            PG_VERSION_10,
-            PG_VERSION_11,
-        ],
-
-        &VM_DB_TEST =>
-        [
-            PG_VERSION_95,
-        ],
-    },
-
     # Debian 9
     &VM_D9 =>
     {
         &VM_OS_BASE => VM_OS_BASE_DEBIAN,
-        &VM_OS => VM_OS_DEBIAN,
         &VM_OS_REPO => 'stretch',
-        &VM_IMAGE => 'debian:9',
-        &VM_ARCH => VM_ARCH_AMD64,
-        &VMDEF_PGSQL_BIN => '/usr/lib/postgresql/{[version]}/bin',
-
-        &VM_DB_TEST =>
-        [
-            PG_VERSION_92,
-            PG_VERSION_93,
-            PG_VERSION_94,
-            PG_VERSION_95,
-            PG_VERSION_96,
-            PG_VERSION_10,
-            PG_VERSION_11,
-            PG_VERSION_12,
-        ],
-
-        &VM_DB_TEST =>
-        [
-            PG_VERSION_96,
-        ],
-    },
-
-    # Ubuntu 12.04
-    &VM_U12 =>
-    {
-        &VM_OS_BASE => VM_OS_BASE_DEBIAN,
-        &VM_OS => VM_OS_UBUNTU,
-        &VM_OS_REPO => 'precise',
-        &VM_IMAGE => 'i386/ubuntu:12.04',
+        &VM_IMAGE => 'i386/debian:9',
         &VM_ARCH => VM_ARCH_I386,
         &VMDEF_PGSQL_BIN => '/usr/lib/postgresql/{[version]}/bin',
-        &VMDEF_WITH_LZ4 => false,
 
         &VM_DB =>
         [
-            PG_VERSION_83,
-            PG_VERSION_84,
             PG_VERSION_90,
             PG_VERSION_91,
             PG_VERSION_92,
-            PG_VERSION_93,
         ],
 
         &VM_DB_TEST =>
         [
-            PG_VERSION_83,
-            PG_VERSION_84,
             PG_VERSION_90,
-            PG_VERSION_93,
-        ],
-    },
-
-    # Ubuntu 14.04
-    &VM_U14 =>
-    {
-        &VM_OS_BASE => VM_OS_BASE_DEBIAN,
-        &VM_OS => VM_OS_UBUNTU,
-        &VM_OS_REPO => 'trusty',
-        &VM_IMAGE => 'ubuntu:14.04',
-        &VM_ARCH => VM_ARCH_AMD64,
-        &VMDEF_PGSQL_BIN => '/usr/lib/postgresql/{[version]}/bin',
-
-        &VM_DB =>
-        [
-            PG_VERSION_84,
-            PG_VERSION_90,
-            PG_VERSION_91,
-            PG_VERSION_92,
-            PG_VERSION_93,
-            PG_VERSION_94,
-            PG_VERSION_95,
-            PG_VERSION_96,
-            PG_VERSION_10,
-            PG_VERSION_11,
-            PG_VERSION_12,
-            PG_VERSION_13,
-        ],
-
-        &VM_DB =>
-        [
-            PG_VERSION_94,
-        ],
-    },
-
-    # Ubuntu 16.04
-    &VM_U16 =>
-    {
-        &VM_OS_BASE => VM_OS_BASE_DEBIAN,
-        &VM_OS => VM_OS_UBUNTU,
-        &VM_OS_REPO => 'xenial',
-        &VM_IMAGE => 'ubuntu:16.04',
-        &VM_ARCH => VM_ARCH_AMD64,
-        &VMDEF_PGSQL_BIN => '/usr/lib/postgresql/{[version]}/bin',
-
-        &VMDEF_WITH_BACKTRACE => true,
-
-        &VM_DB =>
-        [
-            PG_VERSION_91,
-            PG_VERSION_92,
-            PG_VERSION_93,
-            PG_VERSION_94,
-            PG_VERSION_95,
-            PG_VERSION_96,
-            PG_VERSION_10,
-            PG_VERSION_11,
-            PG_VERSION_12,
-            PG_VERSION_13,
-        ],
-
-        &VM_DB_TEST =>
-        [
-            PG_VERSION_94,
-            PG_VERSION_95,
         ],
     },
 
@@ -401,7 +212,6 @@ my $oyVm =
     &VM_U18 =>
     {
         &VM_OS_BASE => VM_OS_BASE_DEBIAN,
-        &VM_OS => VM_OS_UBUNTU,
         &VM_OS_REPO => 'bionic',
         &VM_IMAGE => 'ubuntu:18.04',
         &VM_ARCH => VM_ARCH_AMD64,
@@ -413,8 +223,6 @@ my $oyVm =
 
         &VM_DB =>
         [
-            PG_VERSION_83,
-            PG_VERSION_84,
             PG_VERSION_90,
             PG_VERSION_91,
             PG_VERSION_92,
@@ -430,12 +238,59 @@ my $oyVm =
 
         &VM_DB_TEST =>
         [
+            PG_VERSION_93,
             PG_VERSION_94,
+            PG_VERSION_95,
+            PG_VERSION_10,
             PG_VERSION_11,
             PG_VERSION_12,
             PG_VERSION_13,
         ],
     },
+
+    # Ubuntu 20.04
+    &VM_U20 =>
+    {
+        &VM_OS_BASE => VM_OS_BASE_DEBIAN,
+        &VM_OS_REPO => 'focal',
+        &VM_IMAGE => 'ubuntu:20.04',
+        &VM_ARCH => VM_ARCH_AMD64,
+        &VMDEF_COVERAGE_C => true,
+        &VMDEF_PGSQL_BIN => '/usr/lib/postgresql/{[version]}/bin',
+
+        &VMDEF_WITH_BACKTRACE => true,
+        &VMDEF_WITH_ZST => true,
+
+        &VM_DB =>
+        [
+            PG_VERSION_90,
+            PG_VERSION_91,
+            PG_VERSION_92,
+            PG_VERSION_93,
+            PG_VERSION_94,
+            PG_VERSION_95,
+            PG_VERSION_96,
+            PG_VERSION_10,
+            PG_VERSION_11,
+            PG_VERSION_12,
+            PG_VERSION_13,
+            PG_VERSION_14,
+        ],
+
+        &VM_DB_TEST =>
+        [
+            PG_VERSION_91,
+            PG_VERSION_92,
+            PG_VERSION_93,
+            PG_VERSION_94,
+            PG_VERSION_95,
+            PG_VERSION_10,
+            PG_VERSION_11,
+            PG_VERSION_12,
+            PG_VERSION_13,
+            PG_VERSION_14,
+        ],
+    },
 };
 
 ####################################################################################################################################
@@ -565,11 +420,34 @@ sub vmArchBits
 {
     my $strVm = shift;
 
-    return ($oyVm->{$strVm}{&VM_ARCH} eq VM_ARCH_AMD64 ? 64 : 32);
+    return ($oyVm->{$strVm}{&VM_ARCH} eq VM_ARCH_I386 ? 32 : 64);
 }
 
 push @EXPORT, qw(vmArchBits);
 
+####################################################################################################################################
+# Get host architecture
+####################################################################################################################################
+my $strHostArch = undef;
+
+sub hostArch
+{
+    if (!defined($strHostArch))
+    {
+        $strHostArch = trim(`uname -m`);
+
+        # Mac M1 reports arm64 but we generally need aarch64 (which Linux reports)
+        if ($strHostArch eq 'arm64')
+        {
+            $strHostArch = 'aarch64';
+        }
+    }
+
+    return $strHostArch;
+}
+
+push @EXPORT, qw(hostArch);
+
 ####################################################################################################################################
 # Does the VM support libbacktrace?
 ####################################################################################################################################
