@@ -55,6 +55,7 @@ sub new
     my $self = $class->SUPER::new(
         {
             strImage => containerRepo() . ':' . testRunGet()->vm() . "-test",
+            bTls => $oParam->{bTls},
             strBackupDestination => $$oParam{strBackupDestination},
             oLogTest => $$oParam{oLogTest},
             bSynthetic => true,
@@ -98,8 +99,7 @@ sub dbFileCreate
     # Get tablespace path if this is a tablespace
     my $strPgPath;
 
-    if ($$oManifestRef{&MANIFEST_SECTION_BACKUP_DB}{&MANIFEST_KEY_DB_VERSION} >= PG_VERSION_90 &&
-        index($strTarget, DB_PATH_PGTBLSPC . '/') == 0)
+    if (index($strTarget, DB_PATH_PGTBLSPC . '/') == 0)
     {
         my $iCatalog = ${$oManifestRef}{&MANIFEST_SECTION_BACKUP_DB}{&MANIFEST_KEY_CATALOG};
 
@@ -184,9 +184,8 @@ sub manifestDbPathGet
     # Determine the manifest key
     my $strDbPath = ${$oManifestRef}{&MANIFEST_SECTION_BACKUP_TARGET}{$strTarget}{&MANIFEST_SUBKEY_PATH};
 
-    # If target is a tablespace and pg version >= 9.0
-    if (defined(${$oManifestRef}{&MANIFEST_SECTION_BACKUP_TARGET}{$strTarget}{&MANIFEST_SUBKEY_TABLESPACE_ID}) &&
-        $$oManifestRef{&MANIFEST_SECTION_BACKUP_DB}{&MANIFEST_KEY_DB_VERSION} >= PG_VERSION_90)
+    # If target is a tablespace
+    if (defined(${$oManifestRef}{&MANIFEST_SECTION_BACKUP_TARGET}{$strTarget}{&MANIFEST_SUBKEY_TABLESPACE_ID}))
     {
         my $iCatalog = ${$oManifestRef}{&MANIFEST_SECTION_BACKUP_DB}{&MANIFEST_KEY_CATALOG};
 
@@ -213,7 +212,7 @@ sub manifestFileCreate
     my $strChecksum = shift;
     my $lTime = shift;
     my $strMode = shift;
-    my $bMaster = shift;
+    my $bPrimary = shift;
     my $strChecksumPageError = shift;
 
     # Determine the manifest key
@@ -231,8 +230,6 @@ sub manifestFileCreate
         sprintf('%04o', S_IMODE($oStat->mode));
     ${$oManifestRef}{&MANIFEST_SECTION_TARGET_FILE}{$strManifestKey}{&MANIFEST_SUBKEY_TIMESTAMP} = $oStat->mtime;
     ${$oManifestRef}{&MANIFEST_SECTION_TARGET_FILE}{$strManifestKey}{&MANIFEST_SUBKEY_SIZE} = $oStat->size;
-    ${$oManifestRef}{&MANIFEST_SECTION_TARGET_FILE}{$strManifestKey}{&MANIFEST_SUBKEY_MASTER} =
-        defined($bMaster) ? ($bMaster ? JSON::PP::true : JSON::PP::false) : JSON::PP::false;
     delete(${$oManifestRef}{&MANIFEST_SECTION_TARGET_FILE}{$strManifestKey}{&MANIFEST_SUBKEY_REFERENCE});
 
     my $bChecksumPage = defined($strChecksumPageError) ? false : (isChecksumPage($strManifestKey) ? true : undef);
@@ -298,9 +295,8 @@ sub manifestKeyGet
     # Determine the manifest key
     my $strManifestKey = $strTarget;
 
-    # If target is a tablespace and pg version >= 9.0
-    if (defined(${$oManifestRef}{&MANIFEST_SECTION_BACKUP_TARGET}{$strTarget}{&MANIFEST_SUBKEY_TABLESPACE_ID}) &&
-        $$oManifestRef{&MANIFEST_SECTION_BACKUP_DB}{&MANIFEST_KEY_DB_VERSION} >= PG_VERSION_90)
+    # If target is a tablespace
+    if (defined(${$oManifestRef}{&MANIFEST_SECTION_BACKUP_TARGET}{$strTarget}{&MANIFEST_SUBKEY_TABLESPACE_ID}))
     {
         my $iCatalog = ${$oManifestRef}{&MANIFEST_SECTION_BACKUP_DB}{&MANIFEST_KEY_CATALOG};
 
@@ -324,7 +320,7 @@ sub manifestLinkCreate
     my $strPath = shift;
     my $strFile = shift;
     my $strDestination = shift;
-    my $bMaster = shift;
+    my $bPrimary = shift;
 
     # Determine the manifest key
     my $strManifestKey = $self->manifestKeyGet($oManifestRef, $strPath, $strFile);
@@ -369,8 +365,6 @@ sub manifestLinkCreate
         ${$oManifestRef}{$strSection}{$strManifestKey}{&MANIFEST_SUBKEY_SIZE} = $oStat->size;
         ${$oManifestRef}{$strSection}{$strManifestKey}{&MANIFEST_SUBKEY_TIMESTAMP} = $oStat->mtime;
         (${$oManifestRef}{$strSection}{$strManifestKey}{&MANIFEST_SUBKEY_CHECKSUM}) = storageTest()->hashSize($strDestinationFile);
-        ${$oManifestRef}{$strSection}{$strManifestKey}{&MANIFEST_SUBKEY_MASTER} =
-            defined($bMaster) ? ($bMaster ? JSON::PP::true : JSON::PP::false) : JSON::PP::false;
 
         ${$oManifestRef}{&MANIFEST_SECTION_BACKUP_TARGET}{$strManifestKey}{&MANIFEST_SUBKEY_FILE} =
             basename(${$oManifestRef}{&MANIFEST_SECTION_BACKUP_TARGET}{$strManifestKey}{&MANIFEST_SUBKEY_PATH});
@@ -565,15 +559,11 @@ sub manifestTablespaceCreate
     # Create the tablespace path if it does not exist
     my $strTablespacePath = $strLinkPath;
     my $strPathTarget = $strTarget;
+    my $iCatalog = ${$oManifestRef}{&MANIFEST_SECTION_BACKUP_DB}{&MANIFEST_KEY_CATALOG};
+    my $strTablespaceId = 'PG_' . ${$oManifestRef}{&MANIFEST_SECTION_BACKUP_DB}{&MANIFEST_KEY_DB_VERSION} . "_${iCatalog}";
 
-    if ($$oManifestRef{&MANIFEST_SECTION_BACKUP_DB}{&MANIFEST_KEY_DB_VERSION} >= PG_VERSION_90)
-    {
-        my $iCatalog = ${$oManifestRef}{&MANIFEST_SECTION_BACKUP_DB}{&MANIFEST_KEY_CATALOG};
-        my $strTablespaceId = 'PG_' . ${$oManifestRef}{&MANIFEST_SECTION_BACKUP_DB}{&MANIFEST_KEY_DB_VERSION} . "_${iCatalog}";
-
-        $strTablespacePath .= "/${strTablespaceId}";
-        $strPathTarget .= "/${strTablespaceId}";
-    }
+    $strTablespacePath .= "/${strTablespaceId}";
+    $strPathTarget .= "/${strTablespaceId}";
 
     if (!-e $strTablespacePath)
     {
@@ -665,8 +655,7 @@ sub dbPathCreate
     my $strFinalPath = ${$oManifestRef}{&MANIFEST_SECTION_BACKUP_TARGET}{$strTarget}{&MANIFEST_SUBKEY_PATH};
 
     # Get tablespace path if this is a tablespace
-    if ($$oManifestRef{&MANIFEST_SECTION_BACKUP_DB}{&MANIFEST_KEY_DB_VERSION} >= PG_VERSION_90 &&
-        index($strTarget, DB_PATH_PGTBLSPC . '/') == 0)
+    if (index($strTarget, DB_PATH_PGTBLSPC . '/') == 0)
     {
         my $iCatalog = ${$oManifestRef}{&MANIFEST_SECTION_BACKUP_DB}{&MANIFEST_KEY_CATALOG};
 
