@@ -62,6 +62,7 @@ sub new
     my $self = $class->SUPER::new(
         {
             strImage => containerRepo() . ':' . testRunGet()->vm() . "-test",
+            bTls => $oParam->{bTls},
             strBackupDestination => $$oParam{strBackupDestination},
             oLogTest => $$oParam{oLogTest},
             bStandby => $$oParam{bStandby},
@@ -388,9 +389,9 @@ sub clusterStart
     my $bArchiveEnabled = defined($$hParam{bArchiveEnabled}) ? $$hParam{bArchiveEnabled} : true;
 
     # Make sure postgres is not running
-    if (-e $self->dbBasePath() . '/postmaster.pid')
+    if (-e $self->dbBasePath() . '/' . DB_FILE_POSTMTRPID)
     {
-        confess 'postmaster.pid exists';
+        confess DB_FILE_POSTMTRPID . ' exists';
     }
 
     # Create the archive command
@@ -428,9 +429,13 @@ sub clusterStart
         $strCommand .= " -c archive_command=true";
     }
 
-    if ($self->pgVersion() >= PG_VERSION_90)
+    $strCommand .= ' -c wal_level=hot_standby -c hot_standby=' . ($bHotStandby ? 'on' : 'off');
+
+    # Force parallel mode on to make sure we are disabling it and there are no issues. This is important for testing that 9.6
+    # works since pg_stop_backup() is marked parallel safe and will error if run in a worker.
+    if ($self->pgVersion() >= PG_VERSION_96)
     {
-        $strCommand .= ' -c wal_level=hot_standby -c hot_standby=' . ($bHotStandby ? 'on' : 'off');
+         $strCommand .= " -c force_parallel_mode='on' -c max_parallel_workers_per_gather=2";
     }
 
     $strCommand .=
@@ -466,16 +471,17 @@ sub clusterStop
     # Disconnect user session
     $self->sqlDisconnect();
 
-    # Grep for errors in postgresql.log - this is done first because we want to ignore any errors that happen during shutdown
+    # Grep for errors in postgresql.log - this is done first because we want to ignore any errors that happen during shutdown.
     if (!$bIgnoreLogError && storageTest()->exists($self->pgLogFile()))
     {
         $self->executeSimple(
-            'grep -v "FATAL\:  57P03\: the database system is starting up" ' . $self->pgLogFile() . ' | grep "ERROR\|FATAL"',
+            'grep -v "FATAL\:  57P03\: the database system is (starting up|not yet accepting connections|"
+                "not accepting connections)" ' . $self->pgLogFile() . ' | grep "ERROR\|FATAL"',
             {iExpectedExitStatus => 1});
     }
 
-    # If postmaster process is running then stop the cluster
-    if (-e $self->dbBasePath() . '/' . DB_FILE_POSTMASTERPID)
+    # If pg process is running then stop the cluster
+    if (-e $self->dbBasePath() . '/' . DB_FILE_POSTMTRPID)
     {
         $self->executeSimple($self->pgBinPath() . '/pg_ctl stop -D ' . $self->dbBasePath() . ' -w -s -m fast');
     }
