@@ -32,6 +32,7 @@ use pgBackRestTest::Env::Host::HostBaseTest;
 use pgBackRestTest::Env::Host::HostDbCommonTest;
 use pgBackRestTest::Env::Host::HostDbTest;
 use pgBackRestTest::Env::Host::HostDbSyntheticTest;
+use pgBackRestTest::Env::Host::HostGcsTest;
 use pgBackRestTest::Env::Host::HostS3Test;
 
 ####################################################################################################################################
@@ -66,6 +67,10 @@ sub setup
     {
         $oHostObject = new pgBackRestTest::Env::Host::HostAzureTest();
     }
+    elsif ($oConfigParam->{strStorage} eq GCS)
+    {
+        $oHostObject = new pgBackRestTest::Env::Host::HostGcsTest();
+    }
 
     # Get host group
     my $oHostGroup = hostGroupGet();
@@ -83,7 +88,7 @@ sub setup
 
         $oHostBackup = new pgBackRestTest::Env::Host::HostBackupTest(
             {strBackupDestination => $strBackupDestination, bSynthetic => $bSynthetic, oLogTest => $oLogTest,
-                bRepoLocal => $oConfigParam->{strStorage} eq POSIX, bRepoEncrypt => $bRepoEncrypt});
+                bRepoLocal => $oConfigParam->{strStorage} eq POSIX, bRepoEncrypt => $bRepoEncrypt, bTls => $oConfigParam->{bTls}});
         $oHostGroup->hostAdd($oHostBackup);
     }
     else
@@ -99,13 +104,13 @@ sub setup
     {
         $oHostDbPrimary = new pgBackRestTest::Env::Host::HostDbSyntheticTest(
             {strBackupDestination => $strBackupDestination, oLogTest => $oLogTest,
-                bRepoLocal => $oConfigParam->{strStorage} eq POSIX, bRepoEncrypt => $bRepoEncrypt});
+                bRepoLocal => $oConfigParam->{strStorage} eq POSIX, bRepoEncrypt => $bRepoEncrypt, bTls => $oConfigParam->{bTls}});
     }
     else
     {
         $oHostDbPrimary = new pgBackRestTest::Env::Host::HostDbTest(
             {strBackupDestination => $strBackupDestination, oLogTest => $oLogTest, bRepoLocal =>
-                $oConfigParam->{strStorage} eq POSIX, bRepoEncrypt => $bRepoEncrypt});
+                $oConfigParam->{strStorage} eq POSIX, bRepoEncrypt => $bRepoEncrypt, bTls => $oConfigParam->{bTls}});
     }
 
     $oHostGroup->hostAdd($oHostDbPrimary);
@@ -117,37 +122,43 @@ sub setup
     {
         $oHostDbStandby = new pgBackRestTest::Env::Host::HostDbTest(
             {strBackupDestination => $strBackupDestination, bStandby => true, oLogTest => $oLogTest,
-                bRepoLocal => $oConfigParam->{strStorage} eq POSIX});
+                bRepoLocal => $oConfigParam->{strStorage} eq POSIX, bTls => $oConfigParam->{bTls}});
 
         $oHostGroup->hostAdd($oHostDbStandby);
     }
 
-    # Finalize S3 server
+    # Finalize object server
     #-------------------------------------------------------------------------------------------------------------------------------
     if ($oConfigParam->{strStorage} eq S3)
     {
         $oHostGroup->hostAdd($oHostObject, {rstryHostName => ['pgbackrest-dev.s3.amazonaws.com', 's3.amazonaws.com']});
     }
-    elsif ($oConfigParam->{strStorage} eq AZURE)
+    elsif ($oConfigParam->{strStorage} eq AZURE || $oConfigParam->{strStorage} eq GCS)
     {
         $oHostGroup->hostAdd($oHostObject);
     }
 
     # Create db-primary config
     $oHostDbPrimary->configCreate({
+        bTls => $oConfigParam->{bTls},
         strBackupSource => $$oConfigParam{strBackupSource},
         strCompressType => $$oConfigParam{strCompressType},
         bHardlink => $bHostBackup ? undef : $$oConfigParam{bHardLink},
         bArchiveAsync => $$oConfigParam{bArchiveAsync},
-        strStorage => $oConfigParam->{strStorage}});
+        strStorage => $oConfigParam->{strStorage},
+        iRepoTotal => $oConfigParam->{iRepoTotal},
+        bBundle => $oConfigParam->{bBundle}});
 
     # Create backup config if backup host exists
     if (defined($oHostBackup))
     {
         $oHostBackup->configCreate({
+            bTls => $oConfigParam->{bTls},
             strCompressType => $$oConfigParam{strCompressType},
             bHardlink => $$oConfigParam{bHardLink},
-            strStorage => $oConfigParam->{strStorage}});
+            strStorage => $oConfigParam->{strStorage},
+            iRepoTotal => $oConfigParam->{iRepoTotal},
+            bBundle => $oConfigParam->{bBundle}});
     }
     # If backup host is not defined set it to db-primary
     else
@@ -159,19 +170,24 @@ sub setup
         $self->backrestExeHelper() .
             ' --config=' . $oHostBackup->backrestConfig() . ' --stanza=' . $self->stanza() . ' --log-level-console=off' .
             ' --log-level-stderr=error' .
-            ($oConfigParam->{strStorage} ne POSIX ? " --no-repo1-$oConfigParam->{strStorage}-verify-tls" .
-                " --repo1-$oConfigParam->{strStorage}-host=" . $oHostObject->ipGet() : ''),
+            ($oConfigParam->{strStorage} ne POSIX ?
+                " --no-repo1-storage-verify-tls --repo1-$oConfigParam->{strStorage}-" .
+                ($oConfigParam->{strStorage} eq GCS ? 'endpoint' : 'host') . "=" . $oHostObject->ipGet() : '') .
+                ($oConfigParam->{strStorage} eq GCS ? ':' . HOST_GCS_PORT : ''),
         $oConfigParam->{strStorage} eq POSIX ? STORAGE_POSIX : STORAGE_OBJECT);
 
     # Create db-standby config
     if (defined($oHostDbStandby))
     {
         $oHostDbStandby->configCreate({
+            bTls => $oConfigParam->{bTls},
             strBackupSource => $$oConfigParam{strBackupSource},
             strCompressType => $$oConfigParam{strCompressType},
             bHardlink => $bHostBackup ? undef : $$oConfigParam{bHardLink},
             bArchiveAsync => $$oConfigParam{bArchiveAsync},
-            strStorage => $oConfigParam->{strStorage}});
+            strStorage => $oConfigParam->{strStorage},
+            iRepoTotal => $oConfigParam->{iRepoTotal},
+            bBundle => $oConfigParam->{bBundle}});
     }
 
     # Create object storage
@@ -226,8 +242,6 @@ sub dbCatalogVersion
 
     my $hCatalogVersion =
     {
-        &PG_VERSION_83 => 200711281,
-        &PG_VERSION_84 => 200904091,
         &PG_VERSION_90 => 201008051,
         &PG_VERSION_91 => 201105231,
         &PG_VERSION_92 => 201204301,
@@ -239,6 +253,7 @@ sub dbCatalogVersion
         &PG_VERSION_11 => 201806231,
         &PG_VERSION_12 => 201909212,
         &PG_VERSION_13 => 202007201,
+        &PG_VERSION_14 => 202105121,
     };
 
     if (!defined($hCatalogVersion->{$strPgVersion}))
@@ -270,8 +285,6 @@ sub dbControlVersion
 
     my $hControlVersion =
     {
-        &PG_VERSION_83 => 833,
-        &PG_VERSION_84 => 843,
         &PG_VERSION_90 => 903,
         &PG_VERSION_91 => 903,
         &PG_VERSION_92 => 922,
@@ -283,6 +296,7 @@ sub dbControlVersion
         &PG_VERSION_11 => 1100,
         &PG_VERSION_12 => 1201,
         &PG_VERSION_13 => 1300,
+        &PG_VERSION_14 => 1300,
     };
 
     if (!defined($hControlVersion->{$strPgVersion}))
@@ -321,8 +335,6 @@ sub controlGenerateContent
     {
         32 =>
         {
-            '8.3' =>  96 - length($tControlContent),
-            '8.4' => 104 - length($tControlContent),
             '9.0' => 140 - length($tControlContent),
             '9.1' => 140 - length($tControlContent),
             '9.2' => 156 - length($tControlContent),
@@ -338,8 +350,6 @@ sub controlGenerateContent
 
         64 =>
         {
-            '8.3' => 112 - length($tControlContent),
-            '8.4' => 112 - length($tControlContent),
             '9.0' => 152 - length($tControlContent),
             '9.1' => 152 - length($tControlContent),
             '9.2' => 168 - length($tControlContent),
@@ -431,8 +441,6 @@ sub walGenerateContent
     # Get WAL magic for the PG version
     my $hWalMagic =
     {
-        &PG_VERSION_83 => hex('0xD062'),
-        &PG_VERSION_84 => hex('0xD063'),
         &PG_VERSION_90 => hex('0xD064'),
         &PG_VERSION_91 => hex('0xD066'),
         &PG_VERSION_92 => hex('0xD071'),
