@@ -11,6 +11,7 @@ use Carp qw(confess);
 use Exporter qw(import);
     our @EXPORT = qw();
 use File::Basename qw(dirname basename);
+use Fcntl qw(:mode);
 use Time::Local qw(timelocal);
 
 use pgBackRestDoc::Common::Exception;
@@ -149,8 +150,6 @@ use constant MANIFEST_SUBKEY_FUTURE                                 => 'future';
     push @EXPORT, qw(MANIFEST_SUBKEY_FUTURE);
 use constant MANIFEST_SUBKEY_GROUP                                  => 'group';
     push @EXPORT, qw(MANIFEST_SUBKEY_GROUP);
-use constant MANIFEST_SUBKEY_MASTER                                 => 'master';
-    push @EXPORT, qw(MANIFEST_SUBKEY_MASTER);
 use constant MANIFEST_SUBKEY_MODE                                   => 'mode';
     push @EXPORT, qw(MANIFEST_SUBKEY_MODE);
 use constant MANIFEST_SUBKEY_TIMESTAMP                              => 'timestamp';
@@ -214,10 +213,10 @@ use constant DB_FILE_PGVERSION                                      => 'PG_VERSI
     push @EXPORT, qw(DB_FILE_PGVERSION);
 use constant DB_FILE_POSTGRESQLAUTOCONFTMP                          => 'postgresql.auto.conf.tmp';
     push @EXPORT, qw(DB_FILE_POSTGRESQLAUTOCONFTMP);
-use constant DB_FILE_POSTMASTEROPTS                                 => 'postmaster.opts';
-    push @EXPORT, qw(DB_FILE_POSTMASTEROPTS);
-use constant DB_FILE_POSTMASTERPID                                  => 'postmaster.pid';
-    push @EXPORT, qw(DB_FILE_POSTMASTERPID);
+use constant DB_FILE_POSTMTROPTS                                    => 'postmas'.'ter.opts';
+    push @EXPORT, qw(DB_FILE_POSTMTROPTS);
+use constant DB_FILE_POSTMTRPID                                     => 'postmas'.'ter.pid';
+    push @EXPORT, qw(DB_FILE_POSTMTRPID);
 use constant DB_FILE_RECOVERYCONF                                   => 'recovery.conf';
     push @EXPORT, qw(DB_FILE_RECOVERYCONF);
 use constant DB_FILE_RECOVERYSIGNAL                                 => 'recovery.signal';
@@ -266,10 +265,10 @@ use constant MANIFEST_FILE_PGCONTROL                                => MANIFEST_
     push @EXPORT, qw(MANIFEST_FILE_PGCONTROL);
 use constant MANIFEST_FILE_POSTGRESQLAUTOCONFTMP                    => MANIFEST_TARGET_PGDATA . '/' . DB_FILE_POSTGRESQLAUTOCONFTMP;
     push @EXPORT, qw(MANIFEST_FILE_PGCONTROL);
-use constant MANIFEST_FILE_POSTMASTEROPTS                           => MANIFEST_TARGET_PGDATA . '/' . DB_FILE_POSTMASTEROPTS;
-    push @EXPORT, qw(MANIFEST_FILE_POSTMASTEROPTS);
-use constant MANIFEST_FILE_POSTMASTERPID                            => MANIFEST_TARGET_PGDATA . '/' . DB_FILE_POSTMASTERPID;
-    push @EXPORT, qw(MANIFEST_FILE_POSTMASTERPID);
+use constant MANIFEST_FILE_POSTMTROPTS                              => MANIFEST_TARGET_PGDATA . '/' . DB_FILE_POSTMTROPTS;
+    push @EXPORT, qw(MANIFEST_FILE_POSTMTROPTS);
+use constant MANIFEST_FILE_POSTMTRPID                               => MANIFEST_TARGET_PGDATA . '/' . DB_FILE_POSTMTRPID;
+    push @EXPORT, qw(MANIFEST_FILE_POSTMTRPID);
 use constant MANIFEST_FILE_RECOVERYCONF                             => MANIFEST_TARGET_PGDATA . '/' . DB_FILE_RECOVERYCONF;
     push @EXPORT, qw(MANIFEST_FILE_RECOVERYCONF);
 use constant MANIFEST_FILE_RECOVERYSIGNAL                           => MANIFEST_TARGET_PGDATA . '/' . DB_FILE_RECOVERYSIGNAL;
@@ -384,8 +383,7 @@ sub get
     if (!defined($oValue) && defined($strKey) && defined($strSubKey) &&
         ($strSection eq MANIFEST_SECTION_TARGET_FILE || $strSection eq MANIFEST_SECTION_TARGET_PATH ||
          $strSection eq MANIFEST_SECTION_TARGET_LINK) &&
-        ($strSubKey eq MANIFEST_SUBKEY_USER || $strSubKey eq MANIFEST_SUBKEY_GROUP ||
-         $strSubKey eq MANIFEST_SUBKEY_MODE || $strSubKey eq MANIFEST_SUBKEY_MASTER) &&
+        ($strSubKey eq MANIFEST_SUBKEY_USER || $strSubKey eq MANIFEST_SUBKEY_GROUP || $strSubKey eq MANIFEST_SUBKEY_MODE) &&
         $self->test($strSection, $strKey))
     {
         $oValue = $self->SUPER::get("${strSection}:default", $strSubKey, undef, $bRequired, $oDefault);
@@ -485,8 +483,7 @@ sub repoPathGet
 
     my $strRepoFile = $strTarget;
 
-    if ($self->isTargetTablespace($strTarget) &&
-        ($self->dbVersion() >= PG_VERSION_90))
+    if ($self->isTargetTablespace($strTarget))
     {
         $strRepoFile .= '/' . $self->tablespacePathGet();
     }
@@ -707,7 +704,7 @@ sub build
     my
     (
         $strOperation,
-        $oStorageDbMaster,
+        $oStorageDbPrimary,
         $strPath,
         $oLastManifest,
         $bOnline,
@@ -726,7 +723,7 @@ sub build
         logDebugParam
         (
             __PACKAGE__ . '->build', \@_,
-            {name => 'oStorageDbMaster'},
+            {name => 'oStorageDbPrimary'},
             {name => 'strPath'},
             {name => 'oLastManifest', required => false},
             {name => 'bOnline'},
@@ -769,7 +766,7 @@ sub build
         # If not online then build the tablespace map from pg_tblspc path
         if (!$bOnline && !defined($hTablespaceMap))
         {
-            my $hTablespaceManifest = $oStorageDbMaster->manifest($strPath . '/' . DB_PATH_PGTBLSPC);
+            my $hTablespaceManifest = $oStorageDbPrimary->manifest($strPath . '/' . DB_PATH_PGTBLSPC);
             $hTablespaceMap = {};
 
             foreach my $strOid (sort(CORE::keys(%{$hTablespaceManifest})))
@@ -820,11 +817,11 @@ sub build
             confess &log(ASSERT, "cannot get manifest for '${strPath}' when no parent path is specified");
         }
 
-        $strPath = $oStorageDbMaster->pathAbsolute($strParentPath, $strPath);
+        $strPath = $oStorageDbPrimary->pathAbsolute($strParentPath, $strPath);
     }
 
     # Get the manifest for this level
-    my $hManifest = $oStorageDbMaster->manifest($strPath, {strFilter => $strFilter});
+    my $hManifest = $oStorageDbPrimary->manifest($strPath, {strFilter => $strFilter});
     my $strManifestType = MANIFEST_VALUE_LINK;
 
     # Loop though all paths/files/links in the manifest
@@ -871,7 +868,7 @@ sub build
         next if $strFile =~ ('^' . MANIFEST_PATH_PGDYNSHMEM . '\/') && $self->dbVersion() >= PG_VERSION_94;
 
         # Skip pg_notify/* since these files cannot be reused on recovery
-        next if $strFile =~ ('^' . MANIFEST_PATH_PGNOTIFY . '\/') && $self->dbVersion() >= PG_VERSION_90;
+        next if $strFile =~ ('^' . MANIFEST_PATH_PGNOTIFY . '\/');
 
         # Skip pg_replslot/* since these files are generally not useful after a restore
         next if $strFile =~ ('^' . MANIFEST_PATH_PGREPLSLOT . '\/') && $self->dbVersion() >= PG_VERSION_94;
@@ -884,7 +881,7 @@ sub build
 
         # Skip temporary statistics in pg_stat_tmp even when stats_temp_directory is set because PGSS_TEXT_FILE is always created
         # there.
-        next if $strFile =~ ('^' . MANIFEST_PATH_PGSTATTMP . '\/') && $self->dbVersion() >= PG_VERSION_84;
+        next if $strFile =~ ('^' . MANIFEST_PATH_PGSTATTMP . '\/');
 
         # Skip pg_subtrans/* since these files are reset
         next if $strFile =~ ('^' . MANIFEST_PATH_PGSUBTRANS . '\/');
@@ -905,14 +902,14 @@ sub build
         # Skip ignored files
         if ($strFile eq MANIFEST_FILE_POSTGRESQLAUTOCONFTMP ||      # postgresql.auto.conf.tmp - temp file for safe writes
             $strFile eq MANIFEST_FILE_BACKUPLABELOLD ||             # backup_label.old - old backup labels are not useful
-            $strFile eq MANIFEST_FILE_POSTMASTEROPTS ||             # postmaster.opts - not useful for backup
-            $strFile eq MANIFEST_FILE_POSTMASTERPID)                # postmaster.pid - to avoid confusing postgres after restore
+            $strFile eq MANIFEST_FILE_POSTMTROPTS ||                # not useful for backup
+            $strFile eq MANIFEST_FILE_POSTMTRPID)                   # to avoid confusing postgres after restore
         {
             next;
         }
 
-        # If version is greater than 9.0, check for files to exclude
-        if ($self->dbVersion() >= PG_VERSION_90 && $hManifest->{$strName}{type} eq 'f')
+        # Check for files to exclude
+        if ($hManifest->{$strName}{type} eq 'f')
         {
             # Get the directory name from the manifest; it will be used later to search for existence in the keys
             my $strDir = dirname($strName);
@@ -1024,7 +1021,7 @@ sub build
             # Check for tablespaces in PGDATA
             if (index($hManifest->{$strName}{link_destination}, "${strPath}/") == 0 ||
                 (index($hManifest->{$strName}{link_destination}, '/') != 0 &&
-                 index($oStorageDbMaster->pathAbsolute($strPath . '/' . DB_PATH_PGTBLSPC,
+                 index($oStorageDbPrimary->pathAbsolute($strPath . '/' . DB_PATH_PGTBLSPC,
                        $hManifest->{$strName}{link_destination}) . '/', "${strPath}/") == 0))
             {
                 confess &log(ERROR, 'tablespace symlink ' . $hManifest->{$strName}{link_destination} .
@@ -1063,8 +1060,6 @@ sub build
             $self->set($strSection, $strFile, MANIFEST_SUBKEY_TIMESTAMP,
                        $hManifest->{$strName}{modification_time} + 0);
             $self->set($strSection, $strFile, MANIFEST_SUBKEY_SIZE, $hManifest->{$strName}{size} + 0);
-            $self->boolSet($strSection, $strFile, MANIFEST_SUBKEY_MASTER,
-                ($strFile eq MANIFEST_FILE_PGCONTROL || $self->isMasterFile($strFile)));
         }
 
         # Link destination required for link type only
@@ -1078,12 +1073,7 @@ sub build
 
             if ($bTablespace)
             {
-                # Only versions >= 9.0  have the special top-level tablespace path.  Below 9.0 the database files are stored
-                # directly in the path referenced by the symlink.
-                if ($self->dbVersion() >= PG_VERSION_90)
-                {
-                    $strFilter = $self->tablespacePathGet();
-                }
+                $strFilter = $self->tablespacePathGet();
 
                 $self->set(MANIFEST_SECTION_TARGET_PATH, MANIFEST_TARGET_PGTBLSPC, undef,
                            $self->get(MANIFEST_SECTION_TARGET_PATH, MANIFEST_TARGET_PGDATA));
@@ -1093,8 +1083,8 @@ sub build
             }
 
             $bDelta = $self->build(
-                $oStorageDbMaster, $strLinkDestination, undef, $bOnline, $bDelta, $hTablespaceMap, $hDatabaseMap, $rhExclude, undef,
-                undef, $strFile, $bTablespace, dirname("${strPath}/${strName}"), $strFilter, $iLevel + 1);
+                $oStorageDbPrimary, $strLinkDestination, undef, $bOnline, $bDelta, $hTablespaceMap, $hDatabaseMap, $rhExclude,
+                undef, undef, $strFile, $bTablespace, dirname("${strPath}/${strName}"), $strFilter, $iLevel + 1);
         }
     }
 
@@ -1192,14 +1182,6 @@ sub build
                         $oLastManifest->get(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_REPO_SIZE));
                 }
 
-                # Copy master flag from the previous manifest (if it exists)
-                if ($oLastManifest->test(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_MASTER))
-                {
-                    $self->set(
-                        MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_MASTER,
-                        $oLastManifest->get(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_MASTER));
-                }
-
                 # Copy checksum page from the previous manifest (if it exists)
                 my $bChecksumPage = $oLastManifest->get(
                     MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_CHECKSUM_PAGE, false);
@@ -1258,7 +1240,7 @@ sub fileAdd
         $lModificationTime,
         $lSize,
         $strChecksum,
-        $bMaster,
+        $bPrimary,
     ) =
         logDebugParam
         (
@@ -1267,7 +1249,7 @@ sub fileAdd
             {name => 'lModificationTime'},
             {name => 'lSize'},
             {name => 'lChecksum'},
-            {name => 'bMaster'},
+            {name => 'bPrimary'},
         );
 
     # Set manifest values
@@ -1296,7 +1278,6 @@ sub fileAdd
     $self->set(MANIFEST_SECTION_TARGET_FILE, $strManifestFile, MANIFEST_SUBKEY_TIMESTAMP, $lModificationTime);
     $self->set(MANIFEST_SECTION_TARGET_FILE, $strManifestFile, MANIFEST_SUBKEY_SIZE, $lSize);
     $self->set(MANIFEST_SECTION_TARGET_FILE, $strManifestFile, MANIFEST_SUBKEY_CHECKSUM, $strChecksum);
-    $self->boolSet(MANIFEST_SECTION_TARGET_FILE, $strManifestFile, MANIFEST_SUBKEY_MASTER, $bMaster);
 }
 
 ####################################################################################################################################
@@ -1311,74 +1292,53 @@ sub buildDefault
     # Assign function parameters, defaults, and log debug info
     my ($strOperation) = logDebugParam(__PACKAGE__ . '->buildDefault');
 
-    # Set defaults for subkeys that tend to repeat
+    # Defaults for subkeys that tend to repeat
+    my $strDefaultUser = $self->get(MANIFEST_SECTION_TARGET_PATH, MANIFEST_TARGET_PGDATA, MANIFEST_SUBKEY_USER);
+    my $strDefaultGroup = $self->get(MANIFEST_SECTION_TARGET_PATH, MANIFEST_TARGET_PGDATA, MANIFEST_SUBKEY_GROUP);
+    my $strDefaultPathMode = $self->get(MANIFEST_SECTION_TARGET_PATH, MANIFEST_TARGET_PGDATA, MANIFEST_SUBKEY_MODE);
+    my $strDefaultFileMode = sprintf('%04o', oct($strDefaultPathMode) & (S_IRUSR | S_IWUSR | S_IRGRP));
+
+    # Remove subkeys that match the defaults
     foreach my $strSection (&MANIFEST_SECTION_TARGET_FILE, &MANIFEST_SECTION_TARGET_PATH, &MANIFEST_SECTION_TARGET_LINK)
     {
-        foreach my $strSubKey (&MANIFEST_SUBKEY_USER, &MANIFEST_SUBKEY_GROUP, &MANIFEST_SUBKEY_MODE, &MANIFEST_SUBKEY_MASTER)
+        next if !$self->test($strSection);
+
+        foreach my $strFile ($self->keys($strSection))
         {
-            # Links don't have a mode so skip
-            next if ($strSection eq MANIFEST_SECTION_TARGET_LINK && $strSubKey eq &MANIFEST_SUBKEY_MODE);
-
-            # Only files have the master subkey
-            next if ($strSection ne MANIFEST_SECTION_TARGET_FILE && $strSubKey eq &MANIFEST_SUBKEY_MASTER);
-
-            my %oDefault;
-            my $iSectionTotal = 0;
-
-            foreach my $strFile ($self->keys($strSection))
+            if ($self->test($strSection, $strFile, MANIFEST_SUBKEY_USER, $strDefaultUser))
             {
-                # Don't count false values when subkey in (MANIFEST_SUBKEY_USER, MANIFEST_SUBKEY_GROUP)
-                next if (($strSubKey eq MANIFEST_SUBKEY_USER || $strSubKey eq MANIFEST_SUBKEY_GROUP) &&
-                         $self->boolTest($strSection, $strFile, $strSubKey, false));
-
-                my $strValue = $self->get($strSection, $strFile, $strSubKey);
-
-                if (defined($oDefault{$strValue}))
-                {
-                    $oDefault{$strValue}++;
-                }
-                else
-                {
-                    $oDefault{$strValue} = 1;
-                }
-
-                $iSectionTotal++;
+                $self->remove($strSection, $strFile, MANIFEST_SUBKEY_USER);
             }
 
-            my $strMaxValue;
-            my $iMaxValueTotal = 0;
-
-            foreach my $strValue (sort(keys(%oDefault)))
+            if ($self->test($strSection, $strFile, MANIFEST_SUBKEY_GROUP, $strDefaultGroup))
             {
-                if ($oDefault{$strValue} > $iMaxValueTotal)
-                {
-                    $iMaxValueTotal = $oDefault{$strValue};
-                    $strMaxValue = $strValue;
-                }
+                $self->remove($strSection, $strFile, MANIFEST_SUBKEY_GROUP);
             }
 
-            if (defined($strMaxValue) > 0 && $iMaxValueTotal > $iSectionTotal * MANIFEST_DEFAULT_MATCH_FACTOR)
+            if ($self->test(
+                $strSection, $strFile, MANIFEST_SUBKEY_MODE,
+                $strSection eq MANIFEST_SECTION_TARGET_PATH ? $strDefaultPathMode : $strDefaultFileMode))
             {
-                if ($strSubKey eq MANIFEST_SUBKEY_MASTER)
-                {
-                    $self->boolSet("${strSection}:default", $strSubKey, undef, $strMaxValue);
-                }
-                else
-                {
-                    $self->set("${strSection}:default", $strSubKey, undef, $strMaxValue);
-                }
-
-                foreach my $strFile ($self->keys($strSection))
-                {
-                    if ($self->test($strSection, $strFile, $strSubKey, $strMaxValue))
-                    {
-                        $self->remove($strSection, $strFile, $strSubKey);
-                    }
-                }
+                $self->remove($strSection, $strFile, MANIFEST_SUBKEY_MODE);
             }
         }
     }
 
+    # Write defaults
+    $self->set(MANIFEST_SECTION_TARGET_FILE . ':default', MANIFEST_SUBKEY_USER, undef, $strDefaultUser);
+    $self->set(MANIFEST_SECTION_TARGET_FILE . ':default', MANIFEST_SUBKEY_GROUP, undef, $strDefaultGroup);
+    $self->set(MANIFEST_SECTION_TARGET_FILE . ':default', MANIFEST_SUBKEY_MODE, undef, $strDefaultFileMode);
+
+    if ($self->test(MANIFEST_SECTION_TARGET_LINK))
+    {
+        $self->set(MANIFEST_SECTION_TARGET_LINK . ':default', MANIFEST_SUBKEY_USER, undef, $strDefaultUser);
+        $self->set(MANIFEST_SECTION_TARGET_LINK . ':default', MANIFEST_SUBKEY_GROUP, undef, $strDefaultGroup);
+    }
+
+    $self->set(MANIFEST_SECTION_TARGET_PATH . ':default', MANIFEST_SUBKEY_USER, undef, $strDefaultUser);
+    $self->set(MANIFEST_SECTION_TARGET_PATH . ':default', MANIFEST_SUBKEY_GROUP, undef, $strDefaultGroup);
+    $self->set(MANIFEST_SECTION_TARGET_PATH . ':default', MANIFEST_SUBKEY_MODE, undef, $strDefaultPathMode);
+
     # Return from function and log return values if any
     return logDebugReturn($strOperation);
 }
@@ -1448,11 +1408,11 @@ sub walPath
 }
 
 ####################################################################################################################################
-# isMasterFile
+# isPrimaryFile
 #
-# Is this file required to be copied from the master?
+# Is this file required to be copied from the primary?
 ####################################################################################################################################
-sub isMasterFile
+sub isPrimaryFile
 {
     my $self = shift;
     my $strFile = shift;
