@@ -52,19 +52,18 @@ sub run
 
     foreach my $rhRun
     (
-        {pg => PG_VERSION_83, repoDest => HOST_DB_PRIMARY, storage => POSIX, encrypt => false, compress => NONE, repo => 1},
-        {pg => PG_VERSION_84, repoDest =>     HOST_BACKUP, storage => AZURE, encrypt =>  true, compress =>   GZ, repo => 1},
-        {pg => PG_VERSION_90, repoDest => HOST_DB_PRIMARY, storage => POSIX, encrypt =>  true, compress =>  BZ2, repo => 1},
-        {pg => PG_VERSION_91, repoDest => HOST_DB_STANDBY, storage =>    S3, encrypt => false, compress => NONE, repo => 1},
-        {pg => PG_VERSION_92, repoDest => HOST_DB_STANDBY, storage => POSIX, encrypt =>  true, compress => NONE, repo => 1},
-        {pg => PG_VERSION_93, repoDest =>     HOST_BACKUP, storage => AZURE, encrypt => false, compress =>   GZ, repo => 1},
-        {pg => PG_VERSION_94, repoDest => HOST_DB_STANDBY, storage => POSIX, encrypt =>  true, compress =>  LZ4, repo => 1},
-        {pg => PG_VERSION_95, repoDest =>     HOST_BACKUP, storage =>    S3, encrypt => false, compress =>  BZ2, repo => 1},
-        {pg => PG_VERSION_96, repoDest =>     HOST_BACKUP, storage => POSIX, encrypt => false, compress => NONE, repo => 1},
-        {pg => PG_VERSION_10, repoDest => HOST_DB_STANDBY, storage =>    S3, encrypt =>  true, compress =>   GZ, repo => 1},
-        {pg => PG_VERSION_11, repoDest =>     HOST_BACKUP, storage => AZURE, encrypt => false, compress =>  ZST, repo => 1},
-        {pg => PG_VERSION_12, repoDest =>     HOST_BACKUP, storage =>    S3, encrypt =>  true, compress =>  LZ4, repo => 1},
-        {pg => PG_VERSION_13, repoDest => HOST_DB_STANDBY, storage => AZURE, encrypt => false, compress =>  ZST, repo => 1},
+        {pg => '9.0', repoDest => HOST_DB_PRIMARY, tls => 0, storage =>   GCS, encrypt => 1, compress =>  BZ2, repo => 2, bnd => 1},
+        {pg => '9.1', repoDest => HOST_DB_STANDBY, tls => 1, storage =>   GCS, encrypt => 0, compress =>   GZ, repo => 1, bnd => 0},
+        {pg => '9.2', repoDest => HOST_DB_STANDBY, tls => 0, storage => POSIX, encrypt => 1, compress => NONE, repo => 1, bnd => 1},
+        {pg => '9.3', repoDest =>     HOST_BACKUP, tls => 0, storage => AZURE, encrypt => 0, compress => NONE, repo => 2, bnd => 0},
+        {pg => '9.4', repoDest => HOST_DB_STANDBY, tls => 0, storage => POSIX, encrypt => 1, compress =>  LZ4, repo => 1, bnd => 1},
+        {pg => '9.5', repoDest =>     HOST_BACKUP, tls => 1, storage =>    S3, encrypt => 0, compress =>  BZ2, repo => 1, bnd => 0},
+        {pg => '9.6', repoDest =>     HOST_BACKUP, tls => 0, storage => POSIX, encrypt => 0, compress => NONE, repo => 2, bnd => 1},
+        {pg =>  '10', repoDest => HOST_DB_STANDBY, tls => 1, storage =>    S3, encrypt => 1, compress =>   GZ, repo => 2, bnd => 0},
+        {pg =>  '11', repoDest =>     HOST_BACKUP, tls => 1, storage => AZURE, encrypt => 0, compress =>  ZST, repo => 2, bnd => 1},
+        {pg =>  '12', repoDest =>     HOST_BACKUP, tls => 0, storage =>    S3, encrypt => 1, compress =>  LZ4, repo => 1, bnd => 0},
+        {pg =>  '13', repoDest => HOST_DB_STANDBY, tls => 1, storage =>   GCS, encrypt => 0, compress =>  ZST, repo => 1, bnd => 1},
+        {pg =>  '14', repoDest =>     HOST_BACKUP, tls => 0, storage => POSIX, encrypt => 1, compress =>  LZ4, repo => 2, bnd => 0},
     )
     {
         # Only run tests for this pg version
@@ -73,11 +72,13 @@ sub run
         # Get run parameters
         my $bHostBackup = $rhRun->{repoDest} eq HOST_BACKUP ? true : false;
         my $bHostStandby = $self->pgVersion() >= PG_VERSION_HOT_STANDBY ? true : false;
+        my $bTls = $rhRun->{tls};
         my $strBackupDestination = $rhRun->{repoDest};
         my $strStorage = $rhRun->{storage};
         my $bRepoEncrypt = $rhRun->{encrypt};
         my $strCompressType = $rhRun->{compress};
         my $iRepoTotal = $rhRun->{repo};
+        my $bBundle = $rhRun->{bnd};
 
         # Use a specific VM and version of PostgreSQL for expect testing. This version will also be used to run tests that are not
         # version specific.
@@ -85,21 +86,23 @@ sub run
 
         # Increment the run, log, and decide whether this unit test should be run
         next if (!$self->begin(
-            "bkp ${bHostBackup}, sby ${bHostStandby}, dst ${strBackupDestination}, cmp ${strCompressType}" .
+            "bkp ${bHostBackup}, sby ${bHostStandby}, tls ${bTls}, dst ${strBackupDestination}, cmp ${strCompressType}" .
                 ", storage ${strStorage}, enc ${bRepoEncrypt}",
             $bExpectVersion));
 
         # Create hosts, file object, and config
         my ($oHostDbPrimary, $oHostDbStandby, $oHostBackup) = $self->setup(
             false, $self->expect(),
-            {bHostBackup => $bHostBackup, bStandby => $bHostStandby, strBackupDestination => $strBackupDestination,
+            {bHostBackup => $bHostBackup, bStandby => $bHostStandby, bTls => $bTls, strBackupDestination => $strBackupDestination,
              strCompressType => $strCompressType, bArchiveAsync => false, strStorage => $strStorage,
-             bRepoEncrypt => $bRepoEncrypt, iRepoTotal => $iRepoTotal});
+             bRepoEncrypt => $bRepoEncrypt, iRepoTotal => $iRepoTotal, bBundle => $bBundle});
 
         # Some commands will fail because of the bogus host created when a standby is present. These options reset the bogus host
         # so it won't interfere with commands that won't tolerate a connection failure.
         my $strBogusReset = $oHostBackup->bogusHost() ?
-            ' --reset-pg2-host --reset-pg2-host-cmd --reset-pg2-host-config --reset-pg2-host-user --reset-pg2-path' : '';
+            ' --reset-pg2-host --reset-pg2-host-type --reset-pg2-host-cmd --reset-pg2-host-config --reset-pg2-host-user' .
+                ' --reset-pg2-path' :
+            '';
 
         # If S3 set process max to 2.  This seems like the best place for parallel testing since it will help speed S3 processing
         # without slowing down the other tests too much.
@@ -112,7 +115,7 @@ sub run
         $oHostDbPrimary->clusterCreate();
 
         # Create the stanza
-        $oHostBackup->stanzaCreate('main create stanza info files');
+        $oHostDbPrimary->stanzaCreate('main create stanza info files');
 
         # Get passphrase to access the Manifest file from backup.info - returns undefined if repo not encrypted
         my $strCipherPass =
@@ -281,21 +284,21 @@ sub run
             # Update message for standby
             $oHostDbPrimary->sqlExecute("update test set message = '$strStandbyMessage'");
 
-            if ($oHostDbStandby->pgVersion() >= PG_VERSION_BACKUP_STANDBY)
+            if ($oHostDbStandby->pgVersion() >= PG_VERSION_BACKUP_STANDBY && !$bTls)
             {
-                # If there is only a primary and a replica and the replica is the backup destination, then if pg2-host and pg3-host
-                # are BOGUS, confirm failure to reach the primary
+                # If there is only a primary and a replica and the replica is the backup destination, then if pg2-host and
+                # pg256-host are BOGUS, confirm failure to reach the primary
                 if (!$bHostBackup && $bHostStandby && $strBackupDestination eq HOST_DB_STANDBY)
                 {
                     my $strStandbyBackup = $oHostBackup->backup(
                         CFGOPTVAL_BACKUP_TYPE_FULL, 'backup from standby, failure to reach primary',
-                        {bStandby => true, iExpectedExitStatus => ERROR_DB_CONNECT, strOptionalParam => '--pg8-host=' . BOGUS});
+                        {bStandby => true, iExpectedExitStatus => ERROR_DB_CONNECT, strOptionalParam => '--pg256-host=' . BOGUS});
                 }
                 else
                 {
                     my $strStandbyBackup = $oHostBackup->backup(
                         CFGOPTVAL_BACKUP_TYPE_FULL, 'backup from standby, failure to access at least one standby',
-                        {bStandby => true, iExpectedExitStatus => ERROR_DB_CONNECT, strOptionalParam => '--pg8-host=' . BOGUS});
+                        {bStandby => true, iExpectedExitStatus => ERROR_DB_CONNECT, strOptionalParam => '--pg256-host=' . BOGUS});
                 }
             }
 
@@ -568,34 +571,22 @@ sub run
         # The tablespace path should exist and have files in it
         my $strTablespacePath = $oHostDbPrimary->tablespacePath(1);
 
-        # Version <= 8.4 always places a PG_VERSION file in the tablespace
-        if ($oHostDbPrimary->pgVersion() <= PG_VERSION_84)
-        {
-            if (!storageTest()->exists("${strTablespacePath}/" . DB_FILE_PGVERSION))
-            {
-                confess &log(ASSERT, "unable to find '" . DB_FILE_PGVERSION . "' in tablespace path '${strTablespacePath}'");
-            }
-        }
-        # Version >= 9.0 creates a special path using the version and catalog number
-        else
-        {
-            # Backup info will have the catalog number
-            my $oBackupInfo = new pgBackRestDoc::Common::Ini(
-                storageRepo(), $oHostBackup->repoBackupPath(FILE_BACKUP_INFO),
-                {bLoad => false, strContent => ${storageRepo()->get($oHostBackup->repoBackupPath(FILE_BACKUP_INFO))}});
+        # Backup info will have the catalog number
+        my $oBackupInfo = new pgBackRestDoc::Common::Ini(
+            storageRepo(), $oHostBackup->repoBackupPath(FILE_BACKUP_INFO),
+            {bLoad => false, strContent => ${storageRepo()->get($oHostBackup->repoBackupPath(FILE_BACKUP_INFO))}});
 
-            # Construct the special path
-            $strTablespacePath .=
-                '/PG_' . $oHostDbPrimary->pgVersion() . qw{_} . $oBackupInfo->get(INFO_BACKUP_SECTION_DB, INFO_BACKUP_KEY_CATALOG);
+        # Construct the special path
+        $strTablespacePath .=
+            '/PG_' . $oHostDbPrimary->pgVersion() . qw{_} . $oBackupInfo->get(INFO_BACKUP_SECTION_DB, INFO_BACKUP_KEY_CATALOG);
 
-            # Check that path exists
-            if (!storageTest()->pathExists($strTablespacePath))
-            {
-                confess &log(ASSERT, "unable to find tablespace path '${strTablespacePath}'");
-            }
+        # Check that path exists
+        if (!storageTest()->pathExists($strTablespacePath))
+        {
+            confess &log(ASSERT, "unable to find tablespace path '${strTablespacePath}'");
         }
 
-        # Make sure there are some files in the tablespace path (exclude PG_VERSION if <= 8.4 since that was tested above)
+        # Make sure there are some files in the tablespace path
         if (grep(!/^PG\_VERSION$/i, storageTest()->list($strTablespacePath)) == 0)
         {
             confess &log(ASSERT, "no files found in tablespace path '${strTablespacePath}'");
@@ -610,15 +601,7 @@ sub run
         $oHostDbPrimary->sqlExecute('drop database test2', {bAutoCommit => true});
 
         # The test table lives in ts1 so it needs to be moved or dropped
-        if ($oHostDbPrimary->pgVersion() >= PG_VERSION_90)
-        {
-            $oHostDbPrimary->sqlExecute('alter table test set tablespace pg_default');
-        }
-        # Drop for older versions
-        else
-        {
-            $oHostDbPrimary->sqlExecute('drop table test');
-        }
+        $oHostDbPrimary->sqlExecute('alter table test set tablespace pg_default');
 
         # And drop the tablespace
         $oHostDbPrimary->sqlExecute('drop database test3', {bAutoCommit => true});
@@ -749,25 +732,19 @@ sub run
 
         # Restore (restore type = default, timeline = created by type = xid, inclusive recovery)
         #---------------------------------------------------------------------------------------------------------------------------
-        if ($oHostDbPrimary->pgVersion() >= PG_VERSION_84)
-        {
-            &log(INFO, '    testing recovery type = ' . CFGOPTVAL_RESTORE_TYPE_DEFAULT);
+        &log(INFO, '    testing recovery type = ' . CFGOPTVAL_RESTORE_TYPE_DEFAULT);
 
-            $oHostDbPrimary->clusterStop();
+        $oHostDbPrimary->clusterStop();
 
-            # The timeline to use for this test is subject to change based on tests being added or removed above.  The best thing
-            # would be to automatically grab the timeline after the restore, but since this test has been stable for a long time
-            # it does not seem worth the effort to automate.
-            $oHostDbPrimary->restore(
-                undef, $strIncrBackup,
-                {bDelta => true,
-                    strType => $oHostDbPrimary->pgVersion() >= PG_VERSION_90 ?
-                        CFGOPTVAL_RESTORE_TYPE_STANDBY : CFGOPTVAL_RESTORE_TYPE_DEFAULT,
-                    strTargetTimeline => 4, iRepo => $iRepoTotal});
+        # The timeline to use for this test is subject to change based on tests being added or removed above.  The best thing
+        # would be to automatically grab the timeline after the restore, but since this test has been stable for a long time
+        # it does not seem worth the effort to automate.
+        $oHostDbPrimary->restore(
+            undef, $strIncrBackup,
+            {bDelta => true, strType => CFGOPTVAL_RESTORE_TYPE_STANDBY, strTargetTimeline => 4, iRepo => $iRepoTotal});
 
-            $oHostDbPrimary->clusterStart({bHotStandby => true});
-            $oHostDbPrimary->sqlSelectOneTest('select message from test', $strTimelineMessage, {iTimeout => 120});
-        }
+        $oHostDbPrimary->clusterStart({bHotStandby => true});
+        $oHostDbPrimary->sqlSelectOneTest('select message from test', $strTimelineMessage, {iTimeout => 120});
 
         # Stop clusters to catch any errors in the postgres log
         #---------------------------------------------------------------------------------------------------------------------------
