@@ -62,6 +62,8 @@ testRun(void)
         "    repo-get        Get a file from a repository.\n"
         "    repo-ls         List files in a repository.\n"
         "    restore         Restore a database cluster.\n"
+        "    server          pgBackRest server.\n"
+        "    server-ping     Ping pgBackRest server.\n"
         "    stanza-create   Create the required stanza data.\n"
         "    stanza-delete   Delete a stanza.\n"
         "    stanza-upgrade  Upgrade a stanza.\n"
@@ -119,17 +121,6 @@ testRun(void)
             "two paragraphs, indent first, internal");
     }
 
-    // *****************************************************************************************************************************
-    if (testBegin("helpRenderValue()"))
-    {
-        TEST_RESULT_STR_Z(helpRenderValue(varNewBool(true), cfgOptTypeBoolean), "y", "boolean y");
-        TEST_RESULT_STR_Z(helpRenderValue(varNewBool(false), cfgOptTypeBoolean), "n", "boolean n");
-        TEST_RESULT_STR_Z(helpRenderValue(varNewStrZ("test-string"), cfgOptTypeString), "test-string", "string");
-        TEST_RESULT_STR_Z(helpRenderValue(varNewInt64(1234), cfgOptTypeInteger), "1234", "int");
-        TEST_RESULT_STR_Z(helpRenderValue(varNewInt64(1234000), cfgOptTypeTime), "1234", "time");
-        TEST_RESULT_STR_Z(helpRenderValue(NULL, cfgOptTypeString), NULL, "null");
-    }
-
     // *****************************************************************************************************************************
     if (testBegin("helpRender()"))
     {
@@ -194,6 +185,10 @@ testRun(void)
             "e.g. xid, the --set option must be provided if the target is prior to the\n"
             "latest backup. See Point-in-Time Recovery for more details and examples.\n"
             "\n"
+            "Replication slots are not included per recommendation of PostgreSQL. See\n"
+            "Backing Up The Data Directory in the PostgreSQL documentation for more\n"
+            "information.\n"
+            "\n"
             "Command Options:\n"
             "\n"
             "  --archive-mode                   preserve or disable archiving on restored\n"
@@ -222,7 +217,9 @@ testRun(void)
             "General Options:\n"
             "\n"
             "  --buffer-size                    buffer size for I/O operations\n"
-            "                                   [current=32768, default=1048576]\n"
+            "                                   [current=32768, default=1MiB]\n"
+            "  --cmd                            pgBackRest command\n"
+            "                                   [default=/path/to/pgbackrest]\n"
             "  --cmd-ssh                        SSH client command [default=ssh]\n"
             "  --compress-level-network         network compression level [default=3]\n"
             "  --config                         pgBackRest configuration file\n"
@@ -276,6 +273,9 @@ testRun(void)
             "  --repo-gcs-key-type              GCS repository key type [default=service]\n"
             "  --repo-host                      repository host when operating remotely via\n"
             "                                   SSH [current=backup.example.net]\n"
+            "  --repo-host-ca-file              repository host certificate authority file\n"
+            "  --repo-host-ca-path              repository host certificate authority path\n"
+            "  --repo-host-cert-file            repository host certificate file\n"
             "  --repo-host-cmd                  repository host pgBackRest command\n"
             "                                   [default=/path/to/pgbackrest]\n"
             "  --repo-host-config               pgBackRest repository host configuration\n"
@@ -285,7 +285,9 @@ testRun(void)
             "                                   include path [default=/etc/pgbackrest/conf.d]\n"
             "  --repo-host-config-path          pgBackRest repository host configuration\n"
             "                                   path [default=/etc/pgbackrest]\n"
+            "  --repo-host-key-file             repository host key file\n"
             "  --repo-host-port                 repository host port when repo-host is set\n"
+            "  --repo-host-type                 repository host protocol type [default=ssh]\n"
             "  --repo-host-user                 repository host user when repo-host is set\n"
             "                                   [default=pgbackrest]\n"
             "  --repo-path                      path where backups and archive are stored\n"
@@ -295,6 +297,7 @@ testRun(void)
             "  --repo-s3-key                    S3 repository access key\n"
             "  --repo-s3-key-secret             S3 repository secret access key\n"
             "  --repo-s3-key-type               S3 repository key type [default=shared]\n"
+            "  --repo-s3-kms-key-id             S3 repository KMS key\n"
             "  --repo-s3-region                 S3 repository region\n"
             "  --repo-s3-role                   S3 repository role\n"
             "  --repo-s3-token                  S3 repository security token\n"
@@ -370,12 +373,13 @@ testRun(void)
             "of buffers used depends on options and each operation may use additional\n"
             "memory, e.g. gz compression may use an additional 256KiB of memory.\n"
             "\n"
-            "Size can be entered in bytes (default) or KB, MB, GB, TB, or PB where the\n"
-            "multiplier is a power of 1024. For example, the case-insensitive value 32k (or\n"
-            "32KB) can be used instead of 32768.\n"
+            "Size can be entered in bytes (default) or KiB, MiB, GiB, TiB, or PiB where the\n"
+            "multiplier is a power of 1024. For example, the case-insensitive value 5GiB (or\n"
+            "5GB, 5g) can be used instead of 5368709120. Fractional values such as 2.5GiB\n"
+            "are not allowed, use 2560MiB instead.\n"
             "\n"
-            "Allowed values, in bytes, are 16384, 32768, 65536, 131072, 262144, 524288,\n"
-            "1048576, 2097152, 4194304, 8388608, and 16777216.\n",
+            "Allowed values are 16KiB, 32KiB, 64KiB, 128KiB, 256KiB, 512KiB, 1MiB, 2MiB,\n"
+            "4MiB, 8MiB, and 16MiB.\n",
             helpVersion));
 
         argList = strLstNew();
@@ -384,13 +388,13 @@ testRun(void)
         strLstAddZ(argList, "archive-push");
         strLstAddZ(argList, "buffer-size");
         TEST_RESULT_VOID(testCfgLoad(argList), "help for archive-push command, buffer-size option");
-        TEST_RESULT_STR(helpRender(helpData), strNewFmt("%s\ndefault: 1048576\n", optionHelp), "check text");
+        TEST_RESULT_STR(helpRender(helpData), strNewFmt("%s\ndefault: 1MiB\n", optionHelp), "check text");
 
         // Set a current value
-        hrnCfgArgRawZ(argList, cfgOptBufferSize, "32768");
+        hrnCfgArgRawZ(argList, cfgOptBufferSize, "32k");
         TEST_RESULT_VOID(testCfgLoad(argList), "help for archive-push command, buffer-size option");
         TEST_RESULT_STR(
-            helpRender(helpData), strNewFmt("%s\ncurrent: 32768\ndefault: 1048576\n", optionHelp), "check text, current value");
+            helpRender(helpData), strNewFmt("%s\ncurrent: 32k\ndefault: 1MiB\n", optionHelp), "check text, current value");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("deprecated host option names");
