@@ -37,14 +37,14 @@ testRun(void)
         "db-catalog-version=201409291\n"                                                                                           \
         "db-control-version=942\n"                                                                                                 \
         "db-id=1\n"                                                                                                                \
-        "db-system-id=6625592122879095702\n"                                                                                       \
+        "db-system-id=" HRN_PG_SYSTEMID_94_Z "\n"                                                                                  \
         "db-version=\"9.4\"\n"
 
     #define TEST_BACKUP_DB2_11                                                                                                     \
         "db-catalog-version=201707211\n"                                                                                           \
         "db-control-version=1100\n"                                                                                                \
         "db-id=2\n"                                                                                                                \
-        "db-system-id=6626363367545678089\n"                                                                                       \
+        "db-system-id=" HRN_PG_SYSTEMID_11_Z "\n"                                                                                  \
         "db-version=\"11\"\n"
 
     #define TEST_BACKUP_DB1_CURRENT_FULL1                                                                                          \
@@ -77,11 +77,11 @@ testRun(void)
         "\"option-checksum-page\":true,\"option-compress\":true,\"option-hardlink\":false,\"option-online\":true}\n"
 
     #define TEST_BACKUP_DB1_HISTORY                                                                                                \
-        "1={\"db-catalog-version\":201409291,\"db-control-version\":942,\"db-system-id\":6625592122879095702,"                     \
+        "1={\"db-catalog-version\":201409291,\"db-control-version\":942,\"db-system-id\":" HRN_PG_SYSTEMID_94_Z ","                \
             "\"db-version\":\"9.4\"}"
 
     #define TEST_BACKUP_DB2_HISTORY                                                                                                \
-        "2={\"db-catalog-version\":201707211,\"db-control-version\":1100,\"db-system-id\":6626363367545678089,"                    \
+        "2={\"db-catalog-version\":201707211,\"db-control-version\":1100,\"db-system-id\":" HRN_PG_SYSTEMID_11_Z ","               \
             "\"db-version\":\"11\"}"
 
     #define TEST_BACKUP_INFO_MULTI_HISTORY_BASE                                                                                    \
@@ -101,21 +101,21 @@ testRun(void)
     #define TEST_ARCHIVE_INFO_BASE                                                                                                 \
         "[db]\n"                                                                                                                   \
         "db-id=1\n"                                                                                                                \
-        "db-system-id=6625592122879095702\n"                                                                                       \
+        "db-system-id=" HRN_PG_SYSTEMID_94_Z "\n"                                                                                  \
         "db-version=\"9.4\"\n"                                                                                                     \
         "\n"                                                                                                                       \
         "[db:history]\n"                                                                                                           \
-        "1={\"db-id\":6625592122879095702,\"db-version\":\"9.4\"}"
+        "1={\"db-id\":" HRN_PG_SYSTEMID_94_Z ",\"db-version\":\"9.4\"}"
 
     #define TEST_ARCHIVE_INFO_MULTI_HISTORY_BASE                                                                                   \
         "[db]\n"                                                                                                                   \
         "db-id=2\n"                                                                                                                \
-        "db-system-id=6626363367545678089\n"                                                                                       \
+        "db-system-id=" HRN_PG_SYSTEMID_11_Z "\n"                                                                                  \
         "db-version=\"11\"\n"                                                                                                      \
         "\n"                                                                                                                       \
         "[db:history]\n"                                                                                                           \
-        "1={\"db-id\":6625592122879095702,\"db-version\":\"9.4\"}\n"                                                               \
-        "2={\"db-id\":6626363367545678089,\"db-version\":\"11\"}"
+        "1={\"db-id\":" HRN_PG_SYSTEMID_94_Z ",\"db-version\":\"9.4\"}\n"                                                          \
+        "2={\"db-id\":" HRN_PG_SYSTEMID_11_Z ",\"db-version\":\"11\"}"
 
     #define TEST_MANIFEST_HEADER                                                                                                   \
         "[backup]\n"                                                                                                               \
@@ -131,7 +131,7 @@ testRun(void)
         "db-catalog-version=201204301\n"                                                                                           \
         "db-control-version=922\n"                                                                                                 \
         "db-id=1\n"                                                                                                                \
-        "db-system-id=6625592122879095702\n"                                                                                       \
+        "db-system-id=" HRN_PG_SYSTEMID_94_Z "\n"                                                                                  \
         "db-version=\"9.2\"\n"
 
     #define TEST_MANIFEST_DB_94                                                                                                    \
@@ -140,7 +140,7 @@ testRun(void)
         "db-catalog-version=201409291\n"                                                                                           \
         "db-control-version=942\n"                                                                                                 \
         "db-id=1\n"                                                                                                                \
-        "db-system-id=6625592122879095702\n"                                                                                       \
+        "db-system-id=" HRN_PG_SYSTEMID_94_Z "\n"                                                                                  \
         "db-version=\"9.4\"\n"
 
     #define TEST_MANIFEST_OPTION_ALL                                                                                               \
@@ -173,14 +173,12 @@ testRun(void)
     #define TEST_MANIFEST_FILE                                                                                                     \
         "\n"                                                                                                                       \
         "[target:file]\n"                                                                                                          \
-        "pg_data/PG_VERSION={\"checksum\":\"184473f470864e067ee3a22e64b47b0a1c356f29\",\"mas""ter\":true"                          \
-            ",\"size\":4,\"timestamp\":1565282114}\n"
+        "pg_data/PG_VERSION={\"checksum\":\"184473f470864e067ee3a22e64b47b0a1c356f29\",\"size\":4,\"timestamp\":1565282114}\n"
 
     #define TEST_MANIFEST_FILE_DEFAULT                                                                                             \
         "\n"                                                                                                                       \
         "[target:file:default]\n"                                                                                                  \
         "group=\"group1\"\n"                                                                                                       \
-        "mas""ter=false\n"                                                                                                         \
         "mode=\"0600\"\n"                                                                                                          \
         "user=\"user1\"\n"
 
@@ -257,7 +255,7 @@ testRun(void)
             "P00   WARN: unable to open missing file '" TEST_PATH "/repo/backup/db/20181119-152138F/backup.manifest.copy'"
                 " for read\n"
             "P00  ERROR: [028]: '20181119-152138F' may not be recoverable - PG data (id 1, version 9.2, system-id "
-                "6625592122879095702) is not in the backup.info history, skipping");
+                HRN_PG_SYSTEMID_94_Z ") is not in the backup.info history, skipping");
 
         //--------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("rerun test with db-system-id invalid and no main");
@@ -305,7 +303,7 @@ testRun(void)
             "db-catalog-version=201409291\n"
             "db-control-version=942\n"
             "db-id=0\n"
-            "db-system-id=6625592122879095702\n"
+            "db-system-id=" HRN_PG_SYSTEMID_94_Z "\n"
             "db-version=\"9.4\"\n"
             TEST_MANIFEST_OPTION_ALL
             TEST_MANIFEST_TARGET
@@ -326,7 +324,7 @@ testRun(void)
             "P00   WARN: unable to open missing file '" TEST_PATH "/repo/backup/db/20181119-152138F/backup.manifest' for read\n"
             "P00   WARN: 20181119-152138F/backup.manifest is missing or unusable, using copy\n"
             "P00  ERROR: [028]: '20181119-152138F' may not be recoverable - PG data (id 0, version 9.4, system-id "
-                "6625592122879095702) is not in the backup.info history, skipping");
+                HRN_PG_SYSTEMID_94_Z ") is not in the backup.info history, skipping");
 
         //--------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("missing main manifest, errored copy");
@@ -393,9 +391,9 @@ testRun(void)
         VerifyArchiveResult archiveResult =
         {
             .archiveId = strNewZ("9.4-1"),
-            .walRangeList = lstNewP(sizeof(VerifyWalRange), .comparator =  lstComparatorStr),
+            .walRangeList = lstNewP(sizeof(VerifyWalRange), .comparator = lstComparatorStr),
         };
-        List *archiveIdResultList = lstNewP(sizeof(VerifyArchiveResult), .comparator =  archiveIdComparator);
+        List *archiveIdResultList = lstNewP(sizeof(VerifyArchiveResult), .comparator = archiveIdComparator);
         lstAdd(archiveIdResultList, &archiveResult);
         VerifyArchiveResult *archiveIdResult = lstGetLast(archiveIdResultList);
 
@@ -567,11 +565,11 @@ testRun(void)
             archiveInfo, infoArchiveNewLoad(ioBufferReadNew(harnessInfoChecksumZ(
                 "[db]\n"
                 "db-id=2\n"
-                "db-system-id=6626363367545678089\n"
+                "db-system-id=" HRN_PG_SYSTEMID_11_Z "\n"
                 "db-version=\"11\"\n"
                 "\n"
                 "[db:history]\n"
-                "2={\"db-id\":6626363367545678089,\"db-version\":\"11\"}"))), "archive.info missing history");
+                "2={\"db-id\":" HRN_PG_SYSTEMID_11_Z ",\"db-version\":\"11\"}"))), "archive.info missing history");
 
         TEST_ERROR(
             verifyPgHistory(infoArchivePg(archiveInfo), infoBackupPg(backupInfo)), FormatError,
@@ -584,12 +582,12 @@ testRun(void)
             archiveInfo, infoArchiveNewLoad(ioBufferReadNew(harnessInfoChecksumZ(
                 "[db]\n"
                 "db-id=2\n"
-                "db-system-id=6626363367545678089\n"
+                "db-system-id=" HRN_PG_SYSTEMID_11_Z "\n"
                 "db-version=\"11\"\n"
                 "\n"
                 "[db:history]\n"
                 "1={\"db-id\":6625592122879095777,\"db-version\":\"9.4\"}\n"
-                "2={\"db-id\":6626363367545678089,\"db-version\":\"11\"}"))), "archive.info history system id mismatch");
+                "2={\"db-id\":" HRN_PG_SYSTEMID_11_Z ",\"db-version\":\"11\"}"))), "archive.info history system id mismatch");
 
         TEST_ERROR(
             verifyPgHistory(infoArchivePg(archiveInfo), infoBackupPg(backupInfo)), FormatError,
@@ -602,12 +600,12 @@ testRun(void)
             archiveInfo, infoArchiveNewLoad(ioBufferReadNew(harnessInfoChecksumZ(
                 "[db]\n"
                 "db-id=2\n"
-                "db-system-id=6626363367545678089\n"
+                "db-system-id=" HRN_PG_SYSTEMID_11_Z "\n"
                 "db-version=\"11\"\n"
                 "\n"
                 "[db:history]\n"
-                "1={\"db-id\":6625592122879095702,\"db-version\":\"9.5\"}\n"
-                "2={\"db-id\":6626363367545678089,\"db-version\":\"11\"}"))), "archive.info history version mismatch");
+                "1={\"db-id\":" HRN_PG_SYSTEMID_94_Z ",\"db-version\":\"9.5\"}\n"
+                "2={\"db-id\":" HRN_PG_SYSTEMID_11_Z ",\"db-version\":\"11\"}"))), "archive.info history version mismatch");
 
         TEST_ERROR(
             verifyPgHistory(infoArchivePg(archiveInfo), infoBackupPg(backupInfo)), FormatError,
@@ -620,12 +618,12 @@ testRun(void)
             archiveInfo, infoArchiveNewLoad(ioBufferReadNew(harnessInfoChecksumZ(
                 "[db]\n"
                 "db-id=2\n"
-                "db-system-id=6626363367545678089\n"
+                "db-system-id=" HRN_PG_SYSTEMID_11_Z "\n"
                 "db-version=\"11\"\n"
                 "\n"
                 "[db:history]\n"
-                "3={\"db-id\":6625592122879095702,\"db-version\":\"9.4\"}\n"
-                "2={\"db-id\":6626363367545678089,\"db-version\":\"11\"}"))), "archive.info history id mismatch");
+                "3={\"db-id\":" HRN_PG_SYSTEMID_94_Z ",\"db-version\":\"9.4\"}\n"
+                "2={\"db-id\":" HRN_PG_SYSTEMID_11_Z ",\"db-version\":\"11\"}"))), "archive.info history id mismatch");
 
         TEST_ERROR(
             verifyPgHistory(infoArchivePg(archiveInfo), infoBackupPg(backupInfo)), FormatError,
@@ -685,20 +683,20 @@ testRun(void)
         //--------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("verifyRender() - missing file, empty invalidList");
 
-        List *archiveIdResultList = lstNewP(sizeof(VerifyArchiveResult), .comparator =  archiveIdComparator);
+        List *archiveIdResultList = lstNewP(sizeof(VerifyArchiveResult), .comparator = archiveIdComparator);
         List *backupResultList = lstNewP(sizeof(VerifyBackupResult), .comparator = lstComparatorStr);
 
         VerifyArchiveResult archiveIdResult =
         {
             .archiveId = strNewZ("9.6-1"),
             .totalWalFile = 1,
-            .walRangeList = lstNewP(sizeof(VerifyWalRange), .comparator =  lstComparatorStr),
+            .walRangeList = lstNewP(sizeof(VerifyWalRange), .comparator = lstComparatorStr),
         };
         VerifyWalRange walRange =
         {
             .start = strNewZ("0"),
             .stop = strNewZ("2"),
-            .invalidFileList = lstNewP(sizeof(VerifyInvalidFile), .comparator =  lstComparatorStr),
+            .invalidFileList = lstNewP(sizeof(VerifyInvalidFile), .comparator = lstComparatorStr),
         };
 
         lstAdd(archiveIdResult.walRangeList, &walRange);
@@ -722,7 +720,7 @@ testRun(void)
             .backupLabel = strNewZ("test-backup-label"),
             .status = backupInvalid,
             .totalFileVerify = 1,
-            .invalidFileList = lstNewP(sizeof(VerifyInvalidFile), .comparator =  lstComparatorStr),
+            .invalidFileList = lstNewP(sizeof(VerifyInvalidFile), .comparator = lstComparatorStr),
         };
         lstAdd(backupResult.invalidFileList, &invalidFile);
         lstAdd(backupResultList, &backupResult);
@@ -804,8 +802,8 @@ testRun(void)
             "P00   WARN: invalid checksum, actual 'e056f784a995841fd4e2802b809299b8db6803a2' but expected 'BOGUS'"
                 " <REPO:ARCHIVE>/archive.info\n"
             "P00  ERROR: [029]: backup info file and archive info file do not match\n"
-            "            archive: id = 1, version = 9.4, system-id = 6625592122879095702\n"
-            "            backup : id = 2, version = 11, system-id = 6626363367545678089\n"
+            "            archive: id = 1, version = 9.4, system-id = " HRN_PG_SYSTEMID_94_Z "\n"
+            "            backup : id = 2, version = 11, system-id = " HRN_PG_SYSTEMID_11_Z "\n"
             "            HINT: this may be a symptom of repository corruption!");
 
         //--------------------------------------------------------------------------------------------------------------------------
@@ -858,19 +856,22 @@ testRun(void)
 
         String *filePathName = strNewZ(STORAGE_REPO_ARCHIVE "/testfile");
         HRN_STORAGE_PUT_EMPTY(storageRepoWrite(), strZ(filePathName));
-        TEST_RESULT_UINT(verifyFile(filePathName, STRDEF(HASH_TYPE_SHA1_ZERO), 0, NULL), verifyOk, "file ok");
+        TEST_RESULT_UINT(
+            verifyFile(filePathName, 0, NULL, compressTypeNone, STRDEF(HASH_TYPE_SHA1_ZERO), 0, NULL), verifyOk, "file ok");
 
         //--------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("file size invalid in archive");
 
         HRN_STORAGE_PUT_Z(storageRepoWrite(), strZ(filePathName), fileContents);
-        TEST_RESULT_UINT(verifyFile(filePathName, fileChecksum, 0, NULL), verifySizeInvalid, "file size invalid");
+        TEST_RESULT_UINT(
+            verifyFile(filePathName, 0, NULL, compressTypeNone, fileChecksum, 0, NULL), verifySizeInvalid, "file size invalid");
 
         //--------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("file missing in archive");
+
         TEST_RESULT_UINT(
-            verifyFile(
-                strNewFmt(STORAGE_REPO_ARCHIVE "/missingFile"), fileChecksum, 0, NULL), verifyFileMissing, "file missing");
+            verifyFile(strNewFmt(STORAGE_REPO_ARCHIVE "/missingFile"), 0, NULL, compressTypeNone, fileChecksum, 0, NULL),
+            verifyFileMissing, "file missing");
 
         //--------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("encrypted/compressed file in backup");
@@ -883,10 +884,11 @@ testRun(void)
 
         strCatZ(filePathName, ".gz");
         TEST_RESULT_UINT(
-            verifyFile(filePathName, fileChecksum, fileSize, STRDEF("pass")), verifyOk, "file encrypted compressed ok");
+            verifyFile(filePathName, 0, NULL, compressTypeGz, fileChecksum, fileSize, STRDEF("pass")),
+            verifyOk, "file encrypted compressed ok");
         TEST_RESULT_UINT(
             verifyFile(
-                filePathName, STRDEF("badchecksum"), fileSize, STRDEF("pass")), verifyChecksumMismatch,
+                filePathName, 0, NULL, compressTypeGz, STRDEF("badchecksum"), fileSize, STRDEF("pass")), verifyChecksumMismatch,
                 "file encrypted compressed checksum mismatch");
     }
 
@@ -926,8 +928,7 @@ testRun(void)
         Buffer *walBuffer = bufNew((size_t)(1024 * 1024));
         bufUsedSet(walBuffer, bufSize(walBuffer));
         memset(bufPtr(walBuffer), 0, bufSize(walBuffer));
-        hrnPgWalToBuffer(
-            (PgWal){.version = PG_VERSION_11, .systemId = 6626363367545678089, .size = 1024 * 1024}, walBuffer);
+        hrnPgWalToBuffer((PgWal){.version = PG_VERSION_11, .size = 1024 * 1024}, walBuffer);
         const char *walBufferSha1 = strZ(bufHex(cryptoHashOne(HASH_TYPE_SHA1_STR, walBuffer)));
 
         HRN_STORAGE_PUT(
@@ -1087,7 +1088,7 @@ testRun(void)
             TEST_MANIFEST_TARGET
             TEST_MANIFEST_DB
             TEST_MANIFEST_FILE
-            "pg_data/testvalid={\"checksum\":\"%s\",\"mas""ter\":true,\"size\":7,\"timestamp\":1565282114}\n"
+            "pg_data/testvalid={\"checksum\":\"%s\",\"size\":7,\"timestamp\":1565282114}\n"
             "pg_data/testzero={\"repo-size\":20,\"size\":0,\"timestamp\":1601405663}\n"
             TEST_MANIFEST_FILE_DEFAULT
             TEST_MANIFEST_LINK
@@ -1119,15 +1120,13 @@ testRun(void)
                 TEST_MANIFEST_DB
                 "\n"
                 "[target:file]\n"
-                "pg_data/PG_VERSION={\"checksum\":\"184473f470864e067ee3a22e64b47b0a1c356f29\",\"mas""ter\":true,"
+                "pg_data/PG_VERSION={\"checksum\":\"184473f470864e067ee3a22e64b47b0a1c356f29\","
                     "\"reference\":\"20181119-152900F\",\"size\":4,\"timestamp\":1565282114}\n"
-                "pg_data/testfile={\"checksum\":\"%s\",\"mas""ter\":true,\"reference\":\"20181119-152900F\",\"size\":7,"
-                    "\"timestamp\":1565282114}\n"
-                "pg_data/testfile2={\"checksum\":\"%s\",\"mas""ter\":true,\"size\":7,\"timestamp\":1565282114}\n"
+                "pg_data/testfile={\"checksum\":\"%s\",\"reference\":\"20181119-152900F\",\"size\":7,\"timestamp\":1565282114}\n"
+                "pg_data/testfile2={\"checksum\":\"%s\",\"size\":7,\"timestamp\":1565282114}\n"
                 "pg_data/testmissing="
                     "{\"checksum\":\"123473f470864e067ee3a22e64b47b0a1c356abc\",\"size\":7,\"timestamp\":1565282114}\n"
-                "pg_data/testother={\"checksum\":\"%s\",\"mas""ter\":true,\"reference\":\"UNPROCESSEDBACKUP\",\"size\":7,"
-                    "\"timestamp\":1565282114}\n"
+                "pg_data/testother={\"checksum\":\"%s\",\"reference\":\"UNPROCESSEDBACKUP\",\"size\":7,\"timestamp\":1565282114}\n"
                 TEST_MANIFEST_FILE_DEFAULT
                 TEST_MANIFEST_LINK
                 TEST_MANIFEST_LINK_DEFAULT
@@ -1293,9 +1292,8 @@ testRun(void)
             TEST_MANIFEST_DB                                                                                                       \
             "\n"                                                                                                                   \
             "[target:file]\n"                                                                                                      \
-            "pg_data/PG_VERSION="                                                                                                  \
-                "{\"checksum\":\"184473f470864e067ee3a22e64b47b0a1c356f29\",\"mas""ter\":true,\"reference\":\"20181119-152900F\"," \
-                "\"size\":4,\"timestamp\":1565282114}\n"                                                                           \
+            "pg_data/PG_VERSION={\"checksum\":\"184473f470864e067ee3a22e64b47b0a1c356f29\",\"reference\":\"20181119-152900F\""     \
+                ",\"size\":4,\"timestamp\":1565282114}\n"                                                                          \
             TEST_MANIFEST_FILE_DEFAULT                                                                                             \
             TEST_MANIFEST_LINK                                                                                                     \
             TEST_MANIFEST_LINK_DEFAULT                                                                                             \
@@ -1342,8 +1340,8 @@ testRun(void)
             TEST_MANIFEST_TARGET
             TEST_MANIFEST_DB
             TEST_MANIFEST_FILE
-            "pg_data/base/1/555_init={\"checksum\":\"%s\",\"mas""ter\":false,\"size\":1,\"timestamp\":1565282114}\n"
-            "pg_data/base/1/555_init.1={\"mas""ter\":false,\"size\":0,\"timestamp\":1565282114}\n"
+            "pg_data/base/1/555_init={\"checksum\":\"%s\",\"size\":1,\"timestamp\":1565282114}\n"
+            "pg_data/base/1/555_init.1={\"size\":0,\"timestamp\":1565282114}\n"
             TEST_MANIFEST_FILE_DEFAULT
             TEST_MANIFEST_LINK
             TEST_MANIFEST_LINK_DEFAULT
@@ -1371,8 +1369,8 @@ testRun(void)
             TEST_MANIFEST_DB
             "\n"
             "[target:file]\n"
-            "pg_data/PG_VERSION={\"checksum\":\"184473f470864e067ee3a22e64b47b0a1c356f29\",\"mas""ter\":true,"
-                "\"reference\":\"20181119-152900F\",\"size\":4,\"timestamp\":1565282114}\n"
+            "pg_data/PG_VERSION={\"checksum\":\"184473f470864e067ee3a22e64b47b0a1c356f29\",\"reference\":\"20181119-152900F\""
+                ",\"size\":4,\"timestamp\":1565282114}\n"
             TEST_MANIFEST_FILE_DEFAULT
             TEST_MANIFEST_LINK
             TEST_MANIFEST_LINK_DEFAULT
@@ -1389,6 +1387,7 @@ testRun(void)
         // Create valid full backup and valid diff backup
         manifestContent = strNewFmt(
                 TEST_MANIFEST_HEADER
+                "backup-bundle=true\n"
                 "\n"
                 "[backup:db]\n"
                 TEST_BACKUP_DB2_11
@@ -1397,7 +1396,8 @@ testRun(void)
                 TEST_MANIFEST_DB
                 "\n"
                 "[target:file]\n"
-                "pg_data/validfile={\"checksum\":\"%s\",\"mas""ter\":true,\"size\":%u,\"timestamp\":1565282114}\n"
+                "pg_data/validfile={\"bni\":1,\"bno\":3,\"checksum\":\"%s\",\"size\":%u,\"timestamp\":1565282114}\n"
+                "pg_data/zerofile={\"size\":0,\"timestamp\":1565282114}\n"
                 TEST_MANIFEST_FILE_DEFAULT
                 TEST_MANIFEST_LINK
                 TEST_MANIFEST_LINK_DEFAULT
@@ -1413,14 +1413,14 @@ testRun(void)
             .comment = "valid manifest copy - full");
 
         HRN_STORAGE_PUT_Z(
-            storageRepoWrite(), STORAGE_REPO_BACKUP  "/20201119-163000F/pg_data/validfile", fileContents, .comment = "valid file");
+            storageRepoWrite(), STORAGE_REPO_BACKUP  "/20201119-163000F/bundle/1", strZ(strNewFmt("XXX%s", fileContents)),
+            .comment = "valid file");
 
         // Create WAL file with just header info and small WAL size
         Buffer *walBuffer = bufNew((size_t)(1024 * 1024));
         bufUsedSet(walBuffer, bufSize(walBuffer));
         memset(bufPtr(walBuffer), 0, bufSize(walBuffer));
-        hrnPgWalToBuffer(
-            (PgWal){.version = PG_VERSION_11, .systemId = 6626363367545678089, .size = 1024 * 1024}, walBuffer);
+        hrnPgWalToBuffer((PgWal){.version = PG_VERSION_11, .size = 1024 * 1024}, walBuffer);
         const char *walBufferSha1 = strZ(bufHex(cryptoHashOne(HASH_TYPE_SHA1_STR, walBuffer)));
 
         HRN_STORAGE_PUT(
@@ -1441,7 +1441,7 @@ testRun(void)
             "                missing: 1, checksum invalid: 1, size invalid: 1, other: 0\n"
             "              backup: 20181119-152900F_20181119-152909D, status: invalid, total files checked: 1, total valid files: 0\n"
             "                missing: 0, checksum invalid: 1, size invalid: 0, other: 0\n"
-            "              backup: 20201119-163000F, status: valid, total files checked: 1, total valid files: 1\n"
+            "              backup: 20201119-163000F, status: valid, total files checked: 2, total valid files: 2\n"
             "                missing: 0, checksum invalid: 0, size invalid: 0, other: 0");
     }
 
