@@ -7,12 +7,13 @@ Test Exit Routines
 #include "version.h"
 
 #include "common/harnessConfig.h"
+#include "common/harnessError.h"
 #include "common/harnessFork.h"
 
 /***********************************************************************************************************************************
 Test Run
 ***********************************************************************************************************************************/
-void
+static void
 testRun(void)
 {
     FUNCTION_HARNESS_VOID();
@@ -29,87 +30,86 @@ testRun(void)
     // *****************************************************************************************************************************
     if (testBegin("exitInit() and exitOnSignal()"))
     {
-        cfgInit();
+        HRN_CFG_LOAD(cfgCmdHelp, strLstNew());
 
-        HARNESS_FORK_BEGIN()
+        HRN_FORK_BEGIN()
         {
-            HARNESS_FORK_CHILD_BEGIN(errorTypeCode(&TermError), false)
+            HRN_FORK_CHILD_BEGIN(.expectedExitStatus = errorTypeCode(&TermError))
             {
                 exitInit();
                 raise(SIGTERM);
             }
-            HARNESS_FORK_CHILD_END();                               // {uncoverable - signal is raised in block}
+            HRN_FORK_CHILD_END();                               // {uncoverable - signal is raised in block}
         }
-        HARNESS_FORK_END();
+        HRN_FORK_END();
     }
 
     // *****************************************************************************************************************************
     if (testBegin("exitSafe()"))
     {
-        cfgInit();
-        cfgCommandSet(cfgCmdNone, cfgCmdRoleDefault);
+        HRN_CFG_LOAD(cfgCmdHelp, strLstNew());
+        cfgCommandSet(cfgCmdNone, cfgCmdRoleMain);
 
-        TEST_RESULT_INT(exitSafe(0, false, signalTypeNone), 0, "exit with no command")
+        TEST_RESULT_INT(exitSafe(0, false, signalTypeNone), 0, "exit with no command");
 
         // -------------------------------------------------------------------------------------------------------------------------
-        cfgInit();
-        cfgCommandSet(cfgCmdArchivePush, cfgCmdRoleDefault);
+        StringList *argList = strLstNew();
+        hrnCfgArgRawZ(argList, cfgOptStanza, "test");
+        hrnCfgArgRawNegate(argList, cfgOptLogTimestamp);
+        HRN_CFG_LOAD(cfgCmdArchivePush, argList);
 
-        TEST_RESULT_INT(exitSafe(0, false, signalTypeNone), 0, "exit with no error")
-        harnessLogResult("P00   INFO: archive-push command end: completed successfully");
+        TEST_RESULT_INT(exitSafe(0, false, signalTypeNone), 0, "exit with no error");
+        TEST_RESULT_LOG("P00   INFO: archive-push command end: completed successfully");
 
-        TEST_RESULT_INT(exitSafe(1, false, signalTypeNone), 1, "exit with no error")
-        harnessLogResult("P00   INFO: archive-push command end: completed successfully");
+        TEST_RESULT_INT(exitSafe(1, false, signalTypeNone), 1, "exit with no error");
+        TEST_RESULT_LOG("P00   INFO: archive-push command end: completed successfully");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TRY_BEGIN()
         {
             THROW(RuntimeError, "test error message");
         }
-        CATCH_ANY()
+        CATCH_FATAL()
         {
             exitSafe(0, true, signalTypeNone);
-            harnessLogResult(
+            TEST_RESULT_LOG(
                 "P00  ERROR: [122]: test error message\n"
                 "P00   INFO: archive-push command end: aborted with exception [122]");
         }
         TRY_END();
 
         // -------------------------------------------------------------------------------------------------------------------------
-        StringList *argList = strLstNew();
-        strLstAddZ(argList, PROJECT_BIN);
+        argList = strLstNew();
         strLstAddZ(argList, "--" CFGOPT_STANZA "=test");
         strLstAddZ(argList, "--" CFGOPT_PROCESS_MAX "=4");
-        strLstAddZ(argList, CFGCMD_ARCHIVE_PUSH ":" CONFIG_COMMAND_ROLE_ASYNC);
-        harnessCfgLoadRaw(strLstSize(argList), strLstPtr(argList));
+        HRN_CFG_LOAD(cfgCmdArchivePush, argList, .role = cfgCmdRoleAsync, .noStd = true);
 
         harnessLogLevelSet(logLevelDebug);
 
         TRY_BEGIN()
         {
-            THROW(RuntimeError, "test debug error message");
+            hrnErrorThrowP(.errorType = &RuntimeError, .message = "test debug error message");
         }
-        CATCH_ANY()
+        CATCH_FATAL()
         {
             exitSafe(0, true, signalTypeNone);
-            harnessLogResult(
-                "P00  DEBUG:     common/exit::exitSafe: (result: 0, error: true, signalType: 0)\n"
+            TEST_RESULT_LOG(
+                "P00  DEBUG:     " TEST_PGB_PATH "/src/common/exit::exitSafe: (result: 0, error: true, signalType: 0)\n"
                 "P00  ERROR: [122]: test debug error message\n"
                 "            --------------------------------------------------------------------\n"
                 "            If SUBMITTING AN ISSUE please provide the following information:\n"
                 "            \n"
                 "            version: " PROJECT_VERSION "\n"
                 "            command: archive-push:async\n"
-                "            options: --process-max=4 --stanza=test\n"
+                "            options: --exec-id=1-test --process-max=4 --stanza=test\n"
                 "            \n"
                 "            stack trace:\n"
-                "            test/module/common/exitTest:testRun:90:(void)\n"
-                "            test:main:(argListSize: 1, argList: (char *[]))\n"
+                "            ERR_STACK_TRACE\n"
                 "            --------------------------------------------------------------------\n"
                 "P00   INFO: archive-push:async command end: aborted with exception [122]\n"
-                "P00  DEBUG:     common/lock::lockRelease: (failOnNoLock: false)\n"
-                "P00  DEBUG:     common/lock::lockRelease: => false\n"
-                "P00  DEBUG:     common/exit::exitSafe: => 122");
+                "P00  DEBUG:     " TEST_PGB_PATH "/src/common/lock::lockRelease: (failOnNoLock: false)\n"
+                "P00  DEBUG:     " TEST_PGB_PATH "/src/common/lock::lockRelease: => false\n"
+                "P00  DEBUG:     " TEST_PGB_PATH "/src/common/exit::exitSafe: => 122");
         }
         TRY_END();
 
@@ -118,23 +118,22 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TRY_BEGIN()
         {
-            THROW(AssertError, "test assert message");
+            hrnErrorThrowP(.message = "test assert message");
         }
-        CATCH_ANY()
+        CATCH_FATAL()
         {
             exitSafe(0, true, signalTypeNone);
-            harnessLogResult(
+            TEST_RESULT_LOG(
                 "P00 ASSERT: [025]: test assert message\n"
                 "            --------------------------------------------------------------------\n"
                 "            If SUBMITTING AN ISSUE please provide the following information:\n"
                 "            \n"
                 "            version: " PROJECT_VERSION "\n"
                 "            command: archive-push:async\n"
-                "            options: --process-max=4 --stanza=test\n"
+                "            options: --exec-id=1-test --process-max=4 --stanza=test\n"
                 "            \n"
                 "            stack trace:\n"
-                "            test/module/common/exitTest:testRun:121:(void)\n"
-                "            test:main:(argListSize: 1, argList: (char *[]))\n"
+                "            ERR_STACK_TRACE\n"
                 "            --------------------------------------------------------------------\n"
                 "P00   INFO: archive-push:async command end: aborted with exception [025]");
         }
@@ -143,13 +142,13 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_RESULT_INT(
             exitSafe(errorTypeCode(&TermError), false, signalTypeNone), errorTypeCode(&TermError), "exit on term with no signal");
-        harnessLogResult("P00   INFO: archive-push:async command end: terminated on signal from child process");
+        TEST_RESULT_LOG("P00   INFO: archive-push:async command end: terminated on signal from child process");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_RESULT_INT(
             exitSafe(errorTypeCode(&TermError), false, signalTypeTerm), errorTypeCode(&TermError), "exit on term with SIGTERM");
-        harnessLogResult("P00   INFO: archive-push:async command end: terminated on signal [SIGTERM]");
+        TEST_RESULT_LOG("P00   INFO: archive-push:async command end: terminated on signal [SIGTERM]");
     }
 
-    FUNCTION_HARNESS_RESULT_VOID();
+    FUNCTION_HARNESS_RETURN_VOID();
 }
