@@ -77,7 +77,18 @@ testRun(void)
         TEST_RESULT_STR_Z(httpHeaderGet(header, STRDEF("key2")), "value2a, value2b", "get value");
         TEST_RESULT_STR(httpHeaderGet(header, STRDEF(BOGUS_STR)), NULL, "get missing value");
 
-        TEST_RESULT_STR_Z(httpHeaderToLog(header), "{key1: 'value1', key2: 'value2a, value2b'}", "log output");
+        TEST_RESULT_STR(httpHeaderGet(httpHeaderPutRange(header, 0, NULL), HTTP_HEADER_RANGE_STR), NULL, "do not put range header");
+        TEST_RESULT_STR_Z(
+            httpHeaderGet(httpHeaderPutRange(header, 1, VARUINT64(21)), HTTP_HEADER_RANGE_STR), "bytes=1-21",
+            "put range header with offset and limit");
+        TEST_RESULT_STR_Z(
+            httpHeaderGet(httpHeaderPutRange(header, 0, VARUINT64(21)), HTTP_HEADER_RANGE_STR), "bytes=0-20",
+            "put range header with offset and limit");
+        TEST_RESULT_STR_Z(
+            httpHeaderGet(httpHeaderPutRange(header, 44, NULL), HTTP_HEADER_RANGE_STR), "bytes=44-",
+            "put range header with offset");
+
+        TEST_RESULT_STR_Z(httpHeaderToLog(header), "{key1: 'value1', key2: 'value2a, value2b', range: 'bytes=44-'}", "log output");
 
         TEST_RESULT_VOID(httpHeaderFree(header), "free header");
 
@@ -514,7 +525,7 @@ testRun(void)
                 TEST_RESULT_BOOL(httpResponseEof(response), true, "io is eof");
                 TEST_RESULT_PTR(response->session, NULL, "session is not busy");
                 TEST_RESULT_STR_Z(
-                    httpHeaderToLog(httpResponseHeader(response)),  "{content-length: '380'}", "check response headers");
+                    httpHeaderToLog(httpResponseHeader(response)), "{content-length: '380'}", "check response headers");
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("head request with transfer encoding but no content");
@@ -530,7 +541,7 @@ testRun(void)
                 TEST_RESULT_BOOL(httpResponseEof(response), true, "io is eof");
                 TEST_RESULT_PTR(response->session, NULL, "session is not busy");
                 TEST_RESULT_STR_Z(
-                    httpHeaderToLog(httpResponseHeader(response)),  "{transfer-encoding: 'chunked'}", "check response headers");
+                    httpHeaderToLog(httpResponseHeader(response)), "{transfer-encoding: 'chunked'}", "check response headers");
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("head request with connection close but no content");
@@ -546,7 +557,7 @@ testRun(void)
                 TEST_RESULT_BOOL(httpResponseEof(response), true, "io is eof");
                 TEST_RESULT_PTR(response->session, NULL, "session is not busy");
                 TEST_RESULT_STR_Z(
-                    httpHeaderToLog(httpResponseHeader(response)),  "{connection: 'close'}", "check response headers");
+                    httpHeaderToLog(httpResponseHeader(response)), "{connection: 'close'}", "check response headers");
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("error with content (with a few slow down errors)");
@@ -575,19 +586,21 @@ testRun(void)
                 TEST_RESULT_BOOL(httpResponseCodeOk(response), false, "check response code error");
                 TEST_RESULT_STR_Z(httpResponseReason(response), "Not Found", "check response message");
                 TEST_RESULT_STR_Z(
-                    httpHeaderToLog(httpResponseHeader(response)),  "{}", "check response headers");
+                    httpHeaderToLog(httpResponseHeader(response)), "{}", "check response headers");
 
                 TEST_ERROR(
                     httpRequestError(request, response), ProtocolError,
                     "HTTP request failed with 404 (Not Found):\n"
                     "*** Path/Query ***:\n"
-                    "/");
+                    "GET /");
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("error with content");
 
                 hrnServerScriptExpectZ(http, "GET /?a=b HTTP/1.1\r\n" TEST_USER_AGENT "hdr1:1\r\nhdr2:2\r\n\r\n");
-                hrnServerScriptReplyZ(http, "HTTP/1.1 403 \r\ncontent-length:7\r\n\r\nCONTENT");
+                hrnServerScriptReplyZ(http, "HTTP/1.1 403 \r\nconnection:close\r\ncontent-type:application/json\r\n\r\nCONTENT");
+
+                hrnServerScriptClose(http);
 
                 StringList *headerRedact = strLstNew();
                 strLstAdd(headerRedact, STRDEF("hdr2"));
@@ -605,34 +618,81 @@ testRun(void)
                 TEST_RESULT_UINT(httpResponseCode(response), 403, "check response code");
                 TEST_RESULT_STR_Z(httpResponseReason(response), "", "check empty response message");
                 TEST_RESULT_STR_Z(
-                    httpHeaderToLog(httpResponseHeader(response)),  "{content-length: '7'}", "check response headers");
-                TEST_RESULT_STR_Z(strNewBuf(httpResponseContent(response)),  "CONTENT", "check response content");
+                    httpHeaderToLog(httpResponseHeader(response)), "{connection: 'close', content-type: 'application/json'}",
+                    "check response headers");
+                TEST_RESULT_STR_Z(strNewBuf(httpResponseContent(response)), "CONTENT", "check response content");
 
                 TEST_ERROR(
                     httpRequestError(request, response), ProtocolError,
                     "HTTP request failed with 403:\n"
                     "*** Path/Query ***:\n"
-                    "/?a=b\n"
+                    "GET /?a=b\n"
                     "*** Request Headers ***:\n"
                     "hdr1: 1\n"
                     "hdr2: <redacted>\n"
                     "*** Response Headers ***:\n"
-                    "content-length: 7\n"
+                    "connection: close\n"
+                    "content-type: application/json\n"
                     "*** Response Content ***:\n"
                     "CONTENT");
 
+                // -----------------------------------------------------------------------------------------------------------------
+                TEST_TITLE("end server process");
+
+                hrnServerScriptEnd(http);
+            }
+            HRN_FORK_PARENT_END();
+        }
+        HRN_FORK_END();
+
+        HRN_FORK_BEGIN()
+        {
+            // Start HTTPS test server
+            HRN_FORK_CHILD_BEGIN(.prefix = "test server", .timeout = 5000)
+            {
+                // Set buffer size large enough for server to read expect messages
+                ioBufferSizeSet(65536);
+
+                TEST_RESULT_VOID(hrnServerRunP(HRN_FORK_CHILD_READ(), hrnServerProtocolTls), "http server run");
+            }
+            HRN_FORK_CHILD_END();
+
+            HRN_FORK_PARENT_BEGIN()
+            {
+                IoWrite *http = hrnServerScriptBegin(HRN_FORK_PARENT_WRITE(0));
+
+                // -----------------------------------------------------------------------------------------------------------------
+                TEST_TITLE("create client");
+
+                ioBufferSizeSet(35);
+
+                TEST_ASSIGN(
+                    client,
+                    httpClientNew(
+                        tlsClientNewP(
+                            sckClientNew(hrnServerHost(), hrnServerPort(0), 5000, 5000), hrnServerHost(), 0, 0, TEST_IN_CONTAINER),
+                        5000),
+                    "new client");
+
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("request with content using content-length");
 
+                hrnServerScriptAccept(http);
+
                 hrnServerScriptExpectZ(
                     http, "GET /path/file%201.txt HTTP/1.1\r\n" TEST_USER_AGENT "content-length:30\r\n\r\n"
                         "012345678901234567890123456789");
-                hrnServerScriptReplyZ(http, "HTTP/1.1 200 OK\r\nConnection:close\r\n\r\n01234567890123456789012345678901");
+                hrnServerScriptReplyZ(
+                    http,
+                    "HTTP/1.1 200 OK\r\nConnection:ClosE\r\ncontent-type:application/xml\r\n\r\n01234567890123456789012345678901");
 
-                hrnServerScriptClose(http);
+                // Abort connect without proper TLS shutdown to show that all bytes are read correctly for content type xml
+                hrnServerScriptAbort(http);
 
                 ioBufferSizeSet(30);
 
+                HttpResponse *response = NULL;
+
                 TEST_ASSIGN(
                     response,
                     httpRequestResponse(
@@ -641,9 +701,11 @@ testRun(void)
                             .header = httpHeaderAdd(httpHeaderNew(NULL), STRDEF("content-length"), STRDEF("30")),
                             .content = BUFSTRDEF("012345678901234567890123456789")), true),
                     "request");
+                TEST_RESULT_BOOL(httpResponseReadIgnoreUnexpectedEof(response), true, "check unexpected eof allowed");
                 TEST_RESULT_STR_Z(
-                    httpHeaderToLog(httpResponseHeader(response)),  "{connection: 'close'}", "check response headers");
-                TEST_RESULT_STR_Z(strNewBuf(httpResponseContent(response)),  "01234567890123456789012345678901", "check response");
+                    httpHeaderToLog(httpResponseHeader(response)), "{connection: 'close', content-type: 'application/xml'}",
+                    "check response headers");
+                TEST_RESULT_STR_Z(strNewBuf(httpResponseContent(response)), "01234567890123456789012345678901", "check response");
                 TEST_RESULT_UINT(httpResponseRead(response, bufNew(1), true), 0, "call internal read to check eof");
 
                 // -----------------------------------------------------------------------------------------------------------------
@@ -665,7 +727,7 @@ testRun(void)
                     httpRequestResponse(
                         httpRequestNewP(client, STRDEF("GET"), httpUriEncode(STRDEF("/path/file 1.txt"), true)), true),
                     "request");
-                TEST_RESULT_STR_Z(strNewBuf(httpResponseContent(response)),  "01234567890123456789012345678901", "check response");
+                TEST_RESULT_STR_Z(strNewBuf(httpResponseContent(response)), "01234567890123456789012345678901", "check response");
                 TEST_RESULT_UINT(httpResponseRead(response, bufNew(1), true), 0, "call internal read to check eof");
 
                 // -----------------------------------------------------------------------------------------------------------------
@@ -700,12 +762,12 @@ testRun(void)
 
                 TEST_ASSIGN(response, httpRequestResponse(httpRequestNewP(client, STRDEF("GET"), STRDEF("/")), false), "request");
                 TEST_RESULT_STR_Z(
-                    httpHeaderToLog(httpResponseHeader(response)),  "{transfer-encoding: 'chunked'}", "check response headers");
+                    httpHeaderToLog(httpResponseHeader(response)), "{transfer-encoding: 'chunked'}", "check response headers");
 
                 Buffer *buffer = bufNew(35);
 
-                TEST_RESULT_VOID(ioRead(httpResponseIoRead(response), buffer),  "read response");
-                TEST_RESULT_STR_Z(strNewBuf(buffer),  "01234567890123456789012345678901012", "check response");
+                TEST_RESULT_VOID(ioRead(httpResponseIoRead(response), buffer), "read response");
+                TEST_RESULT_STR_Z(strNewBuf(buffer), "01234567890123456789012345678901012", "check response");
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("close connection and end server process");
