@@ -413,8 +413,7 @@ testRun(void)
         // Mixed line and buffer read
         // -------------------------------------------------------------------------------------------------------------------------
         ioBufferSizeSet(5);
-        read = ioBufferReadNew(BUFSTRDEF("AAAAAA123\n1234\n\n12\nBDDDEFF"));
-        ioReadOpen(read);
+        read = ioBufferReadNewOpen(BUFSTRDEF("AAAAAA123\n1234\n\n12\nBDDDEFF"));
         buffer = bufNew(6);
 
         // Start with a small read
@@ -459,21 +458,33 @@ testRun(void)
 
         // Error if buffer is full and there is no linefeed
         ioBufferSizeSet(10);
-        read = ioBufferReadNew(BUFSTRDEF("0123456789"));
-        ioReadOpen(read);
+        read = ioBufferReadNewOpen(BUFSTRDEF("0123456789"));
         TEST_ERROR(ioReadLine(read), FileReadError, "unable to find line in 10 byte buffer");
 
         // Read line without eof
-        read = ioBufferReadNew(BUFSTRDEF("1234"));
-        ioReadOpen(read);
+        read = ioBufferReadNewOpen(BUFSTRDEF("1234"));
         TEST_RESULT_STR_Z(ioReadLineParam(read, true), "1234", "read line without eof");
 
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("ioCopy()");
+
+        ioBufferSizeSet(4);
+
+        bufferRead = ioBufferReadNewOpen(BUFSTRDEF("a test string"));
+
+        buffer = bufNew(0);
+        IoWrite *bufferWrite = ioBufferWriteNewOpen(buffer);
+
+        TEST_RESULT_VOID(ioCopy(bufferRead, bufferWrite), "copy buffer");
+        TEST_RESULT_VOID(ioWriteClose(bufferWrite), "close write");
+
+        TEST_RESULT_STR_Z(strNewBuf(buffer), "a test string", "check buffer");
+
         // Read IO into a buffer
         // -------------------------------------------------------------------------------------------------------------------------
         ioBufferSizeSet(8);
 
-        bufferRead = ioBufferReadNew(BUFSTRDEF("a test string"));
-        ioReadOpen(bufferRead);
+        bufferRead = ioBufferReadNewOpen(BUFSTRDEF("a test string"));
 
         TEST_RESULT_STR_Z(strNewBuf(ioReadBuf(bufferRead)), "a test string", "read into buffer");
 
@@ -677,8 +688,8 @@ testRun(void)
             THROW_ON_SYS_ERROR((flags = fcntl(fd, F_GETFL)) == -1, ProtocolError, "unable to get flags");
             THROW_ON_SYS_ERROR(fcntl(fd, F_SETFL, flags | O_NONBLOCK) == -1, ProtocolError, "unable to set O_NONBLOCK");
 
-            // Attempt connection
-            CHECK(connect(fd, hostBadAddress->ai_addr, hostBadAddress->ai_addrlen) == -1);
+            // Make sure the bad address does not work before using it for testing
+            ASSERT(connect(fd, hostBadAddress->ai_addr, hostBadAddress->ai_addrlen) == -1);
 
             // Create file descriptor write and wait for timeout
             IoWrite *write = NULL;
