@@ -127,6 +127,15 @@ static const char *const testClientBadCa =
     "qGj7FtRiSdjkZ7pmNpma6ycPR0RBZyL3aHnig+DDfRRt8TgrZzY3aXBReONb\n"
     "-----END CERTIFICATE-----";
 
+/***********************************************************************************************************************************
+Test signal handler that does nothing
+***********************************************************************************************************************************/
+static void
+testSignalHandler(const int signalType)
+{
+    (void)signalType;
+}
+
 /***********************************************************************************************************************************
 Test Run
 ***********************************************************************************************************************************/
@@ -255,8 +264,8 @@ testRun(void)
             // ---------------------------------------------------------------------------------------------------------------------
             TEST_TITLE("connect to non-blocking socket to test write ready");
 
-            // Attempt connection
-            CHECK(connect(fd, hostBadAddress->ai_addr, hostBadAddress->ai_addrlen) == -1);
+            // Make sure the bad address does not work before using it for testing
+            ASSERT(connect(fd, hostBadAddress->ai_addr, hostBadAddress->ai_addrlen) == -1);
 
             // Create socket session and wait for timeout
             IoSession *session = NULL;
@@ -299,7 +308,7 @@ testRun(void)
     }
 
     // *****************************************************************************************************************************
-    if (testBegin("SocketClient"))
+    if (testBegin("SocketClient/SocketServer"))
     {
         IoClient *client = NULL;
 
@@ -311,6 +320,37 @@ testRun(void)
         // This address should not be in use in a test environment -- if it is the test will fail
         TEST_ASSIGN(client, sckClientNew(STRDEF("172.31.255.255"), hrnServerPort(0), 100, 100), "new client");
         TEST_ERROR_FMT(ioClientOpen(client), HostConnectError, "timeout connecting to '172.31.255.255:%u'", hrnServerPort(0));
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("sckServerAccept() returns NULL on interrupt");
+
+        HRN_FORK_BEGIN(.timeout = 5000)
+        {
+            HRN_FORK_CHILD_BEGIN(.prefix = "sighup server")
+            {
+                // Ignore SIGHUP
+                sigaction(SIGHUP, &(struct sigaction){.sa_handler = testSignalHandler}, NULL);
+
+                // Wait for connection. Use port 1 to avoid port conflicts later.
+                IoServer *server = sckServerNew(STRDEF("127.0.0.1"), hrnServerPort(1), 5000);
+                HRN_FORK_CHILD_NOTIFY_PUT();
+
+                TEST_RESULT_PTR(ioServerAccept(server, NULL), NULL, "connection interrupted");
+            }
+            HRN_FORK_CHILD_END();
+
+            HRN_FORK_PARENT_BEGIN(.prefix = "sighup client")
+            {
+                // Wait for client to be ready but also sleep a bit more to allow accept to initialize
+                HRN_FORK_PARENT_NOTIFY_GET(0);
+                sleep(1);
+
+                // Send SIGHUP and the client should exit
+                kill(HRN_FORK_PROCESS_ID(0), SIGHUP);
+            }
+            HRN_FORK_PARENT_END();
+        }
+        HRN_FORK_END();
     }
 
     // Additional coverage not provided by testing with actual certificates
@@ -338,17 +378,13 @@ testRun(void)
         // Connection errors
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_ASSIGN(
-            client,
-            tlsClientNew(sckClientNew(STRDEF("99.99.99.99.99"), 7777, 0, 0), STRDEF("X"), 0, 0, true, NULL, NULL, NULL, NULL),
-            "new client");
+            client, tlsClientNewP(sckClientNew(STRDEF("99.99.99.99.99"), 7777, 0, 0), STRDEF("X"), 0, 0, true), "new client");
         TEST_RESULT_STR_Z(ioClientName(client), "99.99.99.99.99:7777", " check name");
         TEST_ERROR(
             ioClientOpen(client), HostConnectError, "unable to get address for '99.99.99.99.99': [-2] Name or service not known");
 
         TEST_ASSIGN(
-            client,
-            tlsClientNew(
-                sckClientNew(STRDEF("localhost"), hrnServerPort(0), 100, 100), STRDEF("X"), 100, 100, true, NULL, NULL, NULL, NULL),
+            client, tlsClientNewP(sckClientNew(STRDEF("localhost"), hrnServerPort(0), 100, 100), STRDEF("X"), 100, 100, true),
             "new client");
         TEST_ERROR_FMT(
             ioClientOpen(client), HostConnectError, "unable to connect to 'localhost:%u': [111] Connection refused",
@@ -359,9 +395,9 @@ testRun(void)
 
         TEST_ERROR(
             ioClientOpen(
-                tlsClientNew(
-                    sckClientNew(STRDEF("localhost"), hrnServerPort(0), 5000, 5000), STRDEF("X"), 0, 0, true, STRDEF("bogus.crt"),
-                    STRDEF("/bogus"), NULL, NULL)),
+                tlsClientNewP(
+                    sckClientNew(STRDEF("localhost"), hrnServerPort(0), 5000, 5000), STRDEF("X"), 0, 0, true,
+                    .caFile = STRDEF("bogus.crt"), .caPath = STRDEF("/bogus"))),
             CryptoError, "unable to set user-defined CA certificate location: [33558530] No such file or directory");
 
         // -------------------------------------------------------------------------------------------------------------------------
@@ -369,9 +405,9 @@ testRun(void)
 
         TEST_ERROR(
             ioClientOpen(
-                tlsClientNew(
-                    sckClientNew(STRDEF("localhost"), hrnServerPort(0), 5000, 5000), STRDEF("X"), 0, 0, true, NULL, NULL,
-                    STRDEF("/bogus"), STRDEF("/bogus"))),
+                tlsClientNewP(
+                    sckClientNew(STRDEF("localhost"), hrnServerPort(0), 5000, 5000), STRDEF("X"), 0, 0, true,
+                    .certFile = STRDEF("/bogus"), .keyFile = STRDEF("/bogus"))),
             CryptoError, "unable to load cert file '/bogus': [33558530] No such file or directory");
 
         // -------------------------------------------------------------------------------------------------------------------------
@@ -379,9 +415,9 @@ testRun(void)
 
         TEST_ERROR(
             ioClientOpen(
-                tlsClientNew(
-                    sckClientNew(STRDEF("localhost"), hrnServerPort(0), 5000, 5000), STRDEF("X"), 0, 0, true, NULL, NULL,
-                    STRDEF(HRN_SERVER_CLIENT_CERT), STRDEF("/bogus"))),
+                tlsClientNewP(
+                    sckClientNew(STRDEF("localhost"), hrnServerPort(0), 5000, 5000), STRDEF("X"), 0, 0, true,
+                    .certFile = STRDEF(HRN_SERVER_CLIENT_CERT), .keyFile = STRDEF("/bogus"))),
             CryptoError, "unable to load key file '/bogus': [33558530] No such file or directory");
 
         // -------------------------------------------------------------------------------------------------------------------------
@@ -389,9 +425,9 @@ testRun(void)
 
         TEST_ERROR(
             ioClientOpen(
-                tlsClientNew(
-                    sckClientNew(STRDEF("localhost"), hrnServerPort(0), 5000, 5000), STRDEF("X"), 0, 0, true, NULL, NULL,
-                    STRDEF(HRN_SERVER_CLIENT_CERT), STRDEF(HRN_SERVER_KEY))),
+                tlsClientNewP(
+                    sckClientNew(STRDEF("localhost"), hrnServerPort(0), 5000, 5000), STRDEF("X"), 0, 0, true,
+                    .certFile = STRDEF(HRN_SERVER_CLIENT_CERT), .keyFile = STRDEF(HRN_SERVER_KEY))),
             CryptoError,
             "unable to load key file '" HRN_PATH_REPO "/test/certificate/pgbackrest-test-server.key': [185073780] key values"
                 " mismatch");
@@ -404,17 +440,17 @@ testRun(void)
         TRY_BEGIN()
         {
             TEST_ERROR(
-                tlsClientNew(
-                    sckClientNew(STRDEF("localhost"), hrnServerPort(0), 5000, 5000), STRDEF("X"), 0, 0, true, NULL, NULL,
-                    STRDEF(HRN_SERVER_CLIENT_CERT), STRDEF(TEST_PATH "/client-pwd.key")),
+                tlsClientNewP(
+                    sckClientNew(STRDEF("localhost"), hrnServerPort(0), 5000, 5000), STRDEF("X"), 0, 0, true,
+                    .certFile = STRDEF(HRN_SERVER_CLIENT_CERT), .keyFile = STRDEF(TEST_PATH "/client-pwd.key")),
                 CryptoError, "unable to load key file '" TEST_PATH "/client-pwd.key': [101077092] bad decrypt");
         }
         CATCH(TestError)
         {
             TEST_ERROR(                                                                             // {uncovered - 32-bit error}
-                tlsClientNew(
-                    sckClientNew(STRDEF("localhost"), hrnServerPort(0), 5000, 5000), STRDEF("X"), 0, 0, true, NULL, NULL,
-                    STRDEF(HRN_SERVER_CLIENT_CERT), STRDEF(TEST_PATH "/client-pwd.key")),
+                tlsClientNewP(
+                    sckClientNew(STRDEF("localhost"), hrnServerPort(0), 5000, 5000), STRDEF("X"), 0, 0, true,
+                    .certFile = STRDEF(HRN_SERVER_CLIENT_CERT), .keyFile = STRDEF(TEST_PATH "/client-pwd.key")),
                 CryptoError, "unable to load key file '" TEST_PATH "/client-pwd.key': [151429224] bad password read");
         }
         TRY_END();
@@ -428,9 +464,9 @@ testRun(void)
 
         TEST_ERROR(
             ioClientOpen(
-                tlsClientNew(
-                    sckClientNew(STRDEF("localhost"), hrnServerPort(0), 5000, 5000), STRDEF("X"), 0, 0, true, NULL, NULL,
-                    STRDEF(HRN_SERVER_CLIENT_CERT), STRDEF(TEST_PATH "/client-bad-perm.key"))),
+                tlsClientNewP(
+                    sckClientNew(STRDEF("localhost"), hrnServerPort(0), 5000, 5000), STRDEF("X"), 0, 0, true,
+                    .certFile = STRDEF(HRN_SERVER_CLIENT_CERT), .keyFile = STRDEF(TEST_PATH "/client-bad-perm.key"))),
             FileReadError,
             "key file '" TEST_PATH "/client-bad-perm.key' has group or other permissions\n"
             "HINT: file must have permissions u=rw (0600) or less if owned by the '" TEST_USER "' user\n"
@@ -447,9 +483,9 @@ testRun(void)
 
         TEST_ERROR(
             ioClientOpen(
-                tlsClientNew(
-                    sckClientNew(STRDEF("localhost"), hrnServerPort(0), 5000, 5000), STRDEF("X"), 0, 0, true, NULL, NULL,
-                    STRDEF(HRN_SERVER_CLIENT_CERT), STRDEF(TEST_PATH "/client-bad-perm.key"))),
+                tlsClientNewP(
+                    sckClientNew(STRDEF("localhost"), hrnServerPort(0), 5000, 5000), STRDEF("X"), 0, 0, true,
+                    .certFile = STRDEF(HRN_SERVER_CLIENT_CERT), .keyFile = STRDEF(TEST_PATH "/client-bad-perm.key"))),
             FileReadError, "key file '" TEST_PATH "/client-bad-perm.key' must be owned by the '" TEST_USER "' user or root");
 
         // -------------------------------------------------------------------------------------------------------------------------
@@ -459,9 +495,9 @@ testRun(void)
 
         TEST_ERROR(
             ioClientOpen(
-                tlsClientNew(
-                    sckClientNew(STRDEF("localhost"), hrnServerPort(0), 5000, 5000), STRDEF("X"), 0, 0, true, NULL, NULL,
-                    STRDEF(HRN_SERVER_CLIENT_CERT), STRDEF(TEST_PATH "/client-bad-perm.key"))),
+                tlsClientNewP(
+                    sckClientNew(STRDEF("localhost"), hrnServerPort(0), 5000, 5000), STRDEF("X"), 0, 0, true,
+                    .certFile = STRDEF(HRN_SERVER_CLIENT_CERT), .keyFile = STRDEF(TEST_PATH "/client-bad-perm.key"))),
             FileReadError,
             "key file '" TEST_PATH "/client-bad-perm.key' has group or other permissions\n"
             "HINT: file must have permissions u=rw (0600) or less if owned by the '" TEST_USER "' user\n"
@@ -502,9 +538,9 @@ testRun(void)
 
                 TEST_ERROR_FMT(
                     ioClientOpen(
-                        tlsClientNew(
-                            sckClientNew(STRDEF("localhost"), hrnServerPort(0), 5000, 5000), STRDEF("X"), 0, 0, true, NULL,
-                            STRDEF("/bogus"), NULL, NULL)),
+                        tlsClientNewP(
+                            sckClientNew(STRDEF("localhost"), hrnServerPort(0), 5000, 5000), STRDEF("X"), 0, 0, true,
+                            .caPath = STRDEF("/bogus"))),
                     CryptoError,
                     "unable to verify certificate presented by 'localhost:%u': [20] unable to get local issuer certificate",
                     hrnServerPort(0));
@@ -517,9 +553,9 @@ testRun(void)
 
                 TEST_RESULT_VOID(
                     ioClientOpen(
-                        tlsClientNew(
+                        tlsClientNewP(
                             sckClientNew(STRDEF("test.pgbackrest.org"), hrnServerPort(0), 5000, 5000),
-                            STRDEF("test.pgbackrest.org"), 0, 0, true, STRDEF(HRN_SERVER_CA), NULL, NULL, NULL)),
+                            STRDEF("test.pgbackrest.org"), 0, 0, true, .caFile = STRDEF(HRN_SERVER_CA))),
                     "open connection");
 
                 // -----------------------------------------------------------------------------------------------------------------
@@ -530,9 +566,9 @@ testRun(void)
 
                 TEST_RESULT_VOID(
                     ioClientOpen(
-                        tlsClientNew(
+                        tlsClientNewP(
                             sckClientNew(STRDEF("host.test2.pgbackrest.org"), hrnServerPort(0), 5000, 5000),
-                            STRDEF("host.test2.pgbackrest.org"), 0, 0, true, STRDEF(HRN_SERVER_CA), NULL, NULL, NULL)),
+                            STRDEF("host.test2.pgbackrest.org"), 0, 0, true, .caFile = STRDEF(HRN_SERVER_CA))),
                     "open connection");
 
                 // -----------------------------------------------------------------------------------------------------------------
@@ -543,9 +579,9 @@ testRun(void)
 
                 TEST_ERROR(
                     ioClientOpen(
-                        tlsClientNew(
+                        tlsClientNewP(
                             sckClientNew(STRDEF("test3.pgbackrest.org"), hrnServerPort(0), 5000, 5000),
-                            STRDEF("test3.pgbackrest.org"), 0, 0, true, STRDEF(HRN_SERVER_CA), NULL, NULL, NULL)),
+                            STRDEF("test3.pgbackrest.org"), 0, 0, true, .caFile = STRDEF(HRN_SERVER_CA))),
                     CryptoError,
                     "unable to find hostname 'test3.pgbackrest.org' in certificate common name or subject alternative names");
 
@@ -557,9 +593,9 @@ testRun(void)
 
                 TEST_ERROR_FMT(
                     ioClientOpen(
-                        tlsClientNew(
+                        tlsClientNewP(
                             sckClientNew(STRDEF("localhost"), hrnServerPort(0), 5000, 5000), STRDEF("X"), 0, 0, true,
-                            STRDEF(HRN_SERVER_CERT), NULL, NULL, NULL)),
+                            .caFile = STRDEF(HRN_SERVER_CERT))),
                     CryptoError,
                     "unable to verify certificate presented by 'localhost:%u': [20] unable to get local issuer certificate",
                     hrnServerPort(0));
@@ -572,10 +608,8 @@ testRun(void)
 
                 TEST_RESULT_VOID(
                     ioClientOpen(
-                        tlsClientNew(
-                            sckClientNew(STRDEF("localhost"), hrnServerPort(0), 5000, 5000), STRDEF("X"), 0, 0, false, NULL, NULL,
-                            NULL, NULL)),
-                        "open connection");
+                        tlsClientNewP(sckClientNew(STRDEF("localhost"), hrnServerPort(0), 5000, 5000), STRDEF("X"), 0, 0, false)),
+                    "open connection");
 
                 // -----------------------------------------------------------------------------------------------------------------
                 hrnServerScriptEnd(tls);
@@ -662,13 +696,14 @@ testRun(void)
                     TEST_ASSIGN(
                         clientSession,
                         ioClientOpen(
-                            tlsClientNew(
+                            tlsClientNewP(
                                 sckClientNew(STRDEF("127.0.0.1"), hrnServerPort(0), 5000, 5000), STRDEF("127.0.0.1"), 5000, 5000,
-                                true, NULL, NULL, STRDEF(TEST_PATH "/client-bad-ca.crt"), STRDEF(HRN_SERVER_CLIENT_KEY))),
+                                true, .certFile = STRDEF(TEST_PATH "/client-bad-ca.crt"),
+                                .keyFile = STRDEF(HRN_SERVER_CLIENT_KEY))),
                         "client open");
 
                     TEST_ERROR(
-                        ioRead(ioSessionIoRead(clientSession), bufNew(1)), ServiceError,
+                        ioRead(ioSessionIoReadP(clientSession), bufNew(1)), ServiceError,
                         "TLS error [1:336151576] tlsv1 alert unknown ca");
 
                     TEST_RESULT_VOID(ioSessionFree(clientSession), "free client session");
@@ -680,13 +715,13 @@ testRun(void)
                 TEST_ASSIGN(
                     clientSession,
                     ioClientOpen(
-                        tlsClientNew(
+                        tlsClientNewP(
                             sckClientNew(STRDEF("127.0.0.1"), hrnServerPort(0), 5000, 5000), STRDEF("127.0.0.1"), 5000, 5000, true,
-                            NULL, NULL, STRDEF(HRN_SERVER_CLIENT_CERT), STRDEF(HRN_SERVER_CLIENT_KEY))),
+                            .certFile = STRDEF(HRN_SERVER_CLIENT_CERT), .keyFile = STRDEF(HRN_SERVER_CLIENT_KEY))),
                     "client open");
 
                 Buffer *buffer = bufNew(7);
-                TEST_RESULT_VOID(ioRead(ioSessionIoRead(clientSession), buffer), "client read");
+                TEST_RESULT_VOID(ioRead(ioSessionIoReadP(clientSession), buffer), "client read");
                 TEST_RESULT_STR_Z(strNewBuf(buffer), "message", "check read");
 
                 TEST_RESULT_VOID(ioSessionFree(clientSession), "free client session");
@@ -697,13 +732,13 @@ testRun(void)
                 TEST_ASSIGN(
                     clientSession,
                     ioClientOpen(
-                        tlsClientNew(
-                            sckClientNew(STRDEF("127.0.0.1"), hrnServerPort(0), 5000, 5000), STRDEF("127.0.0.1"), 5000, 5000, true,
-                            NULL, NULL, NULL, NULL)),
+                        tlsClientNewP(
+                            sckClientNew(STRDEF("127.0.0.1"), hrnServerPort(0), 5000, 5000), STRDEF("127.0.0.1"), 5000, 5000,
+                            true)),
                     "client open");
 
                 buffer = bufNew(8);
-                TEST_RESULT_VOID(ioRead(ioSessionIoRead(clientSession), buffer), "client read");
+                TEST_RESULT_VOID(ioRead(ioSessionIoReadP(clientSession), buffer), "client read");
                 TEST_RESULT_STR_Z(strNewBuf(buffer), "message2", "check read");
 
                 TEST_RESULT_VOID(ioSessionFree(clientSession), "free client session");
@@ -738,9 +773,8 @@ testRun(void)
 
                 TEST_ASSIGN(
                     client,
-                    tlsClientNew(
-                        sckClientNew(hrnServerHost(), hrnServerPort(0), 5000, 5000), hrnServerHost(), 0, 0, TEST_IN_CONTAINER, NULL,
-                        NULL, NULL, NULL),
+                    tlsClientNewP(
+                        sckClientNew(hrnServerHost(), hrnServerPort(0), 5000, 5000), hrnServerHost(), 0, 0, TEST_IN_CONTAINER),
                     "new client");
 
                 hrnServerScriptAccept(tls);
@@ -773,8 +807,8 @@ testRun(void)
                 TEST_RESULT_VOID(ioWrite(ioSessionIoWrite(session), input), "write input");
                 ioWriteFlush(ioSessionIoWrite(session));
 
-                TEST_RESULT_STR_Z(ioReadLine(ioSessionIoRead(session)), "something:0", "read line");
-                TEST_RESULT_BOOL(ioReadEof(ioSessionIoRead(session)), false, "check eof = false");
+                TEST_RESULT_STR_Z(ioReadLine(ioSessionIoReadP(session)), "something:0", "read line");
+                TEST_RESULT_BOOL(ioReadEof(ioSessionIoReadP(session)), false, "check eof = false");
 
                 hrnServerScriptSleep(tls, 100);
                 hrnServerScriptReplyZ(tls, "some ");
@@ -783,14 +817,14 @@ testRun(void)
                 hrnServerScriptReplyZ(tls, "contentAND MORE");
 
                 Buffer *output = bufNew(12);
-                TEST_RESULT_UINT(ioRead(ioSessionIoRead(session), output), 12, "read output");
+                TEST_RESULT_UINT(ioRead(ioSessionIoReadP(session), output), 12, "read output");
                 TEST_RESULT_STR_Z(strNewBuf(output), "some content", "check output");
-                TEST_RESULT_BOOL(ioReadEof(ioSessionIoRead(session)), false, "check eof = false");
+                TEST_RESULT_BOOL(ioReadEof(ioSessionIoReadP(session)), false, "check eof = false");
 
                 output = bufNew(8);
-                TEST_RESULT_UINT(ioRead(ioSessionIoRead(session), output), 8, "read output");
+                TEST_RESULT_UINT(ioRead(ioSessionIoReadP(session), output), 8, "read output");
                 TEST_RESULT_STR_Z(strNewBuf(output), "AND MORE", "check output");
-                TEST_RESULT_BOOL(ioReadEof(ioSessionIoRead(session)), false, "check eof = false");
+                TEST_RESULT_BOOL(ioReadEof(ioSessionIoReadP(session)), false, "check eof = false");
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("read eof");
@@ -800,7 +834,7 @@ testRun(void)
                 output = bufNew(12);
                 ((IoFdRead *)((SocketSession *)tlsSession->ioSession->pub.driver)->read->pub.driver)->timeout = 100;
                 TEST_ERROR_FMT(
-                    ioRead(ioSessionIoRead(session), output), FileReadError,
+                    ioRead(ioSessionIoReadP(session), output), FileReadError,
                     "timeout after 100ms waiting for read from '%s:%u'", strZ(hrnServerHost()), hrnServerPort(0));
                 ((IoFdRead *)((SocketSession *)tlsSession->ioSession->pub.driver)->read->pub.driver)->timeout = 5000;
 
@@ -817,13 +851,13 @@ testRun(void)
                 ioWriteFlush(ioSessionIoWrite(session));
 
                 output = bufNew(12);
-                TEST_RESULT_UINT(ioRead(ioSessionIoRead(session), output), 12, "read output");
+                TEST_RESULT_UINT(ioRead(ioSessionIoReadP(session), output), 12, "read output");
                 TEST_RESULT_STR_Z(strNewBuf(output), "0123456789AB", "check output");
-                TEST_RESULT_BOOL(ioReadEof(ioSessionIoRead(session)), false, "check eof = false");
+                TEST_RESULT_BOOL(ioReadEof(ioSessionIoReadP(session)), false, "check eof = false");
 
                 output = bufNew(12);
-                TEST_RESULT_UINT(ioRead(ioSessionIoRead(session), output), 0, "read no output after eof");
-                TEST_RESULT_BOOL(ioReadEof(ioSessionIoRead(session)), true, "check eof = true");
+                TEST_RESULT_UINT(ioRead(ioSessionIoReadP(session), output), 0, "read no output after eof");
+                TEST_RESULT_BOOL(ioReadEof(ioSessionIoReadP(session)), true, "check eof = true");
 
                 TEST_RESULT_VOID(ioSessionClose(session), "close again");
 
@@ -839,7 +873,20 @@ testRun(void)
                 socketLocal.block = false;
 
                 output = bufNew(13);
-                TEST_ERROR(ioRead(ioSessionIoRead(session), output), KernelError, "TLS syscall error");
+                TEST_ERROR(ioRead(ioSessionIoReadP(session), output), KernelError, "TLS syscall error");
+
+                // -----------------------------------------------------------------------------------------------------------------
+                TEST_TITLE("aborted connection ignored and read complete (non-blocking socket)");
+
+                hrnServerScriptAccept(tls);
+                hrnServerScriptReplyZ(tls, "0123456789AC");
+                hrnServerScriptAbort(tls);
+
+                TEST_ASSIGN(session, ioClientOpen(client), "open client again (was closed by server)");
+
+                output = bufNew(13);
+                TEST_RESULT_VOID(ioRead(ioSessionIoReadP(session, .ignoreUnexpectedEof = true), output), "ignore syscall error");
+                TEST_RESULT_STR_Z(strNewBuf(output), "0123456789AC", "all bytes read");
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("close connection");
