@@ -4,10 +4,12 @@ Test Database
 #include "common/io/fdRead.h"
 #include "common/io/fdWrite.h"
 #include "common/type/json.h"
+#include "storage/remote/protocol.h"
 
 #include "common/harnessConfig.h"
 #include "common/harnessFork.h"
 #include "common/harnessLog.h"
+#include "common/harnessPostgres.h"
 #include "common/harnessPq.h"
 
 /***********************************************************************************************************************************
@@ -67,9 +69,10 @@ testRun(void)
                 StringList *argList = strLstNew();
                 hrnCfgArgRawZ(argList, cfgOptStanza, "test1");
                 hrnCfgArgKeyRawZ(argList, cfgOptPgPath, 1, TEST_PATH "/pg");
-                hrnCfgArgKeyRawZ(argList, cfgOptPgDatabase, 1,  "testdb");
+                hrnCfgArgKeyRawZ(argList, cfgOptPgDatabase, 1, "testdb");
                 hrnCfgArgRawStrId(argList, cfgOptRemoteType, protocolStorageTypePg);
                 hrnCfgArgRawZ(argList, cfgOptProcess, "0");
+                hrnCfgArgRawZ(argList, cfgOptDbTimeout, "777");
                 HRN_CFG_LOAD(cfgCmdBackup, argList, .role = cfgCmdRoleRemote);
 
                 // Set script
@@ -78,13 +81,15 @@ testRun(void)
                     HRNPQ_MACRO_OPEN(1, "dbname='testdb' port=5432"),
                     HRNPQ_MACRO_SET_SEARCH_PATH(1),
                     HRNPQ_MACRO_SET_CLIENT_ENCODING(1),
-                    HRNPQ_MACRO_VALIDATE_QUERY(1, PG_VERSION_84, TEST_PATH "/pg", NULL, NULL),
+                    HRNPQ_MACRO_VALIDATE_QUERY(1, PG_VERSION_90, TEST_PATH "/pg", NULL, NULL),
+                    HRNPQ_MACRO_SET_APPLICATION_NAME(1),
                     HRNPQ_MACRO_CLOSE(1),
 
                     HRNPQ_MACRO_OPEN(1, "dbname='testdb' port=5432"),
                     HRNPQ_MACRO_SET_SEARCH_PATH(1),
                     HRNPQ_MACRO_SET_CLIENT_ENCODING(1),
-                    HRNPQ_MACRO_VALIDATE_QUERY(1, PG_VERSION_84, TEST_PATH "/pg", NULL, NULL),
+                    HRNPQ_MACRO_VALIDATE_QUERY(1, PG_VERSION_90, TEST_PATH "/pg", NULL, NULL),
+                    HRNPQ_MACRO_SET_APPLICATION_NAME(1),
                     HRNPQ_MACRO_WAL_SWITCH(1, "xlog", "000000030000000200000003"),
                     HRNPQ_MACRO_CLOSE(1),
 
@@ -99,7 +104,12 @@ testRun(void)
                     protocolServerNew(STRDEF("db test server"), STRDEF("test"), HRN_FORK_CHILD_READ(), HRN_FORK_CHILD_WRITE()),
                     "create server");
 
-                static const ProtocolServerHandler commandHandler[] = {PROTOCOL_SERVER_HANDLER_DB_LIST};
+                static const ProtocolServerHandler commandHandler[] =
+                {
+                    PROTOCOL_SERVER_HANDLER_DB_LIST
+                    PROTOCOL_SERVER_HANDLER_OPTION_LIST
+                    PROTOCOL_SERVER_HANDLER_STORAGE_REMOTE_LIST
+                };
 
                 TEST_RESULT_VOID(
                     protocolServerProcess(server, NULL, commandHandler, PROTOCOL_SERVER_HANDLER_LIST_SIZE(commandHandler)),
@@ -110,6 +120,17 @@ testRun(void)
 
             HRN_FORK_PARENT_BEGIN()
             {
+                // Set options
+                StringList *argList = strLstNew();
+                hrnCfgArgRawZ(argList, cfgOptStanza, "test1");
+                hrnCfgArgKeyRawZ(argList, cfgOptPgPath, 1, TEST_PATH "/pg");
+                hrnCfgArgKeyRawZ(argList, cfgOptPgDatabase, 1, "testdb");
+                hrnCfgArgKeyRawZ(argList, cfgOptRepoRetentionFull, 1, "1");
+                HRN_CFG_LOAD(cfgCmdBackup, argList);
+
+                // Create control file
+                HRN_PG_CONTROL_PUT(storagePgIdxWrite(0), PG_VERSION_93);
+
                 // Create client
                 ProtocolClient *client = NULL;
                 Db *db = NULL;
@@ -124,7 +145,7 @@ testRun(void)
                     // -------------------------------------------------------------------------------------------------------------
                     TEST_TITLE("open and free database");
 
-                    TEST_ASSIGN(db, dbNew(NULL, client, STRDEF("test")), "create db");
+                    TEST_ASSIGN(db, dbNew(NULL, client, storagePgIdx(0), STRDEF(PROJECT_NAME " [" CFGCMD_BACKUP "]")), "create db");
 
                     TRY_BEGIN()
                     {
@@ -143,13 +164,14 @@ testRun(void)
                     // -------------------------------------------------------------------------------------------------------------
                     TEST_TITLE("remote commands");
 
-                    TEST_ASSIGN(db, dbNew(NULL, client, STRDEF("test")), "create db");
+                    TEST_ASSIGN(db, dbNew(NULL, client, storagePgIdx(0), STRDEF(PROJECT_NAME " [" CFGCMD_BACKUP "]")), "create db");
 
                     TRY_BEGIN()
                     {
                         TEST_RESULT_VOID(dbOpen(db), "open db");
                         TEST_RESULT_UINT(db->remoteIdx, 1, "check idx");
                         TEST_RESULT_STR_Z(dbWalSwitch(db), "000000030000000200000003", "wal switch");
+                        TEST_RESULT_UINT(dbDbTimeout(db), 777000, "check timeout");
                         TEST_RESULT_VOID(memContextCallbackClear(db->pub.memContext), "clear context so close is not called");
                     }
                     FINALLY()
@@ -178,9 +200,13 @@ testRun(void)
         hrnCfgArgRawZ(argList, cfgOptStanza, "test1");
         hrnCfgArgKeyRawZ(argList, cfgOptRepoRetentionFull, 1, "1");
         hrnCfgArgKeyRawZ(argList, cfgOptPgPath, 1, TEST_PATH "/pg1");
-        hrnCfgArgKeyRawZ(argList, cfgOptPgDatabase, 1,  "backupdb");
+        hrnCfgArgKeyRawZ(argList, cfgOptPgDatabase, 1, "backupdb");
+        hrnCfgArgRawZ(argList, cfgOptDbTimeout, "888");
         HRN_CFG_LOAD(cfgCmdBackup, argList);
 
+        // Create control file
+        HRN_PG_CONTROL_PUT(storagePgIdxWrite(0), PG_VERSION_93, .checkpoint = pgLsnFromStr(STRDEF("1/1")));
+
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("error when unable to select any pg_settings");
 
@@ -196,23 +222,26 @@ testRun(void)
                 "[\"select (select setting from pg_catalog.pg_settings where name = 'server_version_num')::int4,"
                     " (select setting from pg_catalog.pg_settings where name = 'data_directory')::text,"
                     " (select setting from pg_catalog.pg_settings where name = 'archive_mode')::text,"
-                    " (select setting from pg_catalog.pg_settings where name = 'archive_command')::text\"]",
+                    " (select setting from pg_catalog.pg_settings where name = 'archive_command')::text,"
+                    " (select setting from pg_catalog.pg_settings where name = 'checkpoint_timeout')::int4\"]",
                 .resultInt = 1},
             {.session = 1, .function = HRNPQ_CONSUMEINPUT},
             {.session = 1, .function = HRNPQ_ISBUSY},
             {.session = 1, .function = HRNPQ_GETRESULT},
             {.session = 1, .function = HRNPQ_RESULTSTATUS, .resultInt = PGRES_TUPLES_OK},
             {.session = 1, .function = HRNPQ_NTUPLES, .resultInt = 1},
-            {.session = 1, .function = HRNPQ_NFIELDS, .resultInt = 4},
+            {.session = 1, .function = HRNPQ_NFIELDS, .resultInt = 5},
             {.session = 1, .function = HRNPQ_FTYPE, .param = "[0]", .resultInt = HRNPQ_TYPE_INT},
             {.session = 1, .function = HRNPQ_FTYPE, .param = "[1]", .resultInt = HRNPQ_TYPE_TEXT},
             {.session = 1, .function = HRNPQ_FTYPE, .param = "[2]", .resultInt = HRNPQ_TYPE_TEXT},
             {.session = 1, .function = HRNPQ_FTYPE, .param = "[3]", .resultInt = HRNPQ_TYPE_TEXT},
+            {.session = 1, .function = HRNPQ_FTYPE, .param = "[4]", .resultInt = HRNPQ_TYPE_INT},
             {.session = 1, .function = HRNPQ_GETVALUE, .param = "[0,0]", .resultZ = "0"},
             {.session = 1, .function = HRNPQ_GETVALUE, .param = "[0,1]", .resultZ = "value"},
             {.session = 1, .function = HRNPQ_GETVALUE, .param = "[0,2]", .resultZ = "value"},
             {.session = 1, .function = HRNPQ_GETVALUE, .param = "[0,3]", .resultZ = ""},
             {.session = 1, .function = HRNPQ_GETISNULL, .param = "[0,3]", .resultInt = 1},
+            {.session = 1, .function = HRNPQ_GETVALUE, .param = "[0,4]", .resultZ = "300"},
             {.session = 1, .function = HRNPQ_CLEAR},
             {.session = 1, .function = HRNPQ_GETRESULT, .resultNull = true},
 
@@ -225,23 +254,24 @@ testRun(void)
         TEST_ERROR(dbGet(true, true, false), DbConnectError, "unable to find primary cluster - cannot proceed");
 
         TEST_RESULT_LOG(
-            "P00   WARN: unable to check pg-1: [DbQueryError] unable to select some rows from pg_settings\n"
+            "P00   WARN: unable to check pg1: [DbQueryError] unable to select some rows from pg_settings\n"
             "            HINT: is the backup running as the postgres user?\n"
             "            HINT: is the pg_read_all_settings role assigned for PostgreSQL >= 10?");
 
         // -------------------------------------------------------------------------------------------------------------------------
-        TEST_TITLE("PostgreSQL 8.3 start backup with no start fast");
+        TEST_TITLE("PostgreSQL 9.0 start backup with no WAL switch");
 
         harnessPqScriptSet((HarnessPq [])
         {
             // Connect to primary
-            HRNPQ_MACRO_OPEN_LE_91(1, "dbname='backupdb' port=5432", PG_VERSION_83, TEST_PATH "/pg1", NULL, NULL),
+            HRNPQ_MACRO_OPEN_LE_91(1, "dbname='backupdb' port=5432", PG_VERSION_90, TEST_PATH "/pg1", NULL, NULL),
 
             // Get advisory lock
             HRNPQ_MACRO_ADVISORY_LOCK(1, true),
 
-            // Start backup with no start fast
-            HRNPQ_MACRO_START_BACKUP_83(1, "1/1", "000000010000000100000001"),
+            // Start backup with no wal switch
+            HRNPQ_MACRO_CURRENT_WAL_LE_96(1, "000000010000000100000001"),
+            HRNPQ_MACRO_START_BACKUP_LE_95(1, false, "1/1", "000000010000000100000001"),
 
             // Close primary
             HRNPQ_MACRO_CLOSE(1),
@@ -252,13 +282,23 @@ testRun(void)
         DbGetResult db = {0};
         TEST_ASSIGN(db, dbGet(true, true, false), "get primary");
 
-        TEST_RESULT_STR_Z(dbBackupStart(db.primary, false, false).lsn, "1/1", "start backup");
+        TEST_RESULT_UINT(dbDbTimeout(db.primary), 888000, "check timeout");
+        TEST_RESULT_UINT(dbPgControl(db.primary).timeline, 1, "check timeline");
+
+        DbBackupStartResult backupStartResult = {0};
+        TEST_ASSIGN(backupStartResult, dbBackupStart(db.primary, false, false, true), "start backup");
+        TEST_RESULT_STR_Z(backupStartResult.lsn, "1/1", "start backup");
+        TEST_RESULT_PTR(backupStartResult.walSegmentCheck, NULL, "WAL segment check");
+
+        TEST_RESULT_VOID(dbPing(db.primary, false), "ping cluster");
 
         TEST_RESULT_VOID(dbFree(db.primary), "free primary");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("PostgreSQL 9.5 start/stop backup");
 
+        HRN_PG_CONTROL_PUT(storagePgIdxWrite(0), PG_VERSION_93, .checkpoint = pgLsnFromStr(STRDEF("2/3")));
+
         harnessPqScriptSet((HarnessPq [])
         {
             // Connect to primary
@@ -273,7 +313,7 @@ testRun(void)
             // Start backup
             HRNPQ_MACRO_ADVISORY_LOCK(1, true),
             HRNPQ_MACRO_IS_IN_BACKUP(1, false),
-            HRNPQ_MACRO_START_BACKUP_84_95(1, false, "2/3", "000000010000000200000003"),
+            HRNPQ_MACRO_START_BACKUP_LE_95(1, false, "2/3", "000000010000000200000003"),
             HRNPQ_MACRO_DATABASE_LIST_1(1, "test1"),
             HRNPQ_MACRO_TABLESPACE_LIST_0(1),
 
@@ -291,12 +331,11 @@ testRun(void)
         TEST_RESULT_UINT(dbTimeMSec(db.primary), 1000, "check time");
 
         TEST_ERROR(
-            dbBackupStart(db.primary, false, false), LockAcquireError,
+            dbBackupStart(db.primary, false, false, false), LockAcquireError,
             "unable to acquire pgBackRest advisory lock\n"
             "HINT: is another pgBackRest backup already running on this cluster?");
 
-        DbBackupStartResult backupStartResult = {.lsn = NULL};
-        TEST_ASSIGN(backupStartResult, dbBackupStart(db.primary, false, true), "start backup");
+        TEST_ASSIGN(backupStartResult, dbBackupStart(db.primary, false, true, false), "start backup");
         TEST_RESULT_STR_Z(backupStartResult.lsn, "2/3", "check lsn");
         TEST_RESULT_STR_Z(backupStartResult.walSegmentName, "000000010000000200000003", "check wal segment name");
 
@@ -315,6 +354,8 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("PostgreSQL 9.5 start/stop backup where backup is in progress");
 
+        HRN_PG_CONTROL_PUT(storagePgIdxWrite(0), PG_VERSION_93, .checkpoint = pgLsnFromStr(STRDEF("2/5")));
+
         harnessPqScriptSet((HarnessPq [])
         {
             // Connect to primary
@@ -328,7 +369,7 @@ testRun(void)
             HRNPQ_MACRO_STOP_BACKUP_LE_95(1, "1/1", "000000010000000100000001"),
 
             // Start backup
-            HRNPQ_MACRO_START_BACKUP_84_95(1, true, "2/5", "000000010000000200000005"),
+            HRNPQ_MACRO_START_BACKUP_LE_95(1, true, "2/5", "000000010000000200000005"),
 
             // Stop backup
             HRNPQ_MACRO_STOP_BACKUP_LE_95(1, "2/6", "000000010000000200000006"),
@@ -341,7 +382,7 @@ testRun(void)
 
         TEST_ASSIGN(db, dbGet(true, true, false), "get primary");
 
-        TEST_RESULT_STR_Z(dbBackupStart(db.primary, true, true).lsn, "2/5", "start backup");
+        TEST_RESULT_STR_Z(dbBackupStart(db.primary, true, true, false).lsn, "2/5", "start backup");
 
         TEST_RESULT_LOG(
             "P00   WARN: the cluster is already in backup mode but no pgBackRest backup process is running."
@@ -354,13 +395,26 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("PostgreSQL 9.6 start/stop backup");
 
+        HRN_PG_CONTROL_PUT(storagePgIdxWrite(0), PG_VERSION_93, .checkpoint = pgLsnFromStr(STRDEF("3/3")));
+
         harnessPqScriptSet((HarnessPq [])
         {
             // Connect to primary
             HRNPQ_MACRO_OPEN_GE_96(1, "dbname='backupdb' port=5432", PG_VERSION_96, TEST_PATH "/pg1", false, NULL, NULL),
 
+            // Start backup with timeline error
+            HRNPQ_MACRO_ADVISORY_LOCK(1, true),
+            HRNPQ_MACRO_CURRENT_WAL_LE_96(1, "000000020000000300000002"),
+            HRNPQ_MACRO_START_BACKUP_96(1, false, "3/3", "000000020000000300000003"),
+
+            // Start backup with checkpoint error
+            HRNPQ_MACRO_ADVISORY_LOCK(1, true),
+            HRNPQ_MACRO_CURRENT_WAL_LE_96(1, "000000010000000400000003"),
+            HRNPQ_MACRO_START_BACKUP_96(1, false, "4/4", "000000010000000400000004"),
+
             // Start backup
             HRNPQ_MACRO_ADVISORY_LOCK(1, true),
+            HRNPQ_MACRO_CURRENT_WAL_LE_96(1, "000000010000000300000002"),
             HRNPQ_MACRO_START_BACKUP_96(1, false, "3/3", "000000010000000300000003"),
 
             // Stop backup
@@ -374,9 +428,16 @@ testRun(void)
 
         TEST_ASSIGN(db, dbGet(true, true, false), "get primary");
 
-        TEST_ASSIGN(backupStartResult, dbBackupStart(db.primary, false, true), "start backup");
+        TEST_ERROR(
+            dbBackupStart(db.primary, false, true, true), DbMismatchError, "WAL timeline 2 does not match pg_control timeline 1");
+        TEST_ERROR(
+            dbBackupStart(db.primary, false, true, true), DbMismatchError,
+            "current checkpoint '3/3' is less than backup start '4/4'");
+
+        TEST_ASSIGN(backupStartResult, dbBackupStart(db.primary, false, true, true), "start backup");
         TEST_RESULT_STR_Z(backupStartResult.lsn, "3/3", "check lsn");
         TEST_RESULT_STR_Z(backupStartResult.walSegmentName, "000000010000000300000003", "check wal segment name");
+        TEST_RESULT_STR_Z(backupStartResult.walSegmentCheck, "000000010000000300000002", "check wal segment check");
 
         TEST_ASSIGN(backupStopResult, dbBackupStop(db.primary), "stop backup");
         TEST_RESULT_STR_Z(backupStopResult.lsn, "3/4", "check lsn");
@@ -397,6 +458,10 @@ testRun(void)
         hrnCfgArgKeyRawZ(argList, cfgOptPgPort, 2, "5433");
         HRN_CFG_LOAD(cfgCmdBackup, argList);
 
+        // Create control file
+        HRN_PG_CONTROL_PUT(storagePgIdxWrite(0), PG_VERSION_93, .timeline = 5, .checkpoint = pgLsnFromStr(STRDEF("5/4")));
+        HRN_PG_CONTROL_PUT(storagePgIdxWrite(1), PG_VERSION_93, .timeline = 5, .checkpoint = pgLsnFromStr(STRDEF("5/4")));
+
         harnessPqScriptSet((HarnessPq [])
         {
             // Connect to primary
@@ -407,11 +472,21 @@ testRun(void)
 
             // Start backup
             HRNPQ_MACRO_ADVISORY_LOCK(1, true),
-            HRNPQ_MACRO_START_BACKUP_84_95(1, false, "5/4", "000000050000000500000004"),
+            HRNPQ_MACRO_START_BACKUP_LE_95(1, false, "5/4", "000000050000000500000004"),
 
             // Wait for standby to sync
             HRNPQ_MACRO_REPLAY_WAIT_LE_95(2, "5/4"),
 
+            // Ping
+            HRNPQ_MACRO_IS_STANDBY_QUERY(1, true),
+            HRNPQ_MACRO_IS_STANDBY_QUERY(1, false),
+            HRNPQ_MACRO_IS_STANDBY_QUERY(1, false),
+
+            HRNPQ_MACRO_IS_STANDBY_QUERY(2, false),
+            HRNPQ_MACRO_IS_STANDBY_QUERY(2, true),
+            HRNPQ_MACRO_IS_STANDBY_QUERY(2, true),
+            HRNPQ_MACRO_IS_STANDBY_QUERY(2, true),
+
             // Close standby
             HRNPQ_MACRO_CLOSE(2),
 
@@ -423,8 +498,24 @@ testRun(void)
 
         TEST_ASSIGN(db, dbGet(false, true, true), "get primary and standby");
 
-        TEST_RESULT_STR_Z(dbBackupStart(db.primary, false, false).lsn, "5/4", "start backup");
-        TEST_RESULT_VOID(dbReplayWait(db.standby, STRDEF("5/4"), 1000), "sync standby");
+        TEST_RESULT_STR_Z(dbBackupStart(db.primary, false, false, false).lsn, "5/4", "start backup");
+        TEST_RESULT_VOID(dbReplayWait(db.standby, STRDEF("5/4"), dbPgControl(db.primary).timeline, 1000), "sync standby");
+
+        TEST_ERROR(dbPing(db.primary, false), AssertError, "primary has switched to recovery");
+        TEST_RESULT_VOID(dbPing(db.primary, false), "ping primary cluster");
+        TEST_RESULT_VOID(dbPing(db.primary, false), "ping primary cluster (noop)");
+        TEST_RESULT_VOID(dbPing(db.primary, true), "ping primary cluster (force)");
+
+        TEST_ERROR(
+            dbPing(db.standby, false), DbMismatchError,
+            "standby is no longer in recovery\n"
+            "HINT: was the standby promoted during the backup?");
+        TEST_RESULT_VOID(dbPing(db.standby, false), "ping standby cluster");
+        TEST_RESULT_VOID(dbPing(db.standby, false), "ping standby cluster (noop)");
+        TEST_RESULT_VOID(dbPing(db.standby, true), "ping standby cluster (force)");
+
+        db.standby->pingTimeLast -= DB_PING_SEC * 2;
+        TEST_RESULT_VOID(dbPing(db.standby, false), "ping standby cluster");
 
         TEST_RESULT_VOID(dbFree(db.standby), "free standby");
         TEST_RESULT_VOID(dbFree(db.primary), "free primary");
@@ -432,6 +523,10 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("PostgreSQL 10 start/stop backup from standby");
 
+        // Update control file
+        HRN_PG_CONTROL_PUT(storagePgIdxWrite(0), PG_VERSION_93, .timeline = 5, .checkpoint = pgLsnFromStr(STRDEF("5/5")));
+        HRN_PG_CONTROL_PUT(storagePgIdxWrite(1), PG_VERSION_93, .timeline = 5, .checkpoint = pgLsnFromStr(STRDEF("5/5")));
+
         harnessPqScriptSet((HarnessPq [])
         {
             // Connect to primary
@@ -442,8 +537,13 @@ testRun(void)
 
             // Start backup
             HRNPQ_MACRO_ADVISORY_LOCK(1, true),
+            HRNPQ_MACRO_CURRENT_WAL_GE_10(1, "000000050000000500000005"),
             HRNPQ_MACRO_START_BACKUP_GE_10(1, false, "5/5", "000000050000000500000005"),
 
+            // Switch WAL segment so it can be checked
+            HRNPQ_MACRO_CREATE_RESTORE_POINT(1, "5/5"),
+            HRNPQ_MACRO_WAL_SWITCH(1, "wal", "000000050000000500000005"),
+
             // Standby returns NULL lsn
             {.session = 2,
                 .function = HRNPQ_SENDQUERY,
@@ -499,30 +599,78 @@ testRun(void)
 
         TEST_ASSIGN(db, dbGet(false, true, true), "get primary and standby");
 
-        TEST_RESULT_STR_Z(dbBackupStart(db.primary, false, false).lsn, "5/5", "start backup");
+        TEST_RESULT_UINT(dbPgControl(db.primary).timeline, 5, "check primary timeline");
+        TEST_RESULT_UINT(dbPgControl(db.standby).timeline, 5, "check standby timeline");
+
+        TEST_ASSIGN(backupStartResult, dbBackupStart(db.primary, false, false, true), "start backup");
+        TEST_RESULT_STR_Z(backupStartResult.lsn, "5/5", "check lsn");
+        TEST_RESULT_STR_Z(backupStartResult.walSegmentName, "000000050000000500000005", "check wal segment name");
+        TEST_RESULT_STR_Z(backupStartResult.walSegmentCheck, "000000050000000500000005", "check wal segment check");
 
         TEST_ERROR(
-            dbReplayWait(db.standby, STRDEF("5/5"), 1000), ArchiveTimeoutError,
+            dbReplayWait(db.standby, STRDEF("5/5"), 77, 1000), DbMismatchError, "standby is on timeline 5 but expected 77");
+        TEST_ERROR(
+            dbReplayWait(db.standby, STRDEF("4/4"), 5, 1000), DbMismatchError, "standby checkpoint '5/5' is ahead of target '4/4'");
+
+        TEST_ERROR(
+            dbReplayWait(db.standby, STRDEF("5/5"), dbPgControl(db.primary).timeline, 1000), ArchiveTimeoutError,
             "unable to query replay lsn on the standby using 'pg_catalog.pg_last_wal_replay_lsn()'\n"
             "HINT: Is this a standby?");
 
         TEST_ERROR(
-            dbReplayWait(db.standby, STRDEF("5/5"), 200), ArchiveTimeoutError,
+            dbReplayWait(db.standby, STRDEF("5/5"), dbPgControl(db.primary).timeline, 200), ArchiveTimeoutError,
             "timeout before standby replayed to 5/5 - only reached 5/3\n"
             "HINT: is replication running and current on the standby?\n"
             "HINT: disable the 'backup-standby' option to backup directly from the primary.");
 
         TEST_ERROR(
-            dbReplayWait(db.standby, STRDEF("5/5"), 200), ArchiveTimeoutError,
+            dbReplayWait(db.standby, STRDEF("5/5"), dbPgControl(db.primary).timeline, 200), ArchiveTimeoutError,
             "timeout before standby checkpoint lsn reached 5/5 - only reached 5/4");
 
-        TEST_RESULT_VOID(dbReplayWait(db.standby, STRDEF("5/5"), 1000), "sync standby");
+        TEST_RESULT_VOID(dbReplayWait(db.standby, STRDEF("5/5"), dbPgControl(db.primary).timeline, 1000), "sync standby");
 
         TEST_RESULT_VOID(dbFree(db.standby), "free standby");
 
         TEST_RESULT_STR_Z(dbBackupStop(db.primary).tablespaceMap, "TABLESPACE_MAP_DATA", "stop backup");
 
         TEST_RESULT_VOID(dbFree(db.primary), "free primary");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("PostgreSQL 14 - checkpoint timeout warning");
+
+        argList = strLstNew();
+        hrnCfgArgRawZ(argList, cfgOptStanza, "test1");
+        hrnCfgArgKeyRawZ(argList, cfgOptRepoRetentionFull, 1, "1");
+        hrnCfgArgKeyRawZ(argList, cfgOptPgPath, 1, TEST_PATH "/pg1");
+        // With start-fast being disabled, set db-timeout smaller than checkpoint_timeout to raise a warning
+        hrnCfgArgRawZ(argList, cfgOptDbTimeout, "299");
+        HRN_CFG_LOAD(cfgCmdBackup, argList);
+
+        harnessPqScriptSet((HarnessPq [])
+        {
+            // Connect to primary
+            HRNPQ_MACRO_OPEN_GE_96(1, "dbname='postgres' port=5432", PG_VERSION_14, TEST_PATH "/pg1", false, NULL, NULL),
+
+            // Start backup
+            HRNPQ_MACRO_ADVISORY_LOCK(1, true),
+            HRNPQ_MACRO_CURRENT_WAL_GE_10(1, "000000050000000500000004"),
+            HRNPQ_MACRO_START_BACKUP_GE_10(1, false, "5/5", "000000050000000500000005"),
+
+            // Close primary
+            HRNPQ_MACRO_CLOSE(1),
+
+            HRNPQ_MACRO_DONE()
+        });
+
+        TEST_ASSIGN(db, dbGet(true, true, false), "get primary");
+        TEST_ASSIGN(backupStartResult, dbBackupStart(db.primary, false, false, true), "start backup");
+
+        TEST_RESULT_LOG(
+            "P00   WARN: start-fast is disabled and db-timeout (299s) is smaller than the PostgreSQL checkpoint_timeout (300s) -"
+                " timeout may occur before the backup starts");
+
+        TEST_RESULT_VOID(dbFree(db.primary), "free primary");
+
     }
 
     // *****************************************************************************************************************************
@@ -537,6 +685,9 @@ testRun(void)
         hrnCfgArgKeyRawZ(argList, cfgOptPgUser, 1, "bob");
         HRN_CFG_LOAD(cfgCmdBackup, argList);
 
+        // Create control file
+        HRN_PG_CONTROL_PUT(storagePgIdxWrite(0), PG_VERSION_93);
+
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("error connecting to primary");
 
@@ -551,7 +702,7 @@ testRun(void)
 
         TEST_ERROR(dbGet(true, true, false), DbConnectError, "unable to find primary cluster - cannot proceed");
         TEST_RESULT_LOG(
-            "P00   WARN: unable to check pg-1: [DbConnectError] unable to connect to 'dbname='postgres' port=5432 user='bob'':"
+            "P00   WARN: unable to check pg1: [DbConnectError] unable to connect to 'dbname='postgres' port=5432 user='bob'':"
                 " error");
 
         // -------------------------------------------------------------------------------------------------------------------------
@@ -593,7 +744,7 @@ testRun(void)
 
         harnessPqScriptSet((HarnessPq [])
         {
-            HRNPQ_MACRO_OPEN_LE_91(1, "dbname='postgres' port=5432 user='bob'", PG_VERSION_84, TEST_PATH "/pg1", NULL, NULL),
+            HRNPQ_MACRO_OPEN_LE_91(1, "dbname='postgres' port=5432 user='bob'", PG_VERSION_90, TEST_PATH "/pg1", NULL, NULL),
             HRNPQ_MACRO_CLOSE(1),
             HRNPQ_MACRO_DONE()
         });
@@ -604,7 +755,7 @@ testRun(void)
         TEST_RESULT_BOOL(result.primary != NULL, true, "check primary");
         TEST_RESULT_INT(result.standbyIdx, 0, "check standby id");
         TEST_RESULT_BOOL(result.standby == NULL, true, "check standby");
-        TEST_RESULT_INT(dbPgVersion(result.primary), PG_VERSION_84, "version set");
+        TEST_RESULT_INT(dbPgVersion(result.primary), PG_VERSION_90, "version set");
         TEST_RESULT_STR_Z(dbPgDataPath(result.primary), TEST_PATH "/pg1", "path set");
 
         TEST_RESULT_VOID(dbFree(result.primary), "free primary");
@@ -620,10 +771,13 @@ testRun(void)
         hrnCfgArgKeyRawZ(argList, cfgOptPgPort, 8, "5433");
         HRN_CFG_LOAD(cfgCmdBackup, argList);
 
+        // Create control file
+        HRN_PG_CONTROL_PUT(storagePgIdxWrite(1), PG_VERSION_93);
+
         harnessPqScriptSet((HarnessPq [])
         {
-            HRNPQ_MACRO_OPEN_LE_91(1, "dbname='postgres' port=5432", PG_VERSION_84, TEST_PATH "/pg1", NULL, NULL),
-            HRNPQ_MACRO_OPEN_LE_91(8, "dbname='postgres' port=5433", PG_VERSION_84, TEST_PATH "/pg8", NULL, NULL),
+            HRNPQ_MACRO_OPEN_LE_91(1, "dbname='postgres' port=5432", PG_VERSION_90, TEST_PATH "/pg1", NULL, NULL),
+            HRNPQ_MACRO_OPEN_LE_91(8, "dbname='postgres' port=5433", PG_VERSION_90, TEST_PATH "/pg8", NULL, NULL),
 
             HRNPQ_MACRO_CLOSE(1),
             HRNPQ_MACRO_CLOSE(8),
@@ -692,7 +846,7 @@ testRun(void)
         {
             HRNPQ_MACRO_OPEN_GE_92(1, "dbname='postgres' port=5432", PG_VERSION_92, TEST_PATH "/pg1", true, NULL, NULL),
 
-            // pg-4 error
+            // pg4 error
             {.session = 4, .function = HRNPQ_CONNECTDB, .param = "[\"dbname='postgres' port=5433\"]"},
             {.session = 4, .function = HRNPQ_STATUS, .resultInt = CONNECTION_BAD},
             {.session = 4, .function = HRNPQ_ERRORMESSAGE, .resultZ = "error"},
@@ -713,8 +867,8 @@ testRun(void)
 
         hrnLogReplaceAdd("(could not connect to server|connection to server on socket).*$", NULL, "PG ERROR", false);
         TEST_RESULT_LOG(
-            "P00   WARN: unable to check pg-4: [DbConnectError] unable to connect to 'dbname='postgres' port=5433': error\n"
-            "P00   WARN: unable to check pg-5: [DbConnectError] raised from remote-0 ssh protocol on 'localhost':"
+            "P00   WARN: unable to check pg4: [DbConnectError] unable to connect to 'dbname='postgres' port=5433': error\n"
+            "P00   WARN: unable to check pg5: [DbConnectError] raised from remote-0 ssh protocol on 'localhost':"
                 " unable to connect to 'dbname='postgres' port=5432': [PG ERROR]");
 
         TEST_RESULT_INT(result.primaryIdx, 3, "check primary idx");
