@@ -21,8 +21,6 @@ Test protocol server command handlers
 ***********************************************************************************************************************************/
 #define TEST_PROTOCOL_COMMAND_ASSERT                                STRID5("assert", 0x2922ce610)
 
-static unsigned int testCommandAssertProtocolTotal = 0;
-
 __attribute__((__noreturn__)) static void
 testCommandAssertProtocol(PackRead *const param, ProtocolServer *const server)
 {
@@ -34,14 +32,15 @@ testCommandAssertProtocol(PackRead *const param, ProtocolServer *const server)
     ASSERT(param == NULL);
     ASSERT(server != NULL);
 
-    testCommandAssertProtocolTotal++;
-    hrnErrorThrowP(.message = testCommandAssertProtocolTotal <= 3 ? NULL : "ERR_MESSAGE_RETRY");
+    hrnErrorThrowP();
 
     // No FUNCTION_HARNESS_RETURN_VOID() because the function does not return
 }
 
 #define TEST_PROTOCOL_COMMAND_ERROR                                 STRID5("error", 0x127ca450)
 
+static unsigned int testCommandErrorProtocolTotal = 0;
+
 __attribute__((__noreturn__)) static void
 testCommandErrorProtocol(PackRead *const param, ProtocolServer *const server)
 {
@@ -53,7 +52,8 @@ testCommandErrorProtocol(PackRead *const param, ProtocolServer *const server)
     ASSERT(param == NULL);
     ASSERT(server != NULL);
 
-    hrnErrorThrowP(.errorType = &FormatError);
+    testCommandErrorProtocolTotal++;
+    hrnErrorThrowP(.errorType = &FormatError, .message = testCommandErrorProtocolTotal <= 2 ? NULL : "ERR_MESSAGE_RETRY");
 
     // No FUNCTION_HARNESS_RETURN_VOID() because the function does not return
 }
@@ -279,10 +279,13 @@ testRun(void)
         // Create bogus client and exec to generate errors
         ProtocolHelperClient protocolHelperClient = {0};
 
+        IoWrite *write = ioFdWriteNewOpen(STRDEF("invalid"), 0, 0);
+
         OBJ_NEW_BEGIN(ProtocolClient)
         {
             protocolHelperClient.client = OBJ_NEW_ALLOC();
-            *protocolHelperClient.client = (ProtocolClient){.name = STRDEF("test"), .state = protocolClientStateIdle};
+            *protocolHelperClient.client = (ProtocolClient){
+                .name = STRDEF("test"), .state = protocolClientStateIdle, .write = write};
             memContextCallbackSet(memContextCurrent(), protocolClientFreeResource, protocolHelperClient.client);
         }
         OBJ_NEW_END();
@@ -298,7 +301,7 @@ testRun(void)
         TEST_RESULT_VOID(protocolHelperClientFree(&protocolHelperClient), "free");
 
         TEST_RESULT_LOG(
-            "P00   WARN: assertion 'write != NULL' failed\n"
+            "P00   WARN: unable to write to invalid: [9] Bad file descriptor\n"
             "P00   WARN: unable to wait on child process: [10] No child processes");
     }
 
@@ -518,6 +521,14 @@ testRun(void)
                     protocolServerProcess(server, NULL, commandHandler, PROTOCOL_SERVER_HANDLER_LIST_SIZE(commandHandler)),
                     ProtocolError, "invalid command 'BOGUS' (0x38eacd271)");
 
+                // -----------------------------------------------------------------------------------------------------------------
+                TEST_TITLE("server restart and assert");
+
+                // This does not run in a TEST* macro because tests are run by the command handlers
+                TEST_ERROR(
+                    protocolServerProcess(server, NULL, commandHandler, PROTOCOL_SERVER_HANDLER_LIST_SIZE(commandHandler)),
+                    AssertError, "ERR_MESSAGE");
+
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("server restart");
 
@@ -594,7 +605,7 @@ testRun(void)
                 TEST_TITLE("invalid command");
 
                 TEST_ERROR(
-                    protocolClientExecute(client, protocolCommandNew(strIdFromZ(stringIdBit6, "BOGUS")), false), ProtocolError,
+                    protocolClientExecute(client, protocolCommandNew(strIdFromZ("BOGUS")), false), ProtocolError,
                     "raised from test client: invalid command 'BOGUS' (0x38eacd271)");
 
                 // -----------------------------------------------------------------------------------------------------------------
@@ -605,7 +616,7 @@ testRun(void)
                     protocolClientExecute(client, protocolCommandNew(TEST_PROTOCOL_COMMAND_ASSERT), false);
                     THROW(TestError, "error was expected");
                 }
-                CATCH_ANY()
+                CATCH_FATAL()
                 {
                     TEST_RESULT_PTR(errorType(), &AssertError, "check type");
                     TEST_RESULT_Z(errorFileName(), TEST_PGB_PATH "/src/protocol/client.c", "check file");
@@ -679,10 +690,10 @@ testRun(void)
                 TEST_TITLE("command throws assert with retry messages");
 
                 TEST_ERROR(
-                    protocolClientExecute(client, protocolCommandNew(TEST_PROTOCOL_COMMAND_ASSERT), false), AssertError,
+                    protocolClientExecute(client, protocolCommandNew(TEST_PROTOCOL_COMMAND_ERROR), false), FormatError,
                     "raised from test client: ERR_MESSAGE\n"
-                    "[AssertError] on retry after 0ms\n"
-                    "[AssertError] on retry after 500ms: ERR_MESSAGE_RETRY");
+                    "[FormatError] on retry after 0ms\n"
+                    "[FormatError] on retry after 500ms: ERR_MESSAGE_RETRY");
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("free client");
@@ -711,14 +722,13 @@ testRun(void)
                 TEST_TITLE("ping server");
 
                 // Connect to server without any verification
-                IoClient *tlsClient = tlsClientNew(
-                    sckClientNew(hrnServerHost(), hrnServerPort(0), 5000, 5000), hrnServerHost(), 5000, 5000, false, NULL, NULL,
-                    NULL, NULL);
+                IoClient *tlsClient = tlsClientNewP(
+                    sckClientNew(hrnServerHost(), hrnServerPort(0), 5000, 5000), hrnServerHost(), 5000, 5000, false);
                 IoSession *tlsSession = ioClientOpen(tlsClient);
 
                 // Send ping
                 ProtocolClient *protocolClient = protocolClientNew(
-                    PROTOCOL_SERVICE_REMOTE_STR, PROTOCOL_SERVICE_REMOTE_STR, ioSessionIoRead(tlsSession),
+                    PROTOCOL_SERVICE_REMOTE_STR, PROTOCOL_SERVICE_REMOTE_STR, ioSessionIoReadP(tlsSession),
                     ioSessionIoWrite(tlsSession));
                 protocolClientNoExit(protocolClient);
                 protocolClientNoOp(protocolClient);
@@ -816,7 +826,7 @@ testRun(void)
 
                 StringList *argList = strLstDup(argListBase);
                 hrnCfgArgRawZ(argList, cfgOptTlsServerAuth, "pgbackrest-client=db");
-                HRN_CFG_LOAD(cfgCmdServerStart, argList);
+                HRN_CFG_LOAD(cfgCmdServer, argList);
 
                 socketSession = ioServerAccept(socketServer, NULL);
 
@@ -828,7 +838,7 @@ testRun(void)
                 // -----------------------------------------------------------------------------------------------------------------
                 argList = strLstDup(argListBase);
                 hrnCfgArgRawZ(argList, cfgOptTlsServerAuth, "pgbackrest-client=bogus");
-                HRN_CFG_LOAD(cfgCmdServerStart, argList);
+                HRN_CFG_LOAD(cfgCmdServer, argList);
 
                 socketSession = ioServerAccept(socketServer, NULL);
 
@@ -838,7 +848,7 @@ testRun(void)
                 // -----------------------------------------------------------------------------------------------------------------
                 argList = strLstDup(argListBase);
                 hrnCfgArgRawZ(argList, cfgOptTlsServerAuth, "bogus=*");
-                HRN_CFG_LOAD(cfgCmdServerStart, argList);
+                HRN_CFG_LOAD(cfgCmdServer, argList);
 
                 socketSession = ioServerAccept(socketServer, NULL);
 
@@ -848,7 +858,7 @@ testRun(void)
                 // -----------------------------------------------------------------------------------------------------------------
                 argList = strLstDup(argListBase);
                 hrnCfgArgRawZ(argList, cfgOptTlsServerAuth, "pgbackrest-client=db");
-                HRN_CFG_LOAD(cfgCmdServerStart, argList);
+                HRN_CFG_LOAD(cfgCmdServer, argList);
 
                 socketSession = ioServerAccept(socketServer, NULL);
 
@@ -858,7 +868,7 @@ testRun(void)
                 // -----------------------------------------------------------------------------------------------------------------
                 argList = strLstDup(argListBase);
                 hrnCfgArgRawZ(argList, cfgOptTlsServerAuth, "pgbackrest-client=*");
-                HRN_CFG_LOAD(cfgCmdServerStart, argList);
+                HRN_CFG_LOAD(cfgCmdServer, argList);
 
                 socketSession = ioServerAccept(socketServer, NULL);
 
@@ -883,7 +893,7 @@ testRun(void)
         {
             TEST_ASSIGN(
                 job,
-                protocolParallelJobNew(VARSTRDEF("test"), protocolCommandNew(strIdFromZ(stringIdBit5, "c"))), "new job");
+                protocolParallelJobNew(VARSTRDEF("test"), protocolCommandNew(strIdFromZ("c"))), "new job");
             TEST_RESULT_PTR(protocolParallelJobMove(job, memContextPrior()), job, "move job");
             TEST_RESULT_PTR(protocolParallelJobMove(NULL, memContextPrior()), NULL, "move null job");
         }
@@ -915,7 +925,7 @@ testRun(void)
                     "local server 1");
 
                 // Command with output
-                TEST_RESULT_UINT(protocolServerCommandGet(server).id, strIdFromZ(stringIdBit5, "c-one"), "c-one command get");
+                TEST_RESULT_UINT(protocolServerCommandGet(server).id, strIdFromZ("c-one"), "c-one command get");
 
                 // Wait for notify from parent
                 HRN_FORK_CHILD_NOTIFY_GET();
@@ -938,7 +948,7 @@ testRun(void)
                     "local server 2");
 
                 // Command with output
-                TEST_RESULT_UINT(protocolServerCommandGet(server).id, strIdFromZ(stringIdBit5, "c2"), "c2 command get");
+                TEST_RESULT_UINT(protocolServerCommandGet(server).id, strIdFromZ("c2"), "c2 command get");
 
                 // Wait for notify from parent
                 HRN_FORK_CHILD_NOTIFY_GET();
@@ -947,11 +957,11 @@ testRun(void)
                 TEST_RESULT_VOID(protocolServerDataEndPut(server), "data end put");
 
                 // Command with error
-                TEST_RESULT_UINT(protocolServerCommandGet(server).id, strIdFromZ(stringIdBit5, "c-three"), "c-three command get");
+                TEST_RESULT_UINT(protocolServerCommandGet(server).id, strIdFromZ("c-three"), "c-three command get");
                 TEST_RESULT_VOID(protocolServerError(server, 39, STRDEF("very serious error"), STRDEF("stack")), "error put");
 
                 // Wait for exit
-                CHECK(protocolServerCommandGet(server).id == PROTOCOL_COMMAND_EXIT);
+                TEST_RESULT_UINT(protocolServerCommandGet(server).id, PROTOCOL_COMMAND_EXIT, "wait for exit");
             }
             HRN_FORK_CHILD_END();
 
@@ -993,20 +1003,20 @@ testRun(void)
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("add jobs");
 
-                ProtocolCommand *command = protocolCommandNew(strIdFromZ(stringIdBit5, "c-one"));
+                ProtocolCommand *command = protocolCommandNew(strIdFromZ("c-one"));
                 pckWriteStrP(protocolCommandParam(command), STRDEF("param1"));
                 pckWriteStrP(protocolCommandParam(command), STRDEF("param2"));
 
                 ProtocolParallelJob *job = protocolParallelJobNew(varNewStr(STRDEF("job1")), command);
                 TEST_RESULT_VOID(lstAdd(data.jobList, &job), "add job");
 
-                command = protocolCommandNew(strIdFromZ(stringIdBit5, "c2"));
+                command = protocolCommandNew(strIdFromZ("c2"));
                 pckWriteStrP(protocolCommandParam(command), STRDEF("param1"));
 
                 job = protocolParallelJobNew(varNewStr(STRDEF("job2")), command);
                 TEST_RESULT_VOID(lstAdd(data.jobList, &job), "add job");
 
-                command = protocolCommandNew(strIdFromZ(stringIdBit5, "c-three"));
+                command = protocolCommandNew(strIdFromZ("c-three"));
                 pckWriteStrP(protocolCommandParam(command), STRDEF("param1"));
 
                 job = protocolParallelJobNew(varNewStr(STRDEF("job3")), command);
