@@ -109,7 +109,6 @@ testRun(void)
         TEST_RESULT_PTR(storageDriver(storageTest), storageTest->pub.driver, "check driver");
         TEST_RESULT_UINT(storageType(storageTest), storageTest->pub.type, "check type");
         TEST_RESULT_BOOL(storageFeature(storageTest, storageFeaturePath), true, "check path feature");
-        TEST_RESULT_BOOL(storageFeature(storageTest, storageFeatureCompress), true, "check compress feature");
     }
 
     // *****************************************************************************************************************************
@@ -1032,13 +1031,34 @@ testRun(void)
         TEST_RESULT_BOOL(memcmp(bufPtrConst(buffer), "TESTFILE\n", bufSize(buffer)) == 0, true, "check content");
 
         // -------------------------------------------------------------------------------------------------------------------------
-        TEST_TITLE("read limited bytes");
+        TEST_TITLE("error on invalid read offset bytes");
 
-        ioBufferSizeSet(2);
+        TEST_ERROR(
+            storageGetP(storageNewReadP(storageTest, STRDEF(TEST_PATH "/test.txt"), .offset = UINT64_MAX)), FileOpenError,
+            "unable to seek to 18446744073709551615 in file '" TEST_PATH "/test.txt': [22] Invalid argument");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("read limited bytes");
 
         TEST_ASSIGN(buffer, storageGetP(storageNewReadP(storageTest, STRDEF(TEST_PATH "/test.txt"), .limit = VARUINT64(7))), "get");
         TEST_RESULT_UINT(bufSize(buffer), 7, "check size");
         TEST_RESULT_BOOL(memcmp(bufPtrConst(buffer), "TESTFIL", bufSize(buffer)) == 0, true, "check content");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("read offset bytes");
+
+        TEST_ASSIGN(buffer, storageGetP(storageNewReadP(storageTest, STRDEF(TEST_PATH "/test.txt"), .offset = 4)), "get");
+        TEST_RESULT_UINT(bufSize(buffer), 5, "check size");
+        TEST_RESULT_BOOL(memcmp(bufPtrConst(buffer), "FILE\n", bufSize(buffer)) == 0, true, "check content");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("read offset/limited bytes");
+
+        TEST_ASSIGN(
+            buffer, storageGetP(storageNewReadP(storageTest, STRDEF(TEST_PATH "/test.txt"), .offset = 4,
+            .limit = VARUINT64(4))), "get");
+        TEST_RESULT_UINT(bufSize(buffer), 4, "check size");
+        TEST_RESULT_BOOL(memcmp(bufPtrConst(buffer), "FILE", bufSize(buffer)) == 0, true, "check content");
     }
 
     // *****************************************************************************************************************************
@@ -1138,7 +1158,8 @@ testRun(void)
         MEM_CONTEXT_TEMP_BEGIN()
         {
             TEST_ASSIGN(
-                file, storageReadMove(storageNewReadP(storageTest, fileName, .limit = VARUINT64(44)), memContextPrior()),
+                file,
+                storageReadMove(storageNewReadP(storageTest, fileName, .limit = VARUINT64(44)), memContextPrior()),
                 "new read file");
         }
         MEM_CONTEXT_TEMP_END();
@@ -1146,6 +1167,7 @@ testRun(void)
         TEST_RESULT_BOOL(ioReadOpen(storageReadIo(file)), true, "open file");
         TEST_RESULT_STR(storageReadName(file), fileName, "check file name");
         TEST_RESULT_UINT(storageReadType(file), STORAGE_POSIX_TYPE, "check file type");
+        TEST_RESULT_UINT(storageReadOffset(file), 0, "check offset");
         TEST_RESULT_UINT(varUInt64(storageReadLimit(file)), 44, "check limit");
 
         TEST_RESULT_VOID(ioRead(storageReadIo(file), outBuffer), "load data");
@@ -1545,7 +1567,7 @@ testRun(void)
         static const StorageHelper storageHelperListError[] = {{.type = STORAGE_POSIX_TYPE}, STORAGE_END_HELPER};
         storageHelperInit(storageHelperListError);
 
-        TEST_ERROR(storageRepoGet(0, true), AssertError, "check 'type == STORAGE_POSIX_TYPE' failed");
+        TEST_ERROR(storageRepoGet(0, true), AssertError, "invalid storage type");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("storage configuration");
@@ -1558,7 +1580,6 @@ testRun(void)
         TEST_ASSIGN(storage, storageRepoGet(0, true), "get cifs repo storage");
         TEST_RESULT_UINT(storageType(storage), STORAGE_CIFS_TYPE, "check storage type");
         TEST_RESULT_BOOL(storageFeature(storage, storageFeaturePath), true, "check path feature");
-        TEST_RESULT_BOOL(storageFeature(storage, storageFeatureCompress), true, "check compress feature");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("write object path sync false");
