@@ -27,6 +27,8 @@ typedef struct TestRequestParam
     const char *content;
     const char *accessKey;
     const char *securityToken;
+    const char *range;
+    const char *kms;
 } TestRequestParam;
 
 #define testRequestP(write, s3, verb, path, ...)                                                                                   \
@@ -64,11 +66,19 @@ testRequest(IoWrite *write, Storage *s3, const char *verb, const char *path, Tes
         if (param.content != NULL)
             strCatZ(request, "content-md5;");
 
-        strCatZ(request, "host;x-amz-content-sha256;x-amz-date");
+        strCatZ(request, "host;");
+
+        if (param.range != NULL)
+            strCatZ(request, "range;");
+
+        strCatZ(request, "x-amz-content-sha256;x-amz-date");
 
         if (securityToken != NULL)
             strCatZ(request, ";x-amz-security-token");
 
+        if (param.kms != NULL)
+            strCatZ(request, ";x-amz-server-side-encryption;x-amz-server-side-encryption-aws-kms-key-id");
+
         strCatZ(request, ",Signature=????????????????????????????????????????????????????????????????\r\n");
     }
 
@@ -94,6 +104,10 @@ testRequest(IoWrite *write, Storage *s3, const char *verb, const char *path, Tes
     else
         strCatFmt(request, "host:%s\r\n", strZ(hrnServerHost()));
 
+    // Add range
+    if (param.range != NULL)
+        strCatFmt(request, "range:bytes=%s\r\n", param.range);
+
     // Add content checksum and date if s3 service
     if (s3 != NULL)
     {
@@ -110,6 +124,13 @@ testRequest(IoWrite *write, Storage *s3, const char *verb, const char *path, Tes
             strCatFmt(request, "x-amz-security-token:%s\r\n", securityToken);
     }
 
+    // Add kms key
+    if (param.kms != NULL)
+    {
+        strCatZ(request, "x-amz-server-side-encryption:aws:kms\r\n");
+        strCatFmt(request, "x-amz-server-side-encryption-aws-kms-key-id:%s\r\n", param.kms);
+    }
+
     // Add final \r\n
     strCatZ(request, "\r\n");
 
@@ -390,7 +411,6 @@ testRun(void)
 
                 TEST_RESULT_STR(s3->path, path, "check path");
                 TEST_RESULT_BOOL(storageFeature(s3, storageFeaturePath), false, "check path feature");
-                TEST_RESULT_BOOL(storageFeature(s3, storageFeatureCompress), false, "check compress feature");
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("coverage for noop functions");
@@ -417,13 +437,14 @@ testRun(void)
                     "unable to open missing file '/file.txt' for read");
 
                 // -----------------------------------------------------------------------------------------------------------------
-                TEST_TITLE("get file");
+                TEST_TITLE("get file with offset and limit");
 
-                testRequestP(service, s3, HTTP_VERB_GET, "/file.txt");
+                testRequestP(service, s3, HTTP_VERB_GET, "/file.txt", .range = "1-21");
                 testResponseP(service, .content = "this is a sample file");
 
                 TEST_RESULT_STR_Z(
-                    strNewBuf(storageGetP(storageNewReadP(s3, STRDEF("file.txt")))), "this is a sample file", "get file");
+                    strNewBuf(storageGetP(storageNewReadP(s3, STRDEF("file.txt"), .offset = 1, .limit = VARUINT64(21)))),
+                    "this is a sample file", "get file");
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("get zero-length file");
@@ -442,6 +463,7 @@ testRun(void)
                 hrnCfgArgRawFmt(argList, cfgOptRepoStorageHost, "%s:%u", strZ(host), port);
                 hrnCfgArgRaw(argList, cfgOptRepoS3Role, credRole);
                 hrnCfgArgRawStrId(argList, cfgOptRepoS3KeyType, storageS3KeyTypeAuto);
+                hrnCfgArgRawZ(argList, cfgOptRepoS3KmsKeyId, "kmskey1");
                 HRN_CFG_LOAD(cfgCmdArchivePush, argList);
 
                 s3 = storageRepoGet(0, true);
@@ -450,7 +472,6 @@ testRun(void)
                 TEST_RESULT_STR(s3->path, path, "check path");
                 TEST_RESULT_STR(driver->credRole, credRole, "check role");
                 TEST_RESULT_BOOL(storageFeature(s3, storageFeaturePath), false, "check path feature");
-                TEST_RESULT_BOOL(storageFeature(s3, storageFeatureCompress), false, "check compress feature");
 
                 // Set partSize to a small value for testing
                 driver->partSize = 16;
@@ -478,7 +499,7 @@ testRun(void)
                     storageGetP(storageNewReadP(s3, STRDEF("file.txt"))), ProtocolError,
                     "HTTP request failed with 301:\n"
                         "*** Path/Query ***:\n"
-                        "/latest/meta-data/iam/security-credentials\n"
+                        "GET /latest/meta-data/iam/security-credentials\n"
                         "*** Request Headers ***:\n"
                         "content-length: 0\n"
                         "host: %s",
@@ -519,7 +540,7 @@ testRun(void)
                     storageGetP(storageNewReadP(s3, STRDEF("file.txt"))), ProtocolError,
                     "HTTP request failed with 300:\n"
                         "*** Path/Query ***:\n"
-                        "/latest/meta-data/iam/security-credentials/credrole\n"
+                        "GET /latest/meta-data/iam/security-credentials/credrole\n"
                         "*** Request Headers ***:\n"
                         "content-length: 0\n"
                         "host: %s",
@@ -583,7 +604,7 @@ testRun(void)
                     ioReadOpen(storageReadIo(read)), ProtocolError,
                     "HTTP request failed with 303:\n"
                     "*** Path/Query ***:\n"
-                    "/file.txt\n"
+                    "GET /file.txt\n"
                     "*** Request Headers ***:\n"
                     "authorization: <redacted>\n"
                     "content-length: 0\n"
@@ -617,7 +638,9 @@ testRun(void)
 
                 hrnServerScriptClose(auth);
 
-                testRequestP(service, s3, HTTP_VERB_PUT, "/file.txt", .content = "ABCD", .accessKey = "xx", .securityToken = "zz");
+                testRequestP(
+                    service, s3, HTTP_VERB_PUT, "/file.txt", .content = "ABCD", .accessKey = "xx", .securityToken = "zz",
+                    .kms = "kmskey1");
                 testResponseP(service);
 
                 // Make a copy of the signing key to verify that it gets changed when the keys are updated
@@ -648,7 +671,7 @@ testRun(void)
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("write zero-length file");
 
-                testRequestP(service, s3, HTTP_VERB_PUT, "/file.txt", .content = "");
+                testRequestP(service, s3, HTTP_VERB_PUT, "/file.txt", .content = "", .kms = "kmskey1");
                 testResponseP(service);
 
                 TEST_ASSIGN(write, storageNewWriteP(s3, STRDEF("file.txt")), "new write");
@@ -657,7 +680,7 @@ testRun(void)
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("write file in chunks with nothing left over on close");
 
-                testRequestP(service, s3, HTTP_VERB_POST, "/file.txt?uploads=");
+                testRequestP(service, s3, HTTP_VERB_POST, "/file.txt?uploads=", .kms = "kmskey1");
                 testResponseP(
                     service,
                     .content =
@@ -694,7 +717,7 @@ testRun(void)
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("error in success response of multipart upload");
 
-                testRequestP(service, s3, HTTP_VERB_POST, "/file.txt?uploads=");
+                testRequestP(service, s3, HTTP_VERB_POST, "/file.txt?uploads=", .kms = "kmskey1");
                 testResponseP(
                     service,
                     .content =
@@ -730,7 +753,7 @@ testRun(void)
                     storagePutP(write, BUFSTRDEF("12345678901234567890123456789012")), ProtocolError,
                     "HTTP request failed with 200 (OK):\n"
                     "*** Path/Query ***:\n"
-                    "/file.txt?uploadId=WxRt\n"
+                    "POST /file.txt?uploadId=WxRt\n"
                     "*** Request Headers ***:\n"
                     "authorization: <redacted>\n"
                     "content-length: 205\n"
@@ -748,7 +771,7 @@ testRun(void)
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("write file in chunks with something left over on close");
 
-                testRequestP(service, s3, HTTP_VERB_POST, "/file.txt?uploads=");
+                testRequestP(service, s3, HTTP_VERB_POST, "/file.txt?uploads=", .kms = "kmskey1");
                 testResponseP(
                     service,
                     .content =
@@ -898,6 +921,15 @@ testRun(void)
                 // Auth service no longer needed
                 hrnServerScriptEnd(auth);
 
+                // -----------------------------------------------------------------------------------------------------------------
+                TEST_TITLE("write zero-length file (without kms)");
+
+                testRequestP(service, s3, HTTP_VERB_PUT, "/file.txt", .content = "");
+                testResponseP(service);
+
+                TEST_ASSIGN(write, storageNewWriteP(s3, STRDEF("file.txt")), "new write");
+                TEST_RESULT_VOID(storagePutP(write, NULL), "write");
+
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("info check existence only");
 
@@ -926,7 +958,7 @@ testRun(void)
                 TEST_ERROR(storageListP(s3, STRDEF("/")), ProtocolError,
                     "HTTP request failed with 344:\n"
                     "*** Path/Query ***:\n"
-                    "/?delimiter=%2F&list-type=2\n"
+                    "GET /?delimiter=%2F&list-type=2\n"
                     "*** Request Headers ***:\n"
                     "authorization: <redacted>\n"
                     "content-length: 0\n"
@@ -950,7 +982,7 @@ testRun(void)
                 TEST_ERROR(storageListP(s3, STRDEF("/")), ProtocolError,
                     "HTTP request failed with 344:\n"
                     "*** Path/Query ***:\n"
-                    "/?delimiter=%2F&list-type=2\n"
+                    "GET /?delimiter=%2F&list-type=2\n"
                     "*** Request Headers ***:\n"
                     "authorization: <redacted>\n"
                     "content-length: 0\n"
@@ -1153,7 +1185,7 @@ testRun(void)
 
                 argList = strLstDup(commonArgList);
                 hrnCfgArgRawStrId(argList, cfgOptRepoS3UriStyle, storageS3UriStylePath);
-                hrnCfgArgRaw(argList, cfgOptRepoStorageHost, host);
+                hrnCfgArgRawFmt(argList, cfgOptRepoStorageHost, "https://%s", strZ(host));
                 hrnCfgArgRawFmt(argList, cfgOptRepoStoragePort, "%u", port);
                 hrnCfgEnvRemoveRaw(cfgOptRepoS3Token);
                 HRN_CFG_LOAD(cfgCmdArchivePush, argList);
@@ -1270,7 +1302,7 @@ testRun(void)
                 TEST_RESULT_VOID(storagePathRemoveP(s3, STRDEF("/path/to"), .recurse = true), "remove");
 
                 // -----------------------------------------------------------------------------------------------------------------
-                TEST_TITLE("remove error");
+                TEST_TITLE("path remove error and retry");
 
                 testRequestP(service, s3, HTTP_VERB_GET, "/bucket/?list-type=2&prefix=path%2F");
                 testResponseP(
@@ -1299,12 +1331,13 @@ testRun(void)
                     .content =
                         "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
                         "<DeleteResult xmlns=\"http://s3.amazonaws.com/doc/2006-03-01/\">"
-                            "<Error><Key>sample2.txt</Key><Code>AccessDenied</Code><Message>Access Denied</Message></Error>"
+                            "<Error><Key>path/sample2.txt</Key><Code>AccessDenied</Code><Message>Access Denied</Message></Error>"
                             "</DeleteResult>");
 
-                TEST_ERROR(
-                    storagePathRemoveP(s3, STRDEF("/path"), .recurse = true), FileRemoveError,
-                    "unable to remove file 'sample2.txt': [AccessDenied] Access Denied");
+                testRequestP(service, s3, HTTP_VERB_DELETE, "/bucket/path/sample2.txt");
+                testResponseP(service, .code = 204);
+
+                TEST_RESULT_VOID(storagePathRemoveP(s3, STRDEF("/path"), .recurse = true), "remove path");
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("remove file");
